=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2010-01-20 23:28:35 +0000
+++ bzrlib/tests/blackbox/test_info.py	2010-02-05 13:29:25 +0000
@@ -25,22 +25,20 @@
     errors,
     info,
     osutils,
+    tests,
     upgrade,
     urlutils,
     )
-from bzrlib.osutils import format_date
-from bzrlib.tests import TestSkipped, MemoryServer
-from bzrlib.tests.blackbox import ExternalBase
-
-
-class TestInfo(ExternalBase):
+from bzrlib.transport import memory
+
+class TestInfo(tests.TestCaseWithTransport):
 
     def setUp(self):
-        ExternalBase.setUp(self)
+        super(TestInfo, self).setUp()
         self._repo_strings = "2a"
 
     def test_info_non_existing(self):
-        self.vfs_transport_factory = MemoryServer
+        self.vfs_transport_factory = memory.MemoryServer
         location = self.get_url()
         out, err = self.run_bzr('info '+location, retcode=3)
         self.assertEqual(out, '')
@@ -127,7 +125,7 @@
         self.assertEqual('', err)
         tree1.commit('commit one')
         rev = branch1.repository.get_revision(branch1.revision_history()[0])
-        datestring_first = format_date(rev.timestamp, rev.timezone)
+        datestring_first = osutils.format_date(rev.timestamp, rev.timezone)
 
         # Branch standalone with push location
         branch2 = branch1.bzrdir.sprout('branch').open_branch()
@@ -315,7 +313,7 @@
         tree1.add('b')
         tree1.commit('commit two')
         rev = branch1.repository.get_revision(branch1.revision_history()[-1])
-        datestring_last = format_date(rev.timestamp, rev.timezone)
+        datestring_last = osutils.format_date(rev.timestamp, rev.timezone)
 
         # Out of date branched standalone branch will not be detected
         out, err = self.run_bzr('info -v branch')
@@ -569,7 +567,7 @@
         tree2.add('a')
         tree2.commit('commit one')
         rev = repo.get_revision(branch2.revision_history()[0])
-        datestring_first = format_date(rev.timestamp, rev.timezone)
+        datestring_first = osutils.format_date(rev.timestamp, rev.timezone)
         out, err = self.run_bzr('info tree/lightcheckout --verbose')
         self.assertEqualDiff(
 """Lightweight checkout (format: %s)
@@ -688,7 +686,7 @@
 
         # Out of date lightweight checkout
         rev = repo.get_revision(branch1.revision_history()[-1])
-        datestring_last = format_date(rev.timestamp, rev.timezone)
+        datestring_last = osutils.format_date(rev.timestamp, rev.timezone)
         out, err = self.run_bzr('info tree/lightcheckout --verbose')
         self.assertEqualDiff(
 """Lightweight checkout (format: %s)
@@ -844,7 +842,7 @@
         tree1.add('a')
         tree1.commit('commit one')
         rev = repo.get_revision(branch1.revision_history()[0])
-        datestring_first = format_date(rev.timestamp, rev.timezone)
+        datestring_first = osutils.format_date(rev.timestamp, rev.timezone)
         out, err = self.run_bzr('info -v repo/branch1')
         self.assertEqualDiff(
 """Repository tree (format: knit)

=== modified file 'bzrlib/tests/per_branch/test_bound_sftp.py'
--- bzrlib/tests/per_branch/test_bound_sftp.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/per_branch/test_bound_sftp.py	2010-02-05 13:35:16 +0000
@@ -19,27 +19,20 @@
 
 import os
 
-import bzrlib
 from bzrlib import (
+    branch,
     bzrdir,
+    errors,
+    tests,
     )
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import (BzrDir,
-                           BzrDirFormat,
-                           BzrDirFormat6,
-                           BzrDirMetaFormat1,
-                           )
-import bzrlib.errors as errors
-from bzrlib.tests import TestSkipped
-from bzrlib.tests import TestCaseWithTransport
 from bzrlib.transport.local import LocalURLServer
 from bzrlib.transport.memory import MemoryServer
 
 
-class BoundSFTPBranch(TestCaseWithTransport):
+class BoundSFTPBranch(tests.TestCaseWithTransport):
 
     def setUp(self):
-        TestCaseWithTransport.setUp(self)
+        tests.TestCaseWithTransport.setUp(self)
         self.vfs_transport_factory = MemoryServer
         if self.transport_server is LocalURLServer:
             self.transport_server = None
@@ -48,10 +41,10 @@
         self.build_tree(['base/', 'base/a', 'base/b'])
         format = bzrdir.format_registry.make_bzrdir('knit')
         try:
-            wt_base = BzrDir.create_standalone_workingtree(
+            wt_base = bzrdir.BzrDir.create_standalone_workingtree(
                 self.get_url('base'), format=format)
         except errors.NotLocalUrl:
-            raise TestSkipped('Not a local URL')
+            raise tests.TestSkipped('Not a local URL')
 
         b_base = wt_base.branch
 
@@ -60,7 +53,7 @@
         wt_base.commit('first', rev_id='r@b-1')
 
         wt_child = b_base.bzrdir.sprout('child').open_workingtree()
-        self.sftp_base = Branch.open(self.get_url('base'))
+        self.sftp_base = branch.Branch.open(self.get_url('base'))
         wt_child.branch.bind(self.sftp_base)
         # check the branch histories are ready for using in tests.
         self.assertEqual(['r@b-1'], b_base.revision_history())
@@ -70,9 +63,10 @@
     def test_simple_binding(self):
         self.build_tree(['base/', 'base/a', 'base/b', 'child/'])
         try:
-            wt_base = BzrDir.create_standalone_workingtree(self.get_url('base'))
+            wt_base = bzrdir.BzrDir.create_standalone_workingtree(
+                self.get_url('base'))
         except errors.NotLocalUrl:
-            raise TestSkipped('Not a local URL')
+            raise tests.TestSkipped('Not a local URL')
 
         wt_base.add('a')
         wt_base.add('b')
@@ -83,11 +77,12 @@
         # may not be bindable-from, and we want to test the side effects etc
         # of bondage.
         format = bzrdir.format_registry.make_bzrdir('knit')
-        b_child = BzrDir.create_branch_convenience('child', format=format)
+        b_child = bzrdir.BzrDir.create_branch_convenience(
+            'child', format=format)
         self.assertEqual(None, b_child.get_bound_location())
         self.assertEqual(None, b_child.get_master_branch())
 
-        sftp_b_base = Branch.open(self.get_url('base'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
         b_child.bind(sftp_b_base)
         self.assertEqual(sftp_b_base.base, b_child.get_bound_location())
         # the bind must not have given b_child history:
@@ -125,7 +120,7 @@
         self.assertRaises(errors.BoundBranchOutOfDate,
                 wt_child.commit, 'child', rev_id='r@c-2')
 
-        sftp_b_base = Branch.open(self.get_url('base'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
 
         # This is all that cmd_update does
         wt_child.pull(sftp_b_base, overwrite=False)
@@ -170,7 +165,7 @@
         self.assertEqual(['r@b-1', 'r@c-2'], wt_child.branch.revision_history())
         self.assertEqual(['r@b-1', 'r@b-2'], b_base.revision_history())
 
-        sftp_b_base = Branch.open(self.get_url('base'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
         self.assertRaises(errors.DivergedBranches,
                 wt_child.branch.bind, sftp_b_base)
 
@@ -181,8 +176,8 @@
 
         b_base.bzrdir.sprout('newbase')
 
-        sftp_b_base = Branch.open(self.get_url('base'))
-        sftp_b_newbase = Branch.open(self.get_url('newbase'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
+        sftp_b_newbase = branch.Branch.open(self.get_url('newbase'))
 
         sftp_b_base.bind(sftp_b_newbase)
 
@@ -208,7 +203,7 @@
         b_base.bzrdir.open_workingtree().commit('base', rev_id='r@b-2')
         self.assertEqual(['r@b-1', 'r@b-2'], b_base.revision_history())
 
-        sftp_b_base = Branch.open(self.get_url('base'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
 
         self.assertRaises(errors.DivergedBranches,
                 wt_child.branch.bind, sftp_b_base)
@@ -236,7 +231,7 @@
         self.assertEqual(['r@b-1', 'r@b-2'], b_base.revision_history())
         self.assertEqual(['r@b-1'], wt_child.branch.revision_history())
 
-        sftp_b_base = Branch.open(self.get_url('base'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
         wt_child.branch.bind(sftp_b_base)
 
         self.assertEqual(['r@b-1'], wt_child.branch.revision_history())
@@ -265,7 +260,7 @@
         self.assertEqual(['r@b-1', 'r@c-2'], wt_child.branch.revision_history())
         self.assertEqual(['r@b-1'], b_base.revision_history())
 
-        sftp_b_base = Branch.open(self.get_url('base'))
+        sftp_b_base = branch.Branch.open(self.get_url('base'))
         wt_child.branch.bind(sftp_b_base)
 
         self.assertEqual(['r@b-1'], b_base.revision_history())

=== modified file 'bzrlib/tests/per_branch/test_branch.py'
--- bzrlib/tests/per_branch/test_branch.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/per_branch/test_branch.py	2010-02-05 13:56:14 +0000
@@ -16,43 +16,31 @@
 
 """Tests for branch implementations - tests a branch format."""
 
-import os
-import sys
-
 from bzrlib import (
-    branch,
+    branch as _mod_branch,
     bzrdir,
+    delta as _mod_delta,
     errors,
     gpg,
     merge,
     urlutils,
     transactions,
+    transport,
     remote,
     repository,
+    revision,
     tests,
     )
-from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
-from bzrlib.delta import TreeDelta
-from bzrlib.errors import (FileExists,
-                           NoSuchRevision,
-                           NoSuchFile,
-                           UninitializableFormat,
-                           NotBranchError,
-                           )
-from bzrlib.osutils import getcwd
-import bzrlib.revision
 from bzrlib.symbol_versioning import deprecated_in
-from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
+from bzrlib.tests import (
+    http_server,
+    per_branch,
+    )
 from bzrlib.tests.http_server import HttpServer
-from bzrlib.tests.per_branch import TestCaseWithBranch
-from bzrlib.trace import mutter
-from bzrlib.transport import get_transport
 from bzrlib.transport.memory import MemoryServer
-from bzrlib.upgrade import upgrade
-from bzrlib.workingtree import WorkingTree
-
-
-class TestTestCaseWithBranch(TestCaseWithBranch):
+
+
+class TestTestCaseWithBranch(per_branch.TestCaseWithBranch):
 
     def test_branch_format_matches_bzrdir_branch_format(self):
         bzrdir_branch_format = self.bzrdir_format.get_branch_format()
@@ -65,7 +53,7 @@
             branch._format.__class__)
 
 
-class TestBranch(TestCaseWithBranch):
+class TestBranch(per_branch.TestCaseWithBranch):
 
     def test_create_tree_with_merge(self):
         tree = self.create_tree_with_merge()
@@ -128,10 +116,10 @@
         tree_a.commit('rev2', rev_id='rev2')
 
         delta = tree_a.branch.get_revision_delta(1)
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([('foo', 'file1', 'file')], delta.added)
         delta = tree_a.branch.get_revision_delta(2)
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([('vla', 'file2', 'file')], delta.added)
 
     def get_unbalanced_tree_pair(self):
@@ -186,7 +174,7 @@
 
     def test_clone_branch_nickname(self):
         # test the nick name is preserved always
-        raise TestSkipped('XXX branch cloning is not yet tested.')
+        raise tests.TestSkipped('XXX branch cloning is not yet tested.')
 
     def test_clone_branch_parent(self):
         # test the parent is preserved always
@@ -358,14 +346,14 @@
         explicit nickname is set.  That is, an explicit nickname always
         overrides the implicit one.
         """
-        t = get_transport(self.get_url())
+        t = transport.get_transport(self.get_url())
         branch = self.make_branch('bzr.dev')
         # The nick will be 'bzr.dev', because there is no explicit nick set.
         self.assertEqual(branch.nick, 'bzr.dev')
         # Move the branch to a different directory, 'bzr.ab'.  Now that branch
         # will report its nick as 'bzr.ab'.
         t.move('bzr.dev', 'bzr.ab')
-        branch = Branch.open(self.get_url('bzr.ab'))
+        branch = _mod_branch.Branch.open(self.get_url('bzr.ab'))
         self.assertEqual(branch.nick, 'bzr.ab')
         # Set the branch nick explicitly.  This will ensure there's a branch
         # config file in the branch.
@@ -376,7 +364,7 @@
         # "Aaron's branch", regardless of directory name.
         self.assertEqual(branch.nick, "Aaron's branch")
         t.move('bzr.ab', 'integration')
-        branch = Branch.open(self.get_url('integration'))
+        branch = _mod_branch.Branch.open(self.get_url('integration'))
         self.assertEqual(branch.nick, "Aaron's branch")
         branch.nick = u"\u1234"
         self.assertEqual(branch.nick, u"\u1234")
@@ -406,7 +394,7 @@
             return
         self.assertEqual(repo.bzrdir.root_transport.base,
                          child_branch.repository.bzrdir.root_transport.base)
-        child_branch = branch.Branch.open(self.get_url('child'))
+        child_branch = _mod_branch.Branch.open(self.get_url('child'))
         self.assertEqual(repo.bzrdir.root_transport.base,
                          child_branch.repository.bzrdir.root_transport.base)
 
@@ -435,7 +423,7 @@
     def test_generate_revision_history_NULL_REVISION(self):
         tree = self.make_branch_and_tree('.')
         rev1 = tree.commit('foo')
-        tree.branch.generate_revision_history(bzrlib.revision.NULL_REVISION)
+        tree.branch.generate_revision_history(revision.NULL_REVISION)
         self.assertEqual([], tree.branch.revision_history())
 
     def test_create_checkout(self):
@@ -453,10 +441,8 @@
         self.assertEqual('rev2', branch_a.last_revision())
         self.assertEqual(checkout_c.branch.base, branch_a.base)
 
-        os.mkdir('d')
         checkout_d = branch_a.create_checkout('d', lightweight=True)
         self.assertEqual('rev2', checkout_d.last_revision())
-        os.mkdir('e')
         checkout_e = branch_a.create_checkout('e')
         self.assertEqual('rev2', checkout_e.last_revision())
 
@@ -465,7 +451,7 @@
         tree_a = self.make_branch_and_tree('a')
         rev_id = tree_a.commit('put some content in the branch')
         # open the branch via a readonly transport
-        source_branch = bzrlib.branch.Branch.open(self.get_readonly_url('a'))
+        source_branch = _mod_branch.Branch.open(self.get_readonly_url('a'))
         # sanity check that the test will be valid
         self.assertRaises((errors.LockError, errors.TransportNotPossible),
             source_branch.lock_write)
@@ -477,7 +463,7 @@
         tree_a = self.make_branch_and_tree('a')
         rev_id = tree_a.commit('put some content in the branch')
         # open the branch via a readonly transport
-        source_branch = bzrlib.branch.Branch.open(self.get_readonly_url('a'))
+        source_branch = _mod_branch.Branch.open(self.get_readonly_url('a'))
         # sanity check that the test will be valid
         self.assertRaises((errors.LockError, errors.TransportNotPossible),
             source_branch.lock_write)
@@ -494,7 +480,7 @@
         self.assertEquals(br.revision_history(), [])
 
 
-class TestBranchFormat(TestCaseWithBranch):
+class TestBranchFormat(per_branch.TestCaseWithBranch):
 
     def test_branch_format_network_name(self):
         br = self.make_branch('.')
@@ -511,12 +497,12 @@
             real_branch = br._real_branch
             self.assertEqual(real_branch._format.network_name(), network_name)
         else:
-            registry = branch.network_format_registry
+            registry = _mod_branch.network_format_registry
             looked_up_format = registry.get(network_name)
             self.assertEqual(format.__class__, looked_up_format.__class__)
 
 
-class ChrootedTests(TestCaseWithBranch):
+class ChrootedTests(per_branch.TestCaseWithBranch):
     """A support class that provides readonly urls outside the local namespace.
 
     This is done by checking if self.transport_server is a MemoryServer. if it
@@ -530,14 +516,18 @@
             self.transport_readonly_server = HttpServer
 
     def test_open_containing(self):
-        self.assertRaises(NotBranchError, Branch.open_containing,
+        self.assertRaises(errors.NotBranchError,
+                          _mod_branch.Branch.open_containing,
                           self.get_readonly_url(''))
-        self.assertRaises(NotBranchError, Branch.open_containing,
+        self.assertRaises(errors.NotBranchError,
+                          _mod_branch.Branch.open_containing,
                           self.get_readonly_url('g/p/q'))
         branch = self.make_branch('.')
-        branch, relpath = Branch.open_containing(self.get_readonly_url(''))
+        branch, relpath = _mod_branch.Branch.open_containing(
+            self.get_readonly_url(''))
         self.assertEqual('', relpath)
-        branch, relpath = Branch.open_containing(self.get_readonly_url('g/p/q'))
+        branch, relpath = _mod_branch.Branch.open_containing(
+            self.get_readonly_url('g/p/q'))
         self.assertEqual('g/p/q', relpath)
 
 
@@ -564,24 +554,24 @@
     def unlock(self):
         self._calls.append('ul')
 
-    @needs_read_lock
+    @_mod_branch.needs_read_lock
     def do_with_read(self):
         return 1
 
-    @needs_read_lock
+    @_mod_branch.needs_read_lock
     def except_with_read(self):
         raise RuntimeError
 
-    @needs_write_lock
+    @_mod_branch.needs_write_lock
     def do_with_write(self):
         return 2
 
-    @needs_write_lock
+    @_mod_branch.needs_write_lock
     def except_with_write(self):
         raise RuntimeError
 
 
-class TestDecorators(TestCase):
+class TestDecorators(tests.TestCase):
 
     def test_needs_read_lock(self):
         branch = TestDecorator()
@@ -604,7 +594,7 @@
         self.assertEqual(['lw', 'ul'], branch._calls)
 
 
-class TestBranchPushLocations(TestCaseWithBranch):
+class TestBranchPushLocations(per_branch.TestCaseWithBranch):
 
     def test_get_push_location_unset(self):
         self.assertEqual(None, self.get_branch().get_push_location())
@@ -625,7 +615,7 @@
         self.assertEqual('foo', branch.get_push_location())
 
 
-class TestChildSubmitFormats(TestCaseWithBranch):
+class TestChildSubmitFormats(per_branch.TestCaseWithBranch):
 
     def test_get_child_submit_format_default(self):
         self.assertEqual(None, self.get_branch().get_child_submit_format())
@@ -637,7 +627,7 @@
         self.assertEqual('10', branch.get_child_submit_format())
 
 
-class TestFormat(TestCaseWithBranch):
+class TestFormat(per_branch.TestCaseWithBranch):
     """Tests for the format itself."""
 
     def test_get_reference(self):
@@ -677,10 +667,10 @@
             # they may not be initializable.
             return
         # supported formats must be able to init and open
-        t = get_transport(self.get_url())
-        readonly_t = get_transport(self.get_readonly_url())
+        t = transport.get_transport(self.get_url())
+        readonly_t = transport.get_transport(self.get_readonly_url())
         made_branch = self.make_branch('.')
-        self.failUnless(isinstance(made_branch, branch.Branch))
+        self.failUnless(isinstance(made_branch, _mod_branch.Branch))
 
         # find it via bzrdir opening:
         opened_control = bzrdir.BzrDir.open(readonly_t.base)
@@ -691,7 +681,7 @@
                         self.branch_format.__class__))
 
         # find it via Branch.open
-        opened_branch = branch.Branch.open(readonly_t.base)
+        opened_branch = _mod_branch.Branch.open(readonly_t.base)
         self.failUnless(isinstance(opened_branch, made_branch.__class__))
         self.assertEqual(made_branch._format.__class__,
                          opened_branch._format.__class__)
@@ -704,7 +694,7 @@
                          opened_control.find_branch_format())
 
 
-class TestBound(TestCaseWithBranch):
+class TestBound(per_branch.TestCaseWithBranch):
 
     def test_bind_unbind(self):
         branch = self.make_branch('1')
@@ -742,14 +732,14 @@
             raise tests.TestNotApplicable('Format does not support binding')
 
 
-class TestStrict(TestCaseWithBranch):
+class TestStrict(per_branch.TestCaseWithBranch):
 
     def test_strict_history(self):
         tree1 = self.make_branch_and_tree('tree1')
         try:
             tree1.branch.set_append_revisions_only(True)
         except errors.UpgradeRequired:
-            raise TestSkipped('Format does not support strict history')
+            raise tests.TestSkipped('Format does not support strict history')
         tree1.commit('empty commit')
         tree2 = tree1.bzrdir.sprout('tree2').open_workingtree()
         tree2.commit('empty commit 2')
@@ -767,7 +757,7 @@
         tree2.pull(tree3.branch)
 
 
-class TestIgnoreFallbacksParameter(TestCaseWithBranch):
+class TestIgnoreFallbacksParameter(per_branch.TestCaseWithBranch):
 
     def make_branch_with_fallback(self):
         fallback = self.make_branch('fallback')
@@ -789,7 +779,7 @@
         self.assertLength(1, reopened.repository._fallback_repositories)
 
 
-class TestReferenceLocation(TestCaseWithBranch):
+class TestReferenceLocation(per_branch.TestCaseWithBranch):
 
     def test_reference_parent(self):
         tree = self.make_branch_and_tree('tree')
@@ -797,7 +787,7 @@
         subtree.set_root_id('subtree-id')
         try:
             tree.add_reference(subtree)
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Tree cannot hold references.')
         reference_parent = tree.branch.reference_parent('subtree-id',
                                                         'subtree')
@@ -809,7 +799,7 @@
         subtree.set_root_id('subtree-id')
         try:
             tree.add_reference(subtree)
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Tree cannot hold references.')
         reference_parent = tree.branch.reference_parent('subtree-id',
             'subtree', possible_transports=[subtree.bzrdir.root_transport])
@@ -818,7 +808,7 @@
         branch = self.make_branch('branch')
         try:
             path, loc = branch.get_reference_info('file-id')
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         self.assertIs(None, path)
         self.assertIs(None, loc)
@@ -828,7 +818,7 @@
         try:
             branch.set_reference_info('file-id', 'path/to/location',
                                       'path/to/file')
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
 
     def test_set_get_reference_info(self):
@@ -836,10 +826,10 @@
         try:
             branch.set_reference_info('file-id', 'path/to/file',
                                       'path/to/location')
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         # Create a new instance to ensure storage is permanent
-        branch = Branch.open('branch')
+        branch = _mod_branch.Branch.open('branch')
         tree_path, branch_location = branch.get_reference_info('file-id')
         self.assertEqual('path/to/location', branch_location)
 
@@ -848,7 +838,7 @@
         try:
             branch.set_reference_info('file-id', 'path/to/file',
                                       'path/to/location')
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         branch.set_reference_info('file-id', None, None)
         tree_path, branch_location = branch.get_reference_info('file-id')
@@ -859,7 +849,7 @@
         branch = self.make_branch('branch')
         try:
             tree_path, branch_location = branch.get_reference_info('file-id')
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         self.assertIs(None, tree_path)
         self.assertIs(None, branch_location)
@@ -870,7 +860,7 @@
         try:
             e = self.assertRaises(ValueError, branch.set_reference_info,
                                   'file-id', 'path', None)
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         self.assertEqual('tree_path must be None when branch_location is'
                          ' None.', str(e))
@@ -885,7 +875,7 @@
         try:
             branch.set_reference_info(file_id, 'path/to/file',
                                       reference_location)
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         return branch
 
@@ -901,7 +891,7 @@
         try:
             branch.set_reference_info('file-id', 'path/to/file',
             '../reference_branch')
-        except bzrlib.errors.UnsupportedOperation:
+        except errors.UnsupportedOperation:
             raise tests.TestNotApplicable('Branch cannot hold references.')
         referenced_branch = self.make_branch('reference_branch')
         parent = branch.reference_parent('file-id', 'path/to/file')

=== modified file 'bzrlib/tests/per_branch/test_break_lock.py'
--- bzrlib/tests/per_branch/test_break_lock.py	2010-01-25 17:48:22 +0000
+++ bzrlib/tests/per_branch/test_break_lock.py	2010-02-08 08:41:38 +0000
@@ -16,17 +16,15 @@
 
 """Tests for branch break-lock behaviour."""
 
-from cStringIO import StringIO
-
 from  bzrlib import (
     errors,
     ui,
+    tests,
     )
-from bzrlib.tests import TestCase, TestCaseWithTransport, TestNotApplicable
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestBreakLock(TestCaseWithBranch):
+from bzrlib.tests import per_branch
+
+
+class TestBreakLock(per_branch.TestCaseWithBranch):
 
     def setUp(self):
         super(TestBreakLock, self).setUp()
@@ -46,12 +44,14 @@
         token = self.branch.repository.lock_write()
         if token is None:
             self.branch.repository.unlock()
-            raise TestNotApplicable('Repository does not use physical locks.')
+            raise tests.TestNotApplicable(
+                'Repository does not use physical locks.')
         self.branch.repository.leave_lock_in_place()
         self.branch.repository.unlock()
         other_instance = self.branch.repository.bzrdir.open_repository()
         if not other_instance.get_physical_lock_status():
-            raise TestNotApplicable("Repository does not lock persistently.")
+            raise tests.TestNotApplicable(
+                'Repository does not lock persistently.')
         ui.ui_factory = ui.CannedInputUIFactory([True])
         try:
             self.unused_branch.break_lock()

=== modified file 'bzrlib/tests/per_branch/test_commit.py'
--- bzrlib/tests/per_branch/test_commit.py	2009-07-10 05:49:34 +0000
+++ bzrlib/tests/per_branch/test_commit.py	2010-02-08 08:42:18 +0000
@@ -16,19 +16,21 @@
 
 """Tests for the contract of commit on branches."""
 
-from bzrlib.branch import Branch
-from bzrlib import errors
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-from bzrlib.revision import NULL_REVISION
-from bzrlib.transport import get_transport
-from bzrlib.delta import TreeDelta
-
-
-class TestCommit(TestCaseWithBranch):
+from bzrlib import (
+    branch,
+    delta,
+    errors,
+    revision,
+    transport,
+    )
+from bzrlib.tests import per_branch
+
+
+class TestCommit(per_branch.TestCaseWithBranch):
 
     def test_commit_nicks(self):
         """Nicknames are committed to the revision"""
-        get_transport(self.get_url()).mkdir('bzr.dev')
+        transport.get_transport(self.get_url()).mkdir('bzr.dev')
         wt = self.make_branch_and_tree('bzr.dev')
         branch = wt.branch
         branch.nick = "My happy branch"
@@ -38,11 +40,11 @@
                          "My happy branch")
 
 
-class TestCommitHook(TestCaseWithBranch):
+class TestCommitHook(per_branch.TestCaseWithBranch):
 
     def setUp(self):
         self.hook_calls = []
-        TestCaseWithBranch.setUp(self)
+        super(TestCommitHook, self).setUp()
 
     def capture_post_commit_hook(self, local, master, old_revno,
         old_revid, new_revno, new_revid):
@@ -68,16 +70,16 @@
 
     def test_post_commit_to_origin(self):
         tree = self.make_branch_and_memory_tree('branch')
-        Branch.hooks.install_named_hook('post_commit',
-            self.capture_post_commit_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_commit', self.capture_post_commit_hook, None)
         tree.lock_write()
         tree.add('')
         revid = tree.commit('a revision')
         # should have had one notification, from origin, and
         # have the branch locked at notification time.
         self.assertEqual([
-            ('post_commit', None, tree.branch.base, 0, NULL_REVISION, 1, revid,
-             None, True)
+            ('post_commit', None, tree.branch.base, 0, revision.NULL_REVISION,
+             1, revid, None, True)
             ],
             self.hook_calls)
         tree.unlock()
@@ -90,15 +92,15 @@
         except errors.UpgradeRequired:
             # cant bind this format, the test is irrelevant.
             return
-        Branch.hooks.install_named_hook('post_commit',
-            self.capture_post_commit_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_commit', self.capture_post_commit_hook, None)
         tree.lock_write()
         tree.add('')
         revid = tree.commit('a revision')
         # with a bound branch, local is set.
         self.assertEqual([
-            ('post_commit', tree.branch.base, master.base, 0, NULL_REVISION,
-             1, revid, True, True)
+            ('post_commit', tree.branch.base, master.base, 0,
+             revision.NULL_REVISION, 1, revid, True, True)
             ],
             self.hook_calls)
         tree.unlock()
@@ -108,8 +110,8 @@
         tree.lock_write()
         tree.add('')
         revid = tree.commit('first revision')
-        Branch.hooks.install_named_hook('post_commit',
-            self.capture_post_commit_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_commit', self.capture_post_commit_hook, None)
         revid2 = tree.commit('second revision')
         # having committed from up the branch, we should get the
         # before and after revnos and revids correctly.
@@ -121,26 +123,26 @@
         tree.unlock()
 
     def test_pre_commit_passes(self):
-        empty_delta = TreeDelta()
-        root_delta = TreeDelta()
+        empty_delta = delta.TreeDelta()
+        root_delta = delta.TreeDelta()
         tree = self.make_branch_and_memory_tree('branch')
         tree.lock_write()
         tree.add('')
         root_delta.added = [('', tree.path2id(''), 'directory')]
-        Branch.hooks.install_named_hook("pre_commit",
-            self.capture_pre_commit_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            "pre_commit", self.capture_pre_commit_hook, None)
         revid1 = tree.commit('first revision')
         revid2 = tree.commit('second revision')
         self.assertEqual([
-            ('pre_commit', 0, NULL_REVISION, 1, revid1, root_delta),
+            ('pre_commit', 0, revision.NULL_REVISION, 1, revid1, root_delta),
             ('pre_commit', 1, revid1, 2, revid2, empty_delta)
             ],
             self.hook_calls)
         tree.unlock()
 
     def test_pre_commit_fails(self):
-        empty_delta = TreeDelta()
-        root_delta = TreeDelta()
+        empty_delta = delta.TreeDelta()
+        root_delta = delta.TreeDelta()
         tree = self.make_branch_and_memory_tree('branch')
         tree.lock_write()
         tree.add('')
@@ -150,9 +152,9 @@
                       old_revno, old_revid, new_revno, new_revid,
                       tree_delta, future_tree):
             raise PreCommitException(new_revid)
-        Branch.hooks.install_named_hook("pre_commit",
-            self.capture_pre_commit_hook, None)
-        Branch.hooks.install_named_hook("pre_commit", hook_func, None)
+        branch.Branch.hooks.install_named_hook(
+            "pre_commit", self.capture_pre_commit_hook, None)
+        branch.Branch.hooks.install_named_hook("pre_commit", hook_func, None)
         revids = [None, None, None]
         # this commit will raise an exception
         # so the commit is rolled back and revno unchanged
@@ -160,16 +162,16 @@
         # we have to record the revid to use in assertEqual later
         revids[0] = str(err)
         # unregister all pre_commit hooks
-        Branch.hooks["pre_commit"] = []
+        branch.Branch.hooks["pre_commit"] = []
         # and re-register the capture hook
-        Branch.hooks.install_named_hook("pre_commit",
-            self.capture_pre_commit_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            "pre_commit", self.capture_pre_commit_hook, None)
         # now these commits should go through
         for i in range(1, 3):
             revids[i] = tree.commit('message')
         self.assertEqual([
-            ('pre_commit', 0, NULL_REVISION, 1, revids[0], root_delta),
-            ('pre_commit', 0, NULL_REVISION, 1, revids[1], root_delta),
+            ('pre_commit', 0, revision.NULL_REVISION, 1, revids[0], root_delta),
+            ('pre_commit', 0, revision.NULL_REVISION, 1, revids[1], root_delta),
             ('pre_commit', 1, revids[1], 2, revids[2], empty_delta)
             ],
             self.hook_calls)
@@ -202,13 +204,13 @@
             tree.unversion(['to_be_unversioned_id'])
             tree.mkdir('added_dir', 'added_dir_id')
             # start to capture pre_commit delta
-            Branch.hooks.install_named_hook("pre_commit",
-                self.capture_pre_commit_hook, None)
+            branch.Branch.hooks.install_named_hook(
+                "pre_commit", self.capture_pre_commit_hook, None)
             revid2 = tree.commit('second revision')
         finally:
             tree.unlock()
 
-        expected_delta = TreeDelta()
+        expected_delta = delta.TreeDelta()
         expected_delta.added = [('added_dir', 'added_dir_id', 'directory')]
         expected_delta.removed = [('to_be_unversioned',
                                    'to_be_unversioned_id', 'directory')]

=== modified file 'bzrlib/tests/per_branch/test_create_checkout.py'
--- bzrlib/tests/per_branch/test_create_checkout.py	2009-07-10 05:49:34 +0000
+++ bzrlib/tests/per_branch/test_create_checkout.py	2010-02-08 08:43:01 +0000
@@ -19,11 +19,10 @@
 from bzrlib import (
     branch,
     )
-from bzrlib.remote import RemoteBranch
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestCreateCheckout(TestCaseWithBranch):
+from bzrlib.tests import per_branch
+
+
+class TestCreateCheckout(per_branch.TestCaseWithBranch):
 
     def test_checkout_format(self):
         """Make sure the new checkout uses the desired branch format."""

=== modified file 'bzrlib/tests/per_branch/test_create_clone.py'
--- bzrlib/tests/per_branch/test_create_clone.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/per_branch/test_create_clone.py	2010-02-08 08:44:42 +0000
@@ -16,14 +16,16 @@
 
 """Tests for branch.create_clone behaviour."""
 
-from bzrlib.branch import Branch
-from bzrlib import errors
-from bzrlib import remote
-from bzrlib import tests
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestCreateClone(TestCaseWithBranch):
+from bzrlib import (
+    branch,
+    errors,
+    remote,
+    tests,
+    )
+from bzrlib.tests import per_branch
+
+
+class TestCreateClone(per_branch.TestCaseWithBranch):
 
     def test_create_clone_on_transport_missing_parent_dir(self):
         tree = self.make_branch_and_tree('source')
@@ -129,8 +131,8 @@
         source = tree.branch
         target_transport = self.get_transport('target')
         self.hook_calls = []
-        Branch.hooks.install_named_hook("pre_change_branch_tip",
-            self.assertBranchHookBranchIsStacked, None)
+        branch.Branch.hooks.install_named_hook(
+            'pre_change_branch_tip', self.assertBranchHookBranchIsStacked, None)
         result = tree.branch.create_clone_on_transport(target_transport,
             stacked_on=trunk.base)
         self.assertEqual(revid, result.last_revision())

=== modified file 'bzrlib/tests/per_branch/test_hooks.py'
--- bzrlib/tests/per_branch/test_hooks.py	2010-01-08 05:28:17 +0000
+++ bzrlib/tests/per_branch/test_hooks.py	2010-02-05 14:06:57 +0000
@@ -16,15 +16,17 @@
 
 """Tests that branch classes implement hook callouts correctly."""
 
-from bzrlib.branch import Branch, ChangeBranchTipParams
-from bzrlib.errors import HookFailed, TipChangeRejected
-from bzrlib.remote import RemoteBranch
-from bzrlib.revision import NULL_REVISION
+from bzrlib import (
+    branch as _mod_branch,
+    errors,
+    remote,
+    revision,
+    tests,
+    )
 from bzrlib.smart import server
-from bzrlib.tests import TestCaseWithMemoryTransport
-
-
-class ChangeBranchTipTestCase(TestCaseWithMemoryTransport):
+
+
+class ChangeBranchTipTestCase(tests.TestCaseWithMemoryTransport):
     """Base TestCase for testing pre/post_change_branch_tip hooks."""
 
     def install_logging_hook(self, prefix):
@@ -33,7 +35,7 @@
         :returns: the list that the calls will be appended to.
         """
         hook_calls = []
-        Branch.hooks.install_named_hook(
+        _mod_branch.Branch.hooks.install_named_hook(
             prefix + '_change_branch_tip', hook_calls.append, None)
         return hook_calls
 
@@ -53,7 +55,7 @@
         pre=False):
         if hook_calls is None:
             hook_calls = self.hook_calls
-        if isinstance(branch, RemoteBranch):
+        if isinstance(branch, remote.RemoteBranch):
             # For a remote branch, both the server and the client will raise
             # this hook, and we see both in the test environment. The remote
             # instance comes in between the clients - the client doe pre, the
@@ -72,7 +74,7 @@
 
     def setUp(self):
         self.hook_calls = []
-        TestCaseWithMemoryTransport.setUp(self)
+        super(TestSetRevisionHistoryHook, self).setUp()
 
     def capture_set_rh_hook(self, branch, rev_history):
         """Capture post set-rh hook calls to self.hook_calls.
@@ -84,8 +86,8 @@
 
     def test_set_rh_empty_history(self):
         branch = self.make_branch('source')
-        Branch.hooks.install_named_hook('set_rh', self.capture_set_rh_hook,
-                                        None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'set_rh', self.capture_set_rh_hook, None)
         branch.set_revision_history([])
         expected_params = ('set_rh', branch, [], True)
         self.assertHookCalls(expected_params, branch)
@@ -98,8 +100,8 @@
         tree.commit('empty commit', rev_id='foo')
         tree.unlock()
         branch = tree.branch
-        Branch.hooks.install_named_hook('set_rh', self.capture_set_rh_hook,
-                                        None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'set_rh', self.capture_set_rh_hook, None)
         # some branches require that their history be set to a revision in the
         # repository
         branch.set_revision_history(['f\xc2\xb5'])
@@ -108,23 +110,23 @@
 
     def test_set_rh_branch_is_locked(self):
         branch = self.make_branch('source')
-        Branch.hooks.install_named_hook('set_rh', self.capture_set_rh_hook,
-                                        None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'set_rh', self.capture_set_rh_hook, None)
         branch.set_revision_history([])
         expected_params = ('set_rh', branch, [], True)
         self.assertHookCalls(expected_params, branch)
 
     def test_set_rh_calls_all_hooks_no_errors(self):
         branch = self.make_branch('source')
-        Branch.hooks.install_named_hook('set_rh', self.capture_set_rh_hook,
-                                        None)
-        Branch.hooks.install_named_hook('set_rh', self.capture_set_rh_hook,
-                                        None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'set_rh', self.capture_set_rh_hook, None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'set_rh', self.capture_set_rh_hook, None)
         branch.set_revision_history([])
         expected_calls = [('set_rh', branch, [], True),
             ('set_rh', branch, [], True),
             ]
-        if isinstance(branch, RemoteBranch):
+        if isinstance(branch, remote.RemoteBranch):
             # For a remote branch, both the server and the client will raise
             # set_rh, and the server will do so first because that is where
             # the change takes place.
@@ -134,19 +136,20 @@
             self.assertEqual(expected_calls, self.hook_calls)
 
 
-class TestOpen(TestCaseWithMemoryTransport):
+class TestOpen(tests.TestCaseWithMemoryTransport):
 
     def capture_hook(self, branch):
         self.hook_calls.append(branch)
 
     def install_hook(self):
         self.hook_calls = []
-        Branch.hooks.install_named_hook('open', self.capture_hook, None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'open', self.capture_hook, None)
 
     def test_create(self):
         self.install_hook()
         b = self.make_branch('.')
-        if isinstance(b, RemoteBranch):
+        if isinstance(b, remote.RemoteBranch):
             # RemoteBranch creation:
             if (self.transport_readonly_server ==
                 server.ReadonlySmartTCPServer_for_testing_v2_only):
@@ -170,8 +173,8 @@
     def test_open(self):
         branch_url = self.make_branch('.').bzrdir.root_transport.base
         self.install_hook()
-        b = Branch.open(branch_url)
-        if isinstance(b, RemoteBranch):
+        b = _mod_branch.Branch.open(branch_url)
+        if isinstance(b, remote.RemoteBranch):
             self.assertEqual(3, len(self.hook_calls))
             # open_branchV2 RPC
             self.assertRealBranch(self.hook_calls[0])
@@ -185,8 +188,8 @@
     def assertRealBranch(self, b):
         # Branches opened on the server don't have comparable URLs, so we just
         # assert that it is not a RemoteBranch.
-        self.assertIsInstance(b, Branch)
-        self.assertFalse(isinstance(b, RemoteBranch))
+        self.assertIsInstance(b, _mod_branch.Branch)
+        self.assertFalse(isinstance(b, remote.RemoteBranch))
 
 
 class TestPreChangeBranchTip(ChangeBranchTipTestCase):
@@ -203,9 +206,9 @@
         def assertBranchAtRevision1(params):
             self.assertEquals(
                 (1, 'revid-one'), params.branch.last_revision_info())
-        Branch.hooks.install_named_hook(
+        _mod_branch.Branch.hooks.install_named_hook(
             'pre_change_branch_tip', assertBranchAtRevision1, None)
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
 
     def test_hook_failure_prevents_change(self):
         """If a hook raises an exception, the change does not take effect."""
@@ -215,19 +218,20 @@
             pass
         def hook_that_raises(params):
             raise PearShapedError()
-        Branch.hooks.install_named_hook(
+        _mod_branch.Branch.hooks.install_named_hook(
             'pre_change_branch_tip', hook_that_raises, None)
         hook_failed_exc = self.assertRaises(
-            PearShapedError, branch.set_last_revision_info, 0, NULL_REVISION)
+            PearShapedError,
+            branch.set_last_revision_info, 0, revision.NULL_REVISION)
         # The revision info is unchanged.
         self.assertEqual((2, 'two-\xc2\xb5'), branch.last_revision_info())
 
     def test_empty_history(self):
         branch = self.make_branch('source')
         hook_calls = self.install_logging_hook('pre')
-        branch.set_last_revision_info(0, NULL_REVISION)
-        expected_params = ChangeBranchTipParams(
-            branch, 0, 0, NULL_REVISION, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
+        expected_params = _mod_branch.ChangeBranchTipParams(
+            branch, 0, 0, revision.NULL_REVISION, revision.NULL_REVISION)
         self.assertHookCalls(expected_params, branch, hook_calls, pre=True)
 
     def test_nonempty_history(self):
@@ -238,7 +242,7 @@
             'one-\xc2\xb5', 'two-\xc2\xb5')
         hook_calls = self.install_logging_hook('pre')
         branch.set_last_revision_info(1, 'one-\xc2\xb5')
-        expected_params = ChangeBranchTipParams(
+        expected_params = _mod_branch.ChangeBranchTipParams(
             branch, 2, 1, 'two-\xc2\xb5', 'one-\xc2\xb5')
         self.assertHookCalls(expected_params, branch, hook_calls, pre=True)
 
@@ -246,9 +250,9 @@
         branch = self.make_branch('source')
         def assertBranchIsLocked(params):
             self.assertTrue(params.branch.is_locked())
-        Branch.hooks.install_named_hook(
+        _mod_branch.Branch.hooks.install_named_hook(
             'pre_change_branch_tip', assertBranchIsLocked, None)
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
 
     def test_calls_all_hooks_no_errors(self):
         """If multiple hooks are registered, all are called (if none raise
@@ -258,9 +262,9 @@
         hook_calls_1 = self.install_logging_hook('pre')
         hook_calls_2 = self.install_logging_hook('pre')
         self.assertIsNot(hook_calls_1, hook_calls_2)
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
         # Both hooks are called.
-        if isinstance(branch, RemoteBranch):
+        if isinstance(branch, remote.RemoteBranch):
             count = 2
         else:
             count = 1
@@ -275,11 +279,12 @@
         branch = self.make_branch_with_revision_ids(
             'one-\xc2\xb5', 'two-\xc2\xb5')
         def hook_that_rejects(params):
-            raise TipChangeRejected('rejection message')
-        Branch.hooks.install_named_hook(
+            raise errors.TipChangeRejected('rejection message')
+        _mod_branch.Branch.hooks.install_named_hook(
             'pre_change_branch_tip', hook_that_rejects, None)
         self.assertRaises(
-            TipChangeRejected, branch.set_last_revision_info, 0, NULL_REVISION)
+            errors.TipChangeRejected,
+            branch.set_last_revision_info, 0, revision.NULL_REVISION)
         # The revision info is unchanged.
         self.assertEqual((2, 'two-\xc2\xb5'), branch.last_revision_info())
 
@@ -297,17 +302,17 @@
         branch = self.make_branch_with_revision_ids('revid-one')
         def assertBranchAtRevision1(params):
             self.assertEquals(
-                (0, NULL_REVISION), params.branch.last_revision_info())
-        Branch.hooks.install_named_hook(
+                (0, revision.NULL_REVISION), params.branch.last_revision_info())
+        _mod_branch.Branch.hooks.install_named_hook(
             'post_change_branch_tip', assertBranchAtRevision1, None)
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
 
     def test_empty_history(self):
         branch = self.make_branch('source')
         hook_calls = self.install_logging_hook('post')
-        branch.set_last_revision_info(0, NULL_REVISION)
-        expected_params = ChangeBranchTipParams(
-            branch, 0, 0, NULL_REVISION, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
+        expected_params = _mod_branch.ChangeBranchTipParams(
+            branch, 0, 0, revision.NULL_REVISION, revision.NULL_REVISION)
         self.assertHookCalls(expected_params, branch, hook_calls)
 
     def test_nonempty_history(self):
@@ -318,7 +323,7 @@
             'one-\xc2\xb5', 'two-\xc2\xb5')
         hook_calls = self.install_logging_hook('post')
         branch.set_last_revision_info(1, 'one-\xc2\xb5')
-        expected_params = ChangeBranchTipParams(
+        expected_params = _mod_branch.ChangeBranchTipParams(
             branch, 2, 1, 'two-\xc2\xb5', 'one-\xc2\xb5')
         self.assertHookCalls(expected_params, branch, hook_calls)
 
@@ -327,9 +332,9 @@
         branch = self.make_branch('source')
         def assertBranchIsLocked(params):
             self.assertTrue(params.branch.is_locked())
-        Branch.hooks.install_named_hook(
+        _mod_branch.Branch.hooks.install_named_hook(
             'post_change_branch_tip', assertBranchIsLocked, None)
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
 
     def test_calls_all_hooks_no_errors(self):
         """If multiple hooks are registered, all are called (if none raise
@@ -339,9 +344,9 @@
         hook_calls_1 = self.install_logging_hook('post')
         hook_calls_2 = self.install_logging_hook('post')
         self.assertIsNot(hook_calls_1, hook_calls_2)
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
         # Both hooks are called.
-        if isinstance(branch, RemoteBranch):
+        if isinstance(branch, remote.RemoteBranch):
             count = 2
         else:
             count = 1
@@ -373,7 +378,7 @@
         """
         # Check for the number of invocations expected. One invocation is
         # local, one is remote (if the branch is remote).
-        if smart_enabled and isinstance(branch, RemoteBranch):
+        if smart_enabled and isinstance(branch, remote.RemoteBranch):
             length = 2
         else:
             length = 1
@@ -387,12 +392,12 @@
 
     def test_set_last_revision_info(self):
         branch = self.make_branch('')
-        branch.set_last_revision_info(0, NULL_REVISION)
+        branch.set_last_revision_info(0, revision.NULL_REVISION)
         self.assertPreAndPostHooksWereInvoked(branch, True)
 
     def test_generate_revision_history(self):
         branch = self.make_branch('')
-        branch.generate_revision_history(NULL_REVISION)
+        branch.generate_revision_history(revision.NULL_REVISION)
         # NB: for HPSS protocols < v3, the server does not invoke branch tip
         # change events on generate_revision_history, as the change is done
         # directly by the client over the VFS.

=== modified file 'bzrlib/tests/per_branch/test_http.py'
--- bzrlib/tests/per_branch/test_http.py	2009-07-10 10:46:00 +0000
+++ bzrlib/tests/per_branch/test_http.py	2010-02-08 08:46:32 +0000
@@ -16,16 +16,18 @@
 
 """Test branches with inaccessible parents."""
 
-import os
-
-from bzrlib import branch, errors
-from bzrlib.tests.http_server import HttpServer
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-from bzrlib.transport.local import LocalURLServer
-from bzrlib.transport.chroot import TestingChrootServer
-
-
-class InaccessibleParentTests(TestCaseWithBranch):
+from bzrlib import (
+    branch,
+    errors,
+    )
+from bzrlib.tests import per_branch
+from bzrlib.transport import (
+    chroot,
+    local,
+    )
+
+
+class InaccessibleParentTests(per_branch.TestCaseWithBranch):
     """Tests with branches with "inaccessible" parents.
 
     An "inaccessible" parent location is one that cannot be represented, e.g. if
@@ -36,8 +38,8 @@
 
     def setUp(self):
         super(InaccessibleParentTests, self).setUp()
-        if self.transport_server in (LocalURLServer, None):
-            self.transport_readonly_server = TestingChrootServer
+        if self.transport_server in (local.LocalURLServer, None):
+            self.transport_readonly_server = chroot.TestingChrootServer
 
     def get_branch_with_invalid_parent(self):
         """Get a branch whose get_parent will raise InaccessibleParent."""

=== modified file 'bzrlib/tests/per_branch/test_locking.py'
--- bzrlib/tests/per_branch/test_locking.py	2009-10-15 02:11:18 +0000
+++ bzrlib/tests/per_branch/test_locking.py	2010-02-08 08:50:26 +0000
@@ -16,18 +16,21 @@
 
 """Test locks across all branch implemenations"""
 
-from bzrlib import errors
-from bzrlib.branch import BzrBranchFormat4
-from bzrlib.bzrdir import RemoteBzrDirFormat
-from bzrlib.tests import TestSkipped
-from bzrlib.tests.lock_helpers import TestPreventLocking, LockWrapper
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestBranchLocking(TestCaseWithBranch):
+from bzrlib import (
+    branch as _mod_branch,
+    errors,
+    tests,
+    )
+from bzrlib.tests import (
+    lock_helpers,
+    per_branch,
+    )
+
+
+class TestBranchLocking(per_branch.TestCaseWithBranch):
 
     def setUp(self):
-        TestCaseWithBranch.setUp(self)
+        super(TestBranchLocking, self).setUp()
         self.reduceLockdirTimeout()
 
     def get_instrumented_branch(self):
@@ -37,8 +40,8 @@
         # not there. But assuming it has them lets us test the exact
         # lock/unlock order.
         self.locks = []
-        b = LockWrapper(self.locks, self.get_branch(), 'b')
-        b.repository = LockWrapper(self.locks, b.repository, 'r')
+        b = lock_helpers.LockWrapper(self.locks, self.get_branch(), 'b')
+        b.repository = lock_helpers.LockWrapper(self.locks, b.repository, 'r')
         bcf = b.control_files
         rcf = getattr(b.repository, 'control_files', None)
         if rcf is None:
@@ -47,16 +50,18 @@
             # Look out for branch types that reuse their control files
             self.combined_control = bcf is rcf
         try:
-            b.control_files = LockWrapper(self.locks, b.control_files, 'bc')
+            b.control_files = lock_helpers.LockWrapper(
+                self.locks, b.control_files, 'bc')
         except AttributeError:
             # RemoteBranch seems to trigger this.
-            raise TestSkipped("Could not instrument branch control files.")
+            raise tests.TestSkipped(
+                'Could not instrument branch control files.')
         if self.combined_control:
             # instrument the repository control files too to ensure its worked
             # with correctly. When they are not shared, we trust the repository
             # API and only instrument the repository itself.
-            b.repository.control_files = \
-                LockWrapper(self.locks, b.repository.control_files, 'rc')
+            b.repository.control_files = lock_helpers.LockWrapper(
+                self.locks, b.repository.control_files, 'rc')
         return b
 
     def test_01_lock_read(self):
@@ -139,7 +144,7 @@
         try:
             self.assertTrue(b.is_locked())
             self.assertTrue(b.repository.is_locked())
-            self.assertLogsError(TestPreventLocking, b.unlock)
+            self.assertLogsError(lock_helpers.TestPreventLocking, b.unlock)
             if self.combined_control:
                 self.assertTrue(b.is_locked())
             else:
@@ -183,7 +188,7 @@
         try:
             self.assertTrue(b.is_locked())
             self.assertTrue(b.repository.is_locked())
-            self.assertLogsError(TestPreventLocking, b.unlock)
+            self.assertLogsError(lock_helpers.TestPreventLocking, b.unlock)
             self.assertTrue(b.is_locked())
             self.assertTrue(b.repository.is_locked())
 
@@ -216,7 +221,7 @@
         b = self.get_instrumented_branch()
         b.repository.disable_lock_read()
 
-        self.assertRaises(TestPreventLocking, b.lock_read)
+        self.assertRaises(lock_helpers.TestPreventLocking, b.lock_read)
         self.assertFalse(b.is_locked())
         self.assertFalse(b.repository.is_locked())
 
@@ -229,7 +234,7 @@
         b = self.get_instrumented_branch()
         b.repository.disable_lock_write()
 
-        self.assertRaises(TestPreventLocking, b.lock_write)
+        self.assertRaises(lock_helpers.TestPreventLocking, b.lock_write)
         self.assertFalse(b.is_locked())
         self.assertFalse(b.repository.is_locked())
 
@@ -242,7 +247,7 @@
         b = self.get_instrumented_branch()
         b.control_files.disable_lock_read()
 
-        self.assertRaises(TestPreventLocking, b.lock_read)
+        self.assertRaises(lock_helpers.TestPreventLocking, b.lock_read)
         self.assertFalse(b.is_locked())
         self.assertFalse(b.repository.is_locked())
 
@@ -266,7 +271,7 @@
         b = self.get_instrumented_branch()
         b.control_files.disable_lock_write()
 
-        self.assertRaises(TestPreventLocking, b.lock_write)
+        self.assertRaises(lock_helpers.TestPreventLocking, b.lock_write)
         self.assertFalse(b.is_locked())
         self.assertFalse(b.repository.is_locked())
         if self.combined_control:
@@ -493,7 +498,7 @@
         branch.unlock()
 
     def test_lock_write_locks_repo_too(self):
-        if isinstance(self.branch_format, BzrBranchFormat4):
+        if isinstance(self.branch_format, _mod_branch.BzrBranchFormat4):
             # Branch format 4 is combined with the repository, so this test
             # doesn't apply.
             return

=== modified file 'bzrlib/tests/per_branch/test_pull.py'
--- bzrlib/tests/per_branch/test_pull.py	2009-07-10 05:49:34 +0000
+++ bzrlib/tests/per_branch/test_pull.py	2010-02-08 08:55:09 +0000
@@ -18,15 +18,17 @@
 
 import os
 
-from bzrlib.branch import Branch, BzrBranchFormat5
-from bzrlib.bzrdir import BzrDir
-from bzrlib import errors
-from bzrlib.memorytree import MemoryTree
-from bzrlib.revision import NULL_REVISION
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestPull(TestCaseWithBranch):
+from bzrlib import (
+    branch,
+    bzrdir,
+    errors,
+    memorytree,
+    revision,
+    )
+from bzrlib.tests import per_branch
+
+
+class TestPull(per_branch.TestCaseWithBranch):
 
     def test_pull_convergence_simple(self):
         # when revisions are pulled, the left-most accessible parents must
@@ -145,11 +147,11 @@
                          tree_a.branch.revision_history())
 
 
-class TestPullHook(TestCaseWithBranch):
+class TestPullHook(per_branch.TestCaseWithBranch):
 
     def setUp(self):
         self.hook_calls = []
-        TestCaseWithBranch.setUp(self)
+        super(TestPullHook, self).setUp()
 
     def capture_post_pull_hook(self, result):
         """Capture post pull hook calls to self.hook_calls.
@@ -173,14 +175,14 @@
     def test_post_pull_empty_history(self):
         target = self.make_branch('target')
         source = self.make_branch('source')
-        Branch.hooks.install_named_hook('post_pull',
-            self.capture_post_pull_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_pull', self.capture_post_pull_hook, None)
         target.pull(source)
         # with nothing there we should still get a notification, and
         # have both branches locked at the notification time.
         self.assertEqual([
-            ('post_pull', source, None, target.base, 0, NULL_REVISION,
-             0, NULL_REVISION, True, None, True)
+            ('post_pull', source, None, target.base, 0, revision.NULL_REVISION,
+             0, revision.NULL_REVISION, True, None, True)
             ],
             self.hook_calls)
 
@@ -199,17 +201,18 @@
             # remotebranches can't be bound.  Let's instead make a new local
             # branch of the default type, which does allow binding.
             # See https://bugs.launchpad.net/bzr/+bug/112020
-            local = BzrDir.create_branch_convenience('local2')
+            local = bzrdir.BzrDir.create_branch_convenience('local2')
             local.bind(target)
         source = self.make_branch('source')
-        Branch.hooks.install_named_hook('post_pull',
-            self.capture_post_pull_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_pull', self.capture_post_pull_hook, None)
         local.pull(source)
         # with nothing there we should still get a notification, and
         # have both branches locked at the notification time.
         self.assertEqual([
-            ('post_pull', source, local.base, target.base, 0, NULL_REVISION,
-             0, NULL_REVISION, True, True, True)
+            ('post_pull', source, local.base, target.base, 0,
+             revision.NULL_REVISION, 0, revision.NULL_REVISION,
+             True, True, True)
             ],
             self.hook_calls)
 
@@ -220,10 +223,10 @@
         rev1 = target.commit('rev 1')
         target.unlock()
         sourcedir = target.bzrdir.clone(self.get_url('source'))
-        source = MemoryTree.create_on_branch(sourcedir.open_branch())
+        source = memorytree.MemoryTree.create_on_branch(sourcedir.open_branch())
         rev2 = source.commit('rev 2')
-        Branch.hooks.install_named_hook('post_pull',
-            self.capture_post_pull_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_pull', self.capture_post_pull_hook, None)
         target.branch.pull(source.branch)
         # with nothing there we should still get a notification, and
         # have both branches locked at the notification time.

=== modified file 'bzrlib/tests/per_branch/test_push.py'
--- bzrlib/tests/per_branch/test_push.py	2010-01-25 17:48:22 +0000
+++ bzrlib/tests/per_branch/test_push.py	2010-02-08 09:02:01 +0000
@@ -26,22 +26,23 @@
     check,
     debug,
     errors,
+    memorytree,
     push,
     repository,
+    revision,
     tests,
-    )
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
-from bzrlib.memorytree import MemoryTree
-from bzrlib.revision import NULL_REVISION
-from bzrlib.smart import client, server
-from bzrlib.smart.repository import SmartServerRepositoryGetParentMap
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-from bzrlib.transport import get_transport
-from bzrlib.transport.local import LocalURLServer
-
-
-class TestPush(TestCaseWithBranch):
+    transport,
+    )
+from bzrlib.smart import (
+    client,
+    server,
+    repository as _mod_smart_repo,
+    )
+from bzrlib.tests import per_branch
+from bzrlib.transport import local
+
+
+class TestPush(per_branch.TestCaseWithBranch):
 
     def test_push_convergence_simple(self):
         # when revisions are pushed, the left-most accessible parents must
@@ -148,10 +149,11 @@
         try:
             tree = a_branch.bzrdir.create_workingtree()
         except errors.NotLocalUrl:
-            if self.vfs_transport_factory is LocalURLServer:
+            if self.vfs_transport_factory is local.LocalURLServer:
                 # the branch is colocated on disk, we cannot create a checkout.
                 # hopefully callers will expect this.
-                local_controldir= bzrdir.BzrDir.open(self.get_vfs_only_url('repo/tree'))
+                local_controldir= bzrdir.BzrDir.open(
+                    self.get_vfs_only_url('repo/tree'))
                 tree = local_controldir.create_workingtree()
             else:
                 tree = a_branch.create_checkout('repo/tree', lightweight=True)
@@ -223,7 +225,7 @@
         push._show_push_branch(trunk, 'rev-2', self.get_url('remote'), output)
         # Push rev-3 onto "remote".  If "remote" not stacked and is missing the
         # fulltext record for f-id @ rev-1, then this will fail.
-        remote_branch = Branch.open(self.get_url('remote'))
+        remote_branch = branch.Branch.open(self.get_url('remote'))
         trunk.push(remote_branch)
         check.check_dwim(remote_branch.base, False, True, True)
 
@@ -277,15 +279,15 @@
         # for or receiving more data than the caller asked for.
         self.overrideAttr(repository.InterRepository,
                           '_walk_to_common_revisions_batch_size', 1)
-        self.overrideAttr(SmartServerRepositoryGetParentMap,
+        self.overrideAttr(_mod_smart_repo.SmartServerRepositoryGetParentMap,
                           'no_extra_results', True)
 
 
-class TestPushHook(TestCaseWithBranch):
+class TestPushHook(per_branch.TestCaseWithBranch):
 
     def setUp(self):
         self.hook_calls = []
-        TestCaseWithBranch.setUp(self)
+        super(TestPushHook, self).setUp()
 
     def capture_post_push_hook(self, result):
         """Capture post push hook calls to self.hook_calls.
@@ -309,14 +311,14 @@
     def test_post_push_empty_history(self):
         target = self.make_branch('target')
         source = self.make_branch('source')
-        Branch.hooks.install_named_hook('post_push',
-                                        self.capture_post_push_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_push', self.capture_post_push_hook, None)
         source.push(target)
         # with nothing there we should still get a notification, and
         # have both branches locked at the notification time.
         self.assertEqual([
-            ('post_push', source, None, target.base, 0, NULL_REVISION,
-             0, NULL_REVISION, True, None, True)
+            ('post_push', source, None, target.base, 0, revision.NULL_REVISION,
+             0, revision.NULL_REVISION, True, None, True)
             ],
             self.hook_calls)
 
@@ -335,17 +337,18 @@
             # remotebranches can't be bound.  Let's instead make a new local
             # branch of the default type, which does allow binding.
             # See https://bugs.launchpad.net/bzr/+bug/112020
-            local = BzrDir.create_branch_convenience('local2')
+            local = bzrdir.BzrDir.create_branch_convenience('local2')
             local.bind(target)
         source = self.make_branch('source')
-        Branch.hooks.install_named_hook('post_push',
-                                        self.capture_post_push_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_push', self.capture_post_push_hook, None)
         source.push(local)
         # with nothing there we should still get a notification, and
         # have both branches locked at the notification time.
         self.assertEqual([
-            ('post_push', source, local.base, target.base, 0, NULL_REVISION,
-             0, NULL_REVISION, True, True, True)
+            ('post_push', source, local.base, target.base, 0,
+             revision.NULL_REVISION, 0, revision.NULL_REVISION,
+             True, True, True)
             ],
             self.hook_calls)
 
@@ -356,10 +359,10 @@
         rev1 = target.commit('rev 1')
         target.unlock()
         sourcedir = target.bzrdir.clone(self.get_url('source'))
-        source = MemoryTree.create_on_branch(sourcedir.open_branch())
+        source = memorytree.MemoryTree.create_on_branch(sourcedir.open_branch())
         rev2 = source.commit('rev 2')
-        Branch.hooks.install_named_hook('post_push',
-                                        self.capture_post_push_hook, None)
+        branch.Branch.hooks.install_named_hook(
+            'post_push', self.capture_post_push_hook, None)
         source.branch.push(target.branch)
         # with nothing there we should still get a notification, and
         # have both branches locked at the notification time.
@@ -370,7 +373,7 @@
             self.hook_calls)
 
 
-class EmptyPushSmartEffortTests(TestCaseWithBranch):
+class EmptyPushSmartEffortTests(per_branch.TestCaseWithBranch):
     """Tests that a push of 0 revisions should make a limited number of smart
     protocol RPCs.
     """
@@ -404,8 +407,8 @@
     def test_empty_branch_api(self):
         """The branch_obj.push API should make a limited number of HPSS calls.
         """
-        transport = get_transport(self.smart_server.get_url()).clone('target')
-        target = Branch.open_from_transport(transport)
+        t = transport.get_transport(self.smart_server.get_url()).clone('target')
+        target = branch.Branch.open_from_transport(t)
         self.empty_branch.push(target)
         self.assertEqual(
             ['BzrDir.open_2.1',
@@ -432,11 +435,11 @@
         self.assertTrue(len(self.hpss_calls) <= 9, self.hpss_calls)
 
 
-class TestLossyPush(TestCaseWithBranch):
+class TestLossyPush(per_branch.TestCaseWithBranch):
 
     def setUp(self):
         self.hook_calls = []
-        TestCaseWithBranch.setUp(self)
+        super(TestLossyPush, self).setUp()
 
     def test_lossy_push_raises_same_vcs(self):
         target = self.make_branch('target')

=== modified file 'bzrlib/tests/per_branch/test_revision_history.py'
--- bzrlib/tests/per_branch/test_revision_history.py	2009-07-10 05:49:34 +0000
+++ bzrlib/tests/per_branch/test_revision_history.py	2010-02-08 09:02:33 +0000
@@ -21,10 +21,10 @@
     errors,
     revision as _mod_revision,
     )
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestLastRevision(TestCaseWithBranch):
+from bzrlib.tests import per_branch
+
+
+class TestLastRevision(per_branch.TestCaseWithBranch):
     """Tests for the last_revision property of the branch.
     """
 
@@ -47,7 +47,7 @@
         ##         br.set_last_revision_info, 4, 'current:')
 
 
-class TestRevisionHistoryCaching(TestCaseWithBranch):
+class TestRevisionHistoryCaching(per_branch.TestCaseWithBranch):
     """Tests for the caching of branches' revision_history.
 
     When locked, branches should avoid regenerating or rereading
@@ -201,7 +201,7 @@
             branch.unlock()
 
 
-class TestRevisionHistory(TestCaseWithBranch):
+class TestRevisionHistory(per_branch.TestCaseWithBranch):
 
     def test_parent_ghost(self):
         tree = self.make_branch_and_tree('tree')

=== modified file 'bzrlib/tests/per_branch/test_tags.py'
--- bzrlib/tests/per_branch/test_tags.py	2009-07-10 10:46:00 +0000
+++ bzrlib/tests/per_branch/test_tags.py	2010-02-08 09:05:43 +0000
@@ -20,29 +20,26 @@
 1:1 with Branch implementations so can be tested from here.
 """
 
-import os
-import re
-import sys
-
-import bzrlib
-from bzrlib import bzrdir, errors, repository
-from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
-from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
-from bzrlib.trace import mutter
-from bzrlib.workingtree import WorkingTree
-
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-
-
-class TestBranchTags(TestCaseWithBranch):
+from bzrlib import (
+    branch,
+    bzrdir,
+    errors,
+    repository,
+    tests,
+    )
+from bzrlib.tests import per_branch
+
+
+class TestBranchTags(per_branch.TestCaseWithBranch):
 
     def setUp(self):
-        TestCaseWithBranch.setUp(self)
+        super(TestBranchTags, self).setUp()
         # formats that don't support tags can skip the rest of these
         # tests...
         branch = self.make_branch('probe')
         if not branch._format.supports_tags():
-            raise TestSkipped("format %s doesn't support tags" % branch._format)
+            raise tests.TestSkipped(
+                "format %s doesn't support tags" % branch._format)
 
     def test_tags_initially_empty(self):
         b = self.make_branch('b')
@@ -54,7 +51,7 @@
         b.tags.set_tag('tag-name', 'target-revid-1')
         b.tags.set_tag('other-name', 'target-revid-2')
         # then reopen the branch and see they're still there
-        b = Branch.open('b')
+        b = branch.Branch.open('b')
         self.assertEqual(b.tags.get_tag_dict(),
             {'tag-name': 'target-revid-1',
              'other-name': 'target-revid-2',
@@ -71,7 +68,7 @@
         b.tags.set_tag('tag-name', 'target-revid-1')
         b.tags.set_tag('other-name', 'target-revid-2')
         # then reopen the branch and check reverse map id->tags list
-        b = Branch.open('b')
+        b = branch.Branch.open('b')
         self.assertEqual(b.tags.get_reverse_tag_dict(),
             {'target-revid-1': ['tag-name'],
              'target-revid-2': ['other-name'],
@@ -147,15 +144,15 @@
         b1.tags.merge_to(b2.tags)
 
 
-class TestUnsupportedTags(TestCaseWithBranch):
+class TestUnsupportedTags(per_branch.TestCaseWithBranch):
     """Formats that don't support tags should give reasonable errors."""
 
     def setUp(self):
-        TestCaseWithBranch.setUp(self)
+        super(TestUnsupportedTags, self).setUp()
         branch = self.make_branch('probe')
         if branch._format.supports_tags():
-            raise TestSkipped("Format %s declares that tags are supported"
-                              % branch._format)
+            raise tests.TestSkipped("Format %s declares that tags are supported"
+                                    % branch._format)
             # it's covered by TestBranchTags
 
     def test_tag_methods_raise(self):

=== modified file 'bzrlib/tests/per_branch/test_uncommit.py'
--- bzrlib/tests/per_branch/test_uncommit.py	2009-07-10 05:49:34 +0000
+++ bzrlib/tests/per_branch/test_uncommit.py	2010-02-08 09:08:31 +0000
@@ -19,17 +19,19 @@
 Note that uncommit currently is not a branch method; it should be.
 """
 
-from bzrlib.branch import Branch
-from bzrlib import errors
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
-from bzrlib.uncommit import uncommit
-
-
-class TestUncommitHook(TestCaseWithBranch):
+from bzrlib import (
+    branch,
+    errors,
+    uncommit,
+    )
+from bzrlib.tests import per_branch
+
+
+class TestUncommitHook(per_branch.TestCaseWithBranch):
 
     def setUp(self):
         self.hook_calls = []
-        TestCaseWithBranch.setUp(self)
+        super(TestUncommitHook, self).setUp()
 
     def capture_post_uncommit_hook(self, local, master, old_revno,
         old_revid, new_revno, new_revid):
@@ -53,9 +55,9 @@
         tree.add('')
         revid = tree.commit('a revision')
         tree.unlock()
-        Branch.hooks.install_named_hook('post_uncommit',
+        branch.Branch.hooks.install_named_hook('post_uncommit',
             self.capture_post_uncommit_hook, None)
-        uncommit(tree.branch)
+        uncommit.uncommit(tree.branch)
         # with nothing left we should still get a notification, and
         # have the branch locked at notification time.
         self.assertEqual([
@@ -76,9 +78,9 @@
         tree.add('')
         revid = tree.commit('a revision')
         tree.unlock()
-        Branch.hooks.install_named_hook('post_uncommit',
-            self.capture_post_uncommit_hook, None)
-        uncommit(tree.branch)
+        branch.Branch.hooks.install_named_hook(
+            'post_uncommit', self.capture_post_uncommit_hook, None)
+        uncommit.uncommit(tree.branch)
         # with nothing left we should still get a notification, and
         # have the branch locked at notification time.
         self.assertEqual([
@@ -95,9 +97,9 @@
         revid2 = tree.commit('second revision')
         revid3 = tree.commit('third revision')
         tree.unlock()
-        Branch.hooks.install_named_hook('post_uncommit',
-            self.capture_post_uncommit_hook, None)
-        uncommit(tree.branch, revno=2)
+        branch.Branch.hooks.install_named_hook(
+            'post_uncommit', self.capture_post_uncommit_hook, None)
+        uncommit.uncommit(tree.branch, revno=2)
         # having uncommitted from up the branch, we should get the
         # before and after revnos and revids correctly.
         self.assertEqual([

=== modified file 'bzrlib/tests/per_branch/test_update.py'
--- bzrlib/tests/per_branch/test_update.py	2009-07-10 05:49:34 +0000
+++ bzrlib/tests/per_branch/test_update.py	2010-02-08 09:11:54 +0000
@@ -19,13 +19,13 @@
     errors,
     revision as _mod_revision,
     )
-from bzrlib.tests.per_branch.test_branch import TestCaseWithBranch
+from bzrlib.tests import per_branch
 
 
 """Tests for branch.update()"""
 
 
-class TestUpdate(TestCaseWithBranch):
+class TestUpdate(per_branch.TestCaseWithBranch):
 
     def test_update_unbound_works(self):
         b = self.make_branch('.')
@@ -69,7 +69,7 @@
         self.assertEqual(['bar'], child_tree.branch.revision_history())
 
 
-class TestUpdateRevisions(TestCaseWithBranch):
+class TestUpdateRevisions(per_branch.TestCaseWithBranch):
 
     def test_accepts_graph(self):
         # An implementation may not use it, but it should allow a 'graph' to be

=== modified file 'bzrlib/tests/per_repository/test_break_lock.py'
--- bzrlib/tests/per_repository/test_break_lock.py	2010-01-25 17:48:22 +0000
+++ bzrlib/tests/per_repository/test_break_lock.py	2010-02-08 09:19:33 +0000
@@ -16,17 +16,14 @@
 
 """Tests for repository break-lock."""
 
-from cStringIO import StringIO
-
 from bzrlib import (
     errors,
     ui,
     )
-from bzrlib.tests.per_repository.test_repository import TestCaseWithRepository
-from bzrlib.workingtree import WorkingTree
-
-
-class TestBreakLock(TestCaseWithRepository):
+from bzrlib.tests import per_repository
+
+
+class TestBreakLock(per_repository.TestCaseWithRepository):
 
     def setUp(self):
         super(TestBreakLock, self).setUp()

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2009-11-19 15:06:47 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2010-02-08 09:20:42 +0000
@@ -16,24 +16,21 @@
 
 """Tests for repository commit builder."""
 
-from copy import copy
-import errno
 import os
-import sys
 
 from bzrlib import (
     errors,
+    graph,
     inventory,
     osutils,
     repository,
     revision as _mod_revision,
     tests,
     )
-from bzrlib.graph import Graph
-from bzrlib.tests.per_repository import test_repository
-
-
-class TestCommitBuilder(test_repository.TestCaseWithRepository):
+from bzrlib.tests import per_repository
+
+
+class TestCommitBuilder(per_repository.TestCaseWithRepository):
 
     def test_get_commit_builder(self):
         branch = self.make_branch('.')
@@ -924,8 +921,8 @@
         # (closest to a public per-file graph API we have today)
         tree.lock_read()
         self.addCleanup(tree.unlock)
-        graph = dict(Graph(tree.branch.repository.texts).iter_ancestry([tip]))
-        self.assertEqual(expected_graph, graph)
+        g = dict(graph.Graph(tree.branch.repository.texts).iter_ancestry([tip]))
+        self.assertEqual(expected_graph, g)
 
     def test_last_modified_revision_after_content_file_changes(self):
         # altering a file changes the last modified.

=== modified file 'bzrlib/tests/per_repository/test_fileid_involved.py'
--- bzrlib/tests/per_repository/test_fileid_involved.py	2009-09-09 02:14:12 +0000
+++ bzrlib/tests/per_repository/test_fileid_involved.py	2010-02-08 09:23:42 +0000
@@ -14,7 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import os
 import sys
 import time
 
@@ -23,15 +22,12 @@
     remote,
     revision as _mod_revision,
     tests,
+    transform,
     )
-from bzrlib.errors import IllegalPath, NonAsciiRevisionId
-from bzrlib.tests import TestSkipped
-from bzrlib.tests.per_repository.test_repository import TestCaseWithRepository
-from bzrlib.transform import TreeTransform
-from bzrlib.workingtree import WorkingTree
-
-
-class FileIdInvolvedBase(TestCaseWithRepository):
+from bzrlib.tests import per_repository
+
+
+class FileIdInvolvedBase(per_repository.TestCaseWithRepository):
 
     def touch(self, tree, filename):
         # use the trees transport to not depend on the tree's location or type.
@@ -81,13 +77,13 @@
                                  'c-funky<file-id>quiji%bo'])
         try:
             main_wt.commit("Commit one", rev_id="rev-A")
-        except IllegalPath:
+        except errors.IllegalPath:
             # TODO: jam 20060701 Consider raising a different exception
             #       newer formats do support this, and nothin can done to
             #       correct this test - its not a bug.
             if sys.platform == 'win32':
-                raise TestSkipped('Old repository formats do not'
-                                  ' support file ids with <> on win32')
+                raise tests.TestSkipped('Old repository formats do not'
+                                        ' support file ids with <> on win32')
             # This is not a known error condition
             raise
 
@@ -243,9 +239,9 @@
         revision_id = u'r\xe9v-a'.encode('utf8')
         try:
             main_wt.commit('a', rev_id=revision_id)
-        except NonAsciiRevisionId:
-            raise TestSkipped('non-ascii revision ids not supported by %s'
-                              % self.repository_format)
+        except errors.NonAsciiRevisionId:
+            raise tests.TestSkipped('non-ascii revision ids not supported by %s'
+                                    % self.repository_format)
 
         repo = main_wt.branch.repository
         repo.lock_read()
@@ -275,13 +271,13 @@
                                  'c-funky<file-id>quiji\'"%bo'])
         try:
             main_wt.commit("Commit one", rev_id="rev-A")
-        except IllegalPath:
+        except errors.IllegalPath:
             # TODO: jam 20060701 Consider raising a different exception
             #       newer formats do support this, and nothin can done to
             #       correct this test - its not a bug.
             if sys.platform == 'win32':
-                raise TestSkipped('Old repository formats do not'
-                                  ' support file ids with <> on win32')
+                raise tests.TestSkipped('Old repository formats do not'
+                                        ' support file ids with <> on win32')
             # This is not a known error condition
             raise
 
@@ -320,7 +316,7 @@
         self.assertSubset(l2, l1)
 
 
-class FileIdInvolvedWGhosts(TestCaseWithRepository):
+class FileIdInvolvedWGhosts(per_repository.TestCaseWithRepository):
 
     def create_branch_with_ghost_text(self):
         builder = self.make_branch_builder('ghost')
@@ -352,7 +348,7 @@
         if isinstance(repo, remote.RemoteRepository):
             # We can't easily disable the checks in a remote repo.
             repo.abort_write_group()
-            raise TestSkipped(
+            raise tests.TestSkipped(
                 "repository format does not support storing revisions with "
                 "missing texts.")
         pack_coll = getattr(repo, '_pack_collection', None)
@@ -408,7 +404,7 @@
     unmark a file as executable.
     """
     file_id = wt.path2id(path)
-    tt = TreeTransform(wt)
+    tt = transform.TreeTransform(wt)
     try:
         tt.set_executability(executable, tt.trans_id_tree_file_id(file_id))
         tt.apply()

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2009-11-11 22:46:53 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2010-02-05 14:36:54 +0000
@@ -19,45 +19,36 @@
 from cStringIO import StringIO
 import re
 
-import bzrlib
 from bzrlib import (
+    branch as _mod_branch,
     bzrdir,
+    delta as _mod_delta,
     errors,
     gpg,
     graph,
     info,
+    inventory,
     osutils,
     remote,
     repository,
+    revision as _mod_revision,
+    tests,
+    transport,
+    upgrade,
+    versionedfile,
+    workingtree,
     xml_serializer,
     )
-from bzrlib.branch import BzrBranchFormat6
-from bzrlib.delta import TreeDelta
-from bzrlib.inventory import CommonInventory, Inventory, InventoryDirectory
-from bzrlib.repofmt.pack_repo import (
-    RepositoryFormatKnitPack5RichRootBroken,
-    )
-from bzrlib.repofmt.weaverepo import (
-    RepositoryFormat5,
-    RepositoryFormat6,
-    RepositoryFormat7,
-    )
-from bzrlib.revision import NULL_REVISION, Revision
+from bzrlib.repofmt import (
+    pack_repo,
+    weaverepo,
+    )
 from bzrlib.smart import server
-from bzrlib.tests import (
-    KnownFailure,
-    TestCaseWithTransport,
-    TestNotApplicable,
-    TestSkipped,
-    )
-from bzrlib.tests.per_repository import TestCaseWithRepository
-from bzrlib.transport import get_transport
+from bzrlib.tests import per_repository
 from bzrlib.transport.fakevfat import FakeVFATServer
-from bzrlib.upgrade import upgrade
-from bzrlib.workingtree import WorkingTree
-
-
-class TestRepositoryMakeBranchAndTree(TestCaseWithRepository):
+
+
+class TestRepositoryMakeBranchAndTree(per_repository.TestCaseWithRepository):
 
     def test_repository_format(self):
         # make sure the repository on tree.branch is of the desired format,
@@ -69,7 +60,7 @@
             self.repository_format.__class__)
 
 
-class TestRepository(TestCaseWithRepository):
+class TestRepository(per_repository.TestCaseWithRepository):
 
     def assertFormatAttribute(self, attribute, allowed_values):
         """Assert that the format has an attribute 'attribute'."""
@@ -99,8 +90,7 @@
         """Test the existence of the inventories attribute."""
         tree = self.make_branch_and_tree('tree')
         repo = tree.branch.repository
-        self.assertIsInstance(repo.inventories,
-            bzrlib.versionedfile.VersionedFiles)
+        self.assertIsInstance(repo.inventories, versionedfile.VersionedFiles)
 
     def test_attribute_inventories_basics(self):
         """Test basic aspects of the inventories attribute."""
@@ -116,7 +106,7 @@
         tree = self.make_branch_and_tree('tree')
         repo = tree.branch.repository
         self.assertIsInstance(repo.revisions,
-            bzrlib.versionedfile.VersionedFiles)
+            versionedfile.VersionedFiles)
 
     def test_attribute_revision_store_basics(self):
         """Test the basic behaviour of the revisions attribute."""
@@ -150,7 +140,7 @@
         tree = self.make_branch_and_tree('tree')
         repo = tree.branch.repository
         self.assertIsInstance(repo.signatures,
-            bzrlib.versionedfile.VersionedFiles)
+            versionedfile.VersionedFiles)
 
     def test_attribute_text_store_basics(self):
         """Test the basic behaviour of the text store."""
@@ -166,7 +156,8 @@
             try:
                 rev_key = (tree.commit("foo"),)
             except errors.IllegalPath:
-                raise TestNotApplicable('file_id %r cannot be stored on this'
+                raise tests.TestNotApplicable(
+                    'file_id %r cannot be stored on this'
                     ' platform for this repo format' % (file_id,))
             if repo._format.rich_root_data:
                 root_commit = (tree.get_root_id(),) + rev_key
@@ -212,7 +203,7 @@
         tree = self.make_branch_and_tree('tree')
         repo = tree.branch.repository
         self.assertIsInstance(repo.texts,
-            bzrlib.versionedfile.VersionedFiles)
+            versionedfile.VersionedFiles)
 
     def test_exposed_versioned_files_are_marked_dirty(self):
         repo = self.make_repository('.')
@@ -261,7 +252,7 @@
         invs = tree.branch.repository.iter_inventories(revs)
         for rev_id, inv in zip(revs, invs):
             self.assertEqual(rev_id, inv.revision_id)
-            self.assertIsInstance(inv, CommonInventory)
+            self.assertIsInstance(inv, inventory.CommonInventory)
 
     def test_supports_rich_root(self):
         tree = self.make_branch_and_tree('a')
@@ -286,8 +277,8 @@
             # they may not be initializable.
             return
         # supported formats must be able to init and open
-        t = get_transport(self.get_url())
-        readonly_t = get_transport(self.get_readonly_url())
+        t = transport.get_transport(self.get_url())
+        readonly_t = transport.get_transport(self.get_readonly_url())
         made_control = self.bzrdir_format.initialize(t.base)
         made_repo = self.repository_format.initialize(made_control)
         self.assertEqual(made_control, made_repo.bzrdir)
@@ -346,7 +337,7 @@
             # because the default open will not open them and
             # they may not be initializable.
             return
-        t = get_transport(self.get_url())
+        t = transport.get_transport(self.get_url())
         made_control = self.bzrdir_format.initialize(t.base)
         made_repo = made_control.create_repository()
         # Check that we have a repository object.
@@ -360,7 +351,7 @@
             # because the default open will not open them and
             # they may not be initializable.
             return
-        t = get_transport(self.get_url())
+        t = transport.get_transport(self.get_url())
         made_control = self.bzrdir_format.initialize(t.base)
         try:
             made_repo = made_control.create_repository(shared=True)
@@ -381,7 +372,7 @@
         tree.lock_read()
         try:
             self.assertEqual('revision-1', tree.inventory.root.revision)
-            expected = InventoryDirectory('fixed-root', '', None)
+            expected = inventory.InventoryDirectory('fixed-root', '', None)
             expected.revision = 'revision-1'
             self.assertEqual([('', 'V', 'directory', 'fixed-root', expected)],
                              list(tree.list_files(include_root=True)))
@@ -395,7 +386,7 @@
             self.assertEqual([], list(tree.list_files(include_root=True)))
         finally:
             tree.unlock()
-        tree = wt.branch.repository.revision_tree(NULL_REVISION)
+        tree = wt.branch.repository.revision_tree(_mod_revision.NULL_REVISION)
         tree.lock_read()
         try:
             self.assertEqual([], list(tree.list_files(include_root=True)))
@@ -412,10 +403,10 @@
         tree_a.commit('rev2', rev_id='rev2')
 
         delta = tree_a.branch.repository.get_revision_delta('rev1')
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([('foo', 'file1', 'file')], delta.added)
         delta = tree_a.branch.repository.get_revision_delta('rev2')
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([('vla', 'file2', 'file')], delta.added)
 
     def test_get_revision_delta_filtered(self):
@@ -431,7 +422,7 @@
         # Test multiple files
         delta = tree_a.branch.repository.get_revision_delta('rev1',
             specific_fileids=['foo-id', 'baz-id'])
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([
             ('baz', 'baz-id', 'file'),
             ('foo', 'foo-id', 'file'),
@@ -439,7 +430,7 @@
         # Test a directory
         delta = tree_a.branch.repository.get_revision_delta('rev1',
             specific_fileids=['bar-id'])
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([
             ('bar', 'bar-id', 'directory'),
             ('bar/b1', 'b1-id', 'file'),
@@ -448,7 +439,7 @@
         # Test a file in a directory
         delta = tree_a.branch.repository.get_revision_delta('rev1',
             specific_fileids=['b2-id'])
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([
             ('bar', 'bar-id', 'directory'),
             ('bar/b2', 'b2-id', 'file'),
@@ -456,24 +447,25 @@
         # Try another revision
         delta = tree_a.branch.repository.get_revision_delta('rev2',
                 specific_fileids=['b3-id'])
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([
             ('bar', 'bar-id', 'directory'),
             ('bar/b3', 'b3-id', 'file'),
             ], delta.added)
         delta = tree_a.branch.repository.get_revision_delta('rev2',
                 specific_fileids=['foo-id'])
-        self.assertIsInstance(delta, TreeDelta)
+        self.assertIsInstance(delta, _mod_delta.TreeDelta)
         self.assertEqual([], delta.added)
 
     def test_clone_bzrdir_repository_revision(self):
         # make a repository with some revisions,
         # and clone it, this should not have unreferenced revisions.
         # also: test cloning with a revision id of NULL_REVISION -> empty repo.
-        raise TestSkipped('revision limiting is not implemented yet.')
+        raise tests.TestSkipped('revision limiting is not implemented yet.')
 
     def test_clone_repository_basis_revision(self):
-        raise TestSkipped('the use of a basis should not add noise data to the result.')
+        raise tests.TestSkipped(
+            'the use of a basis should not add noise data to the result.')
 
     def test_clone_shared_no_tree(self):
         # cloning a shared repository keeps it shared
@@ -514,13 +506,13 @@
             # This gives metadir branches something they can convert to.
             # it would be nice to have a 'latest' vs 'default' concept.
             format = bzrdir.format_registry.make_bzrdir('dirstate-with-subtree')
-            upgrade(repo.bzrdir.root_transport.base, format=format)
+            upgrade.upgrade(repo.bzrdir.root_transport.base, format=format)
         except errors.UpToDateFormat:
             # this is in the most current format already.
             return
         except errors.BadConversionTarget, e:
-            raise TestSkipped(str(e))
-        wt = WorkingTree.open(wt.basedir)
+            raise tests.TestSkipped(str(e))
+        wt = workingtree.WorkingTree.open(wt.basedir)
         new_signature = wt.branch.repository.get_signature_text('A')
         self.assertEqual(old_signature, new_signature)
 
@@ -608,16 +600,16 @@
             return # local conversion to/from RemoteObjects is irrelevant.
         if self.repository_format.get_format_description() \
             == "Repository format 4":
-            raise TestSkipped('Cannot convert format-4 to itself')
+            raise tests.TestSkipped('Cannot convert format-4 to itself')
         self.build_tree_contents(_upgrade_dir_template)
-        old_repodir = bzrlib.bzrdir.BzrDir.open_unsupported('.')
+        old_repodir = bzrdir.BzrDir.open_unsupported('.')
         old_repo_format = old_repodir.open_repository()._format
         format = self.repository_format._matchingbzrdir
         try:
             format.repository_format = self.repository_format
         except AttributeError:
             pass
-        upgrade('.', format)
+        upgrade.upgrade('.', format)
 
     def test_pointless_commit(self):
         tree = self.make_branch_and_tree('.')
@@ -735,7 +727,8 @@
         tree.commit('initial commit', rev_id='rev1')
         tree.commit('next commit', rev_id='rev2')
         graph = tree.branch.repository.get_graph()
-        parents = graph.get_parent_map([NULL_REVISION, 'rev1', 'rev2'])
+        parents = graph.get_parent_map(
+            [_mod_revision.NULL_REVISION, 'rev1', 'rev2'])
         for value in parents.values():
             self.assertIsInstance(value, tuple)
 
@@ -763,17 +756,18 @@
         self.addCleanup(repo.unlock)
         repo.start_write_group()
         self.addCleanup(repo.abort_write_group)
-        inv = Inventory(revision_id='A')
+        inv = inventory.Inventory(revision_id='A')
         inv.root.revision = 'A'
         repo.add_inventory('A', inv, [])
-        repo.add_revision('A', Revision('A', committer='A', timestamp=0,
-                          inventory_sha1='', timezone=0, message='A'))
+        repo.add_revision('A', _mod_revision.Revision(
+                'A', committer='A', timestamp=0,
+                inventory_sha1='', timezone=0, message='A'))
         repo.add_signature_text('A', 'This might be a signature')
         self.assertEqual('This might be a signature',
                          repo.get_signature_text('A'))
 
     def test_add_revision_inventory_sha1(self):
-        inv = Inventory(revision_id='A')
+        inv = inventory.Inventory(revision_id='A')
         inv.root.revision = 'A'
         inv.root.file_id = 'fixed-root'
         # Insert the inventory on its own to an identical repository, to get
@@ -791,8 +785,9 @@
         repo.start_write_group()
         root_id = inv.root.file_id
         repo.texts.add_lines(('fixed-root', 'A'), [], [])
-        repo.add_revision('A', Revision('A', committer='B', timestamp=0,
-                          timezone=0, message='C'), inv=inv)
+        repo.add_revision('A', _mod_revision.Revision(
+                'A', committer='B', timestamp=0,
+                timezone=0, message='C'), inv=inv)
         repo.commit_write_group()
         repo.unlock()
         repo.lock_read()
@@ -827,22 +822,23 @@
         repo = self.make_repository(path, shared=shared)
         smart_server = server.SmartTCPServer_for_testing()
         self.start_server(smart_server, self.get_server())
-        remote_transport = get_transport(smart_server.get_url()).clone(path)
+        remote_transport = transport.get_transport(
+            smart_server.get_url()).clone(path)
         remote_bzrdir = bzrdir.BzrDir.open_from_transport(remote_transport)
         remote_repo = remote_bzrdir.open_repository()
         return remote_repo
 
     def test_sprout_from_hpss_preserves_format(self):
         """repo.sprout from a smart server preserves the repository format."""
-        if self.repository_format == RepositoryFormat7():
-            raise TestNotApplicable(
+        if self.repository_format == weaverepo.RepositoryFormat7():
+            raise tests.TestNotApplicable(
                 "Cannot fetch weaves over smart protocol.")
         remote_repo = self.make_remote_repository('remote')
         local_bzrdir = self.make_bzrdir('local')
         try:
             local_repo = remote_repo.sprout(local_bzrdir)
         except errors.TransportNotPossible:
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 "Cannot lock_read old formats like AllInOne over HPSS.")
         remote_backing_repo = bzrdir.BzrDir.open(
             self.get_vfs_only_url('remote')).open_repository()
@@ -851,17 +847,18 @@
     def test_sprout_branch_from_hpss_preserves_repo_format(self):
         """branch.sprout from a smart server preserves the repository format.
         """
-        weave_formats = [RepositoryFormat5(), RepositoryFormat6(),
-                         RepositoryFormat7()]
+        weave_formats = [weaverepo.RepositoryFormat5(),
+                         weaverepo.RepositoryFormat6(),
+                         weaverepo.RepositoryFormat7()]
         if self.repository_format in weave_formats:
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 "Cannot fetch weaves over smart protocol.")
         remote_repo = self.make_remote_repository('remote')
         remote_branch = remote_repo.bzrdir.create_branch()
         try:
             local_bzrdir = remote_branch.bzrdir.sprout('local')
         except errors.TransportNotPossible:
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 "Cannot lock_read old formats like AllInOne over HPSS.")
         local_repo = local_bzrdir.open_repository()
         remote_backing_repo = bzrdir.BzrDir.open(
@@ -872,10 +869,11 @@
         """branch.sprout from a smart server preserves the repository format of
         a branch from a shared repository.
         """
-        weave_formats = [RepositoryFormat5(), RepositoryFormat6(),
-                         RepositoryFormat7()]
+        weave_formats = [weaverepo.RepositoryFormat5(),
+                         weaverepo.RepositoryFormat6(),
+                         weaverepo.RepositoryFormat7()]
         if self.repository_format in weave_formats:
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 "Cannot fetch weaves over smart protocol.")
         # Make a shared repo
         remote_repo = self.make_remote_repository('remote', shared=True)
@@ -894,15 +892,16 @@
         try:
             local_bzrdir = remote_branch.bzrdir.sprout('local')
         except errors.TransportNotPossible:
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 "Cannot lock_read old formats like AllInOne over HPSS.")
         local_repo = local_bzrdir.open_repository()
         self.assertEqual(remote_backing_repo._format, local_repo._format)
 
     def test_clone_to_hpss(self):
-        pre_metadir_formats = [RepositoryFormat5(), RepositoryFormat6()]
+        pre_metadir_formats = [weaverepo.RepositoryFormat5(),
+                               weaverepo.RepositoryFormat6()]
         if self.repository_format in pre_metadir_formats:
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 "Cannot lock pre_metadir_formats remotely.")
         remote_transport = self.make_smart_server('remote')
         local_branch = self.make_branch('local')
@@ -919,18 +918,20 @@
         try:
             repo = self.make_repository('repo', shared=True)
         except errors.IncompatibleFormat:
-            raise TestNotApplicable('Cannot make a shared repository')
+            raise tests.TestNotApplicable('Cannot make a shared repository')
         if isinstance(repo.bzrdir, bzrdir.BzrDirPreSplitOut):
-            raise KnownFailure("pre metadir branches do not upgrade on push "
+            raise tests.KnownFailure(
+                "pre metadir branches do not upgrade on push "
                 "with stacking policy")
-        if isinstance(repo._format, RepositoryFormatKnitPack5RichRootBroken):
-            raise TestNotApplicable("unsupported format")
+        if isinstance(repo._format,
+                      pack_repo.RepositoryFormatKnitPack5RichRootBroken):
+            raise tests.TestNotApplicable("unsupported format")
         # Make a source branch in 'repo' in an unstackable branch format
         bzrdir_format = self.repository_format._matchingbzrdir
         transport = self.get_transport('repo/branch')
         transport.mkdir('.')
         target_bzrdir = bzrdir_format.initialize_on_transport(transport)
-        branch = BzrBranchFormat6().initialize(target_bzrdir)
+        branch = _mod_branch.BzrBranchFormat6().initialize(target_bzrdir)
         # Ensure that stack_on will be stackable and match the serializer of
         # repo.
         if isinstance(repo, remote.RemoteRepository):
@@ -1011,7 +1012,7 @@
         try:
             repo = self.make_repository_and_foo_bar(shared=True)
         except errors.IncompatibleFormat:
-            raise TestNotApplicable
+            raise tests.TestNotApplicable
         branches = repo.find_branches(using=True)
         self.assertContainsRe(branches[-1].base, 'repository/foo/$')
         # in some formats, creating a repo creates a branch
@@ -1045,7 +1046,7 @@
         try:
             repo.set_make_working_trees(True)
         except errors.RepositoryUpgradeRequired, e:
-            raise TestNotApplicable('Format does not support this flag.')
+            raise tests.TestNotApplicable('Format does not support this flag.')
         self.assertTrue(repo.make_working_trees())
 
     def test_set_get_make_working_trees_false(self):
@@ -1053,11 +1054,11 @@
         try:
             repo.set_make_working_trees(False)
         except errors.RepositoryUpgradeRequired, e:
-            raise TestNotApplicable('Format does not support this flag.')
+            raise tests.TestNotApplicable('Format does not support this flag.')
         self.assertFalse(repo.make_working_trees())
 
 
-class TestRepositoryLocking(TestCaseWithRepository):
+class TestRepositoryLocking(per_repository.TestCaseWithRepository):
 
     def test_leave_lock_in_place(self):
         repo = self.make_repository('r')
@@ -1118,7 +1119,7 @@
         repo.unlock()
 
 
-class TestCaseWithComplexRepository(TestCaseWithRepository):
+class TestCaseWithComplexRepository(per_repository.TestCaseWithRepository):
 
     def setUp(self):
         super(TestCaseWithComplexRepository, self).setUp()
@@ -1148,7 +1149,8 @@
         try:
             tree_a.commit('rev3', rev_id='rev3', allow_pointless=True)
         except errors.RevisionNotPresent:
-            raise TestNotApplicable("Cannot test with ghosts for this format.")
+            raise tests.TestNotApplicable(
+                "Cannot test with ghosts for this format.")
         # add another reference to a ghost, and a second ghost.
         tree_a.add_parent_tree_id('ghost1')
         tree_a.add_parent_tree_id('ghost2')
@@ -1208,7 +1210,7 @@
             repo.unlock()
 
 
-class TestCaseWithCorruptRepository(TestCaseWithRepository):
+class TestCaseWithCorruptRepository(per_repository.TestCaseWithRepository):
 
     def setUp(self):
         super(TestCaseWithCorruptRepository, self).setUp()
@@ -1217,36 +1219,31 @@
         repo = self.make_repository('inventory_with_unnecessary_ghost')
         repo.lock_write()
         repo.start_write_group()
-        inv = Inventory(revision_id = 'ghost')
+        inv = inventory.Inventory(revision_id = 'ghost')
         inv.root.revision = 'ghost'
         if repo.supports_rich_root():
             root_id = inv.root.file_id
             repo.texts.add_lines((root_id, 'ghost'), [], [])
         sha1 = repo.add_inventory('ghost', inv, [])
-        rev = bzrlib.revision.Revision(timestamp=0,
-                                       timezone=None,
-                                       committer="Foo Bar <foo@example.com>",
-                                       message="Message",
-                                       inventory_sha1=sha1,
-                                       revision_id='ghost')
+        rev = _mod_revision.Revision(
+            timestamp=0, timezone=None, committer="Foo Bar <foo@example.com>",
+            message="Message", inventory_sha1=sha1, revision_id='ghost')
         rev.parent_ids = ['the_ghost']
         try:
             repo.add_revision('ghost', rev)
         except (errors.NoSuchRevision, errors.RevisionNotPresent):
-            raise TestNotApplicable("Cannot test with ghosts for this format.")
+            raise tests.TestNotApplicable(
+                "Cannot test with ghosts for this format.")
 
-        inv = Inventory(revision_id = 'the_ghost')
+        inv = inventory.Inventory(revision_id = 'the_ghost')
         inv.root.revision = 'the_ghost'
         if repo.supports_rich_root():
             root_id = inv.root.file_id
             repo.texts.add_lines((root_id, 'the_ghost'), [], [])
         sha1 = repo.add_inventory('the_ghost', inv, [])
-        rev = bzrlib.revision.Revision(timestamp=0,
-                                       timezone=None,
-                                       committer="Foo Bar <foo@example.com>",
-                                       message="Message",
-                                       inventory_sha1=sha1,
-                                       revision_id='the_ghost')
+        rev = _mod_revision.Revision(
+            timestamp=0, timezone=None, committer="Foo Bar <foo@example.com>",
+            message="Message", inventory_sha1=sha1, revision_id='the_ghost')
         rev.parent_ids = []
         repo.add_revision('the_ghost', rev)
         # check its setup usefully
@@ -1279,7 +1276,7 @@
 
 # FIXME: document why this is a TestCaseWithTransport rather than a
 #        TestCaseWithRepository
-class TestEscaping(TestCaseWithTransport):
+class TestEscaping(tests.TestCaseWithTransport):
     """Test that repositories can be stored correctly on VFAT transports.
 
     Makes sure we have proper escaping of invalid characters, etc.
@@ -1293,8 +1290,7 @@
     def test_on_vfat(self):
         # dont bother with remote repository testing, because this test is
         # about local disk layout/support.
-        from bzrlib.remote import RemoteRepositoryFormat
-        if isinstance(self.repository_format, RemoteRepositoryFormat):
+        if isinstance(self.repository_format, remote.RemoteRepositoryFormat):
             return
         self.transport_server = FakeVFATServer
         FOO_ID = 'foo<:>ID'
@@ -1321,4 +1317,5 @@
         wt.add('file1')
         wt.commit('file1', rev_id='rev1')
         fileobj = StringIO()
-        wt.branch.repository.create_bundle('rev1', NULL_REVISION, fileobj)
+        wt.branch.repository.create_bundle(
+            'rev1', _mod_revision.NULL_REVISION, fileobj)

=== modified file 'bzrlib/tests/per_repository/test_write_group.py'
--- bzrlib/tests/per_repository/test_write_group.py	2009-10-15 02:11:18 +0000
+++ bzrlib/tests/per_repository/test_write_group.py	2010-02-05 14:40:22 +0000
@@ -19,21 +19,21 @@
 import sys
 
 from bzrlib import (
+    branch,
     bzrdir,
     errors,
     graph,
     memorytree,
     osutils,
     remote,
+    tests,
     versionedfile,
     )
-from bzrlib.branch import BzrBranchFormat7
 from bzrlib.transport import local, memory
-from bzrlib.tests import TestNotApplicable
-from bzrlib.tests.per_repository import TestCaseWithRepository
-
-
-class TestWriteGroup(TestCaseWithRepository):
+from bzrlib.tests import per_repository
+
+
+class TestWriteGroup(per_repository.TestCaseWithRepository):
 
     def test_start_write_group_unlocked_needs_write_lock(self):
         repo = self.make_repository('.')
@@ -131,7 +131,7 @@
         self.assertEqual(None, repo.abort_write_group(suppress_errors=True))
 
 
-class TestGetMissingParentInventories(TestCaseWithRepository):
+class TestGetMissingParentInventories(per_repository.TestCaseWithRepository):
 
     def test_empty_get_missing_parent_inventories(self):
         """A new write group has no missing parent inventories."""
@@ -183,8 +183,8 @@
         else:
             repo = self.make_repository(relpath)
         if not repo._format.supports_external_lookups:
-            raise TestNotApplicable('format not stackable')
-        repo.bzrdir._format.set_branch_format(BzrBranchFormat7())
+            raise tests.TestNotApplicable('format not stackable')
+        repo.bzrdir._format.set_branch_format(branch.BzrBranchFormat7())
         return repo
 
     def reopen_repo_and_resume_write_group(self, repo):
@@ -334,7 +334,7 @@
         repo = self.make_repository('test-repo')
         if (not repo._format.supports_external_lookups or
             isinstance(repo, remote.RemoteRepository)):
-            raise TestNotApplicable(
+            raise tests.TestNotApplicable(
                 'only valid for direct connections to resumable repos')
         # log calls to get_missing_parent_inventories, so that we can assert it
         # is called with the correct parameters
@@ -361,7 +361,7 @@
         self.assertEqual([True], call_log)
 
 
-class TestResumeableWriteGroup(TestCaseWithRepository):
+class TestResumeableWriteGroup(per_repository.TestCaseWithRepository):
 
     def make_write_locked_repo(self, relpath='repo'):
         repo = self.make_repository(relpath)
@@ -384,7 +384,7 @@
             wg_tokens = repo.suspend_write_group()
         except errors.UnsuspendableWriteGroup:
             repo.abort_write_group()
-            raise TestNotApplicable(reason)
+            raise tests.TestNotApplicable(reason)
 
     def test_suspend_write_group(self):
         repo = self.make_write_locked_repo()

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2009-09-04 13:43:21 +0000
+++ bzrlib/tests/test_branch.py	2010-02-08 09:39:51 +0000
@@ -22,88 +22,68 @@
 also see this file.
 """
 
-from StringIO import StringIO
+from cStringIO import StringIO
 
 from bzrlib import (
     branch as _mod_branch,
     bzrdir,
     config,
     errors,
+    tests,
     trace,
+    transport,
     urlutils,
     )
-from bzrlib.branch import (
-    Branch,
-    BranchHooks,
-    BranchFormat,
-    BranchReferenceFormat,
-    BzrBranch5,
-    BzrBranchFormat5,
-    BzrBranchFormat6,
-    BzrBranchFormat7,
-    PullResult,
-    _run_with_write_locked_target,
-    )
-from bzrlib.bzrdir import (BzrDirMetaFormat1, BzrDirMeta1,
-                           BzrDir, BzrDirFormat)
-from bzrlib.errors import (NotBranchError,
-                           UnknownFormatError,
-                           UnknownHook,
-                           UnsupportedFormatError,
-                           )
-
-from bzrlib.tests import TestCase, TestCaseWithTransport
-from bzrlib.transport import get_transport
-
-
-class TestDefaultFormat(TestCase):
+
+
+class TestDefaultFormat(tests.TestCase):
 
     def test_default_format(self):
         # update this if you change the default branch format
-        self.assertIsInstance(BranchFormat.get_default_format(),
-                BzrBranchFormat7)
+        self.assertIsInstance(_mod_branch.BranchFormat.get_default_format(),
+                _mod_branch.BzrBranchFormat7)
 
     def test_default_format_is_same_as_bzrdir_default(self):
         # XXX: it might be nice if there was only one place the default was
         # set, but at the moment that's not true -- mbp 20070814 --
         # https://bugs.launchpad.net/bzr/+bug/132376
-        self.assertEqual(BranchFormat.get_default_format(),
-                BzrDirFormat.get_default_format().get_branch_format())
+        self.assertEqual(
+            _mod_branch.BranchFormat.get_default_format(),
+            bzrdir.BzrDirFormat.get_default_format().get_branch_format())
 
     def test_get_set_default_format(self):
         # set the format and then set it back again
-        old_format = BranchFormat.get_default_format()
-        BranchFormat.set_default_format(SampleBranchFormat())
+        old_format = _mod_branch.BranchFormat.get_default_format()
+        _mod_branch.BranchFormat.set_default_format(SampleBranchFormat())
         try:
             # the default branch format is used by the meta dir format
             # which is not the default bzrdir format at this point
-            dir = BzrDirMetaFormat1().initialize('memory:///')
+            dir = bzrdir.BzrDirMetaFormat1().initialize('memory:///')
             result = dir.create_branch()
             self.assertEqual(result, 'A branch')
         finally:
-            BranchFormat.set_default_format(old_format)
-        self.assertEqual(old_format, BranchFormat.get_default_format())
-
-
-class TestBranchFormat5(TestCaseWithTransport):
+            _mod_branch.BranchFormat.set_default_format(old_format)
+        self.assertEqual(old_format,
+                         _mod_branch.BranchFormat.get_default_format())
+
+
+class TestBranchFormat5(tests.TestCaseWithTransport):
     """Tests specific to branch format 5"""
 
     def test_branch_format_5_uses_lockdir(self):
         url = self.get_url()
-        bzrdir = BzrDirMetaFormat1().initialize(url)
-        bzrdir.create_repository()
-        branch = bzrdir.create_branch()
+        bdir = bzrdir.BzrDirMetaFormat1().initialize(url)
+        bdir.create_repository()
+        branch = bdir.create_branch()
         t = self.get_transport()
         self.log("branch instance is %r" % branch)
-        self.assert_(isinstance(branch, BzrBranch5))
+        self.assert_(isinstance(branch, _mod_branch.BzrBranch5))
         self.assertIsDirectory('.', t)
         self.assertIsDirectory('.bzr/branch', t)
         self.assertIsDirectory('.bzr/branch/lock', t)
         branch.lock_write()
-        try:
-            self.assertIsDirectory('.bzr/branch/lock/held', t)
-        finally:
-            branch.unlock()
+        self.addCleanup(branch.unlock)
+        self.assertIsDirectory('.bzr/branch/lock/held', t)
 
     def test_set_push_location(self):
         from bzrlib.config import (locations_config_filename,
@@ -132,7 +112,7 @@
     # recursive section - that is, it appends the branch name.
 
 
-class SampleBranchFormat(BranchFormat):
+class SampleBranchFormat(_mod_branch.BranchFormat):
     """A sample format
 
     this format is initializable, unsupported to aid in testing the
@@ -156,7 +136,7 @@
         return "opened branch."
 
 
-class TestBzrBranchFormat(TestCaseWithTransport):
+class TestBzrBranchFormat(tests.TestCaseWithTransport):
     """Tests for the BzrBranchFormat facility."""
 
     def test_find_format(self):
@@ -168,21 +148,21 @@
             dir = format._matchingbzrdir.initialize(url)
             dir.create_repository()
             format.initialize(dir)
-            found_format = BranchFormat.find_format(dir)
+            found_format = _mod_branch.BranchFormat.find_format(dir)
             self.failUnless(isinstance(found_format, format.__class__))
-        check_format(BzrBranchFormat5(), "bar")
+        check_format(_mod_branch.BzrBranchFormat5(), "bar")
 
     def test_find_format_not_branch(self):
         dir = bzrdir.BzrDirMetaFormat1().initialize(self.get_url())
-        self.assertRaises(NotBranchError,
-                          BranchFormat.find_format,
+        self.assertRaises(errors.NotBranchError,
+                          _mod_branch.BranchFormat.find_format,
                           dir)
 
     def test_find_format_unknown_format(self):
         dir = bzrdir.BzrDirMetaFormat1().initialize(self.get_url())
         SampleBranchFormat().initialize(dir)
-        self.assertRaises(UnknownFormatError,
-                          BranchFormat.find_format,
+        self.assertRaises(errors.UnknownFormatError,
+                          _mod_branch.BranchFormat.find_format,
                           dir)
 
     def test_register_unregister_format(self):
@@ -192,14 +172,17 @@
         # make a branch
         format.initialize(dir)
         # register a format for it.
-        BranchFormat.register_format(format)
+        _mod_branch.BranchFormat.register_format(format)
         # which branch.Open will refuse (not supported)
-        self.assertRaises(UnsupportedFormatError, Branch.open, self.get_url())
+        self.assertRaises(errors.UnsupportedFormatError,
+                          _mod_branch.Branch.open, self.get_url())
         self.make_branch_and_tree('foo')
         # but open_downlevel will work
-        self.assertEqual(format.open(dir), bzrdir.BzrDir.open(self.get_url()).open_branch(unsupported=True))
+        self.assertEqual(
+            format.open(dir),
+            bzrdir.BzrDir.open(self.get_url()).open_branch(unsupported=True))
         # unregister the format
-        BranchFormat.unregister_format(format)
+        _mod_branch.BranchFormat.unregister_format(format)
         self.make_branch_and_tree('bar')
 
 
@@ -216,7 +199,7 @@
         raise NotImplementedError(self.get_class)
 
     def test_creation(self):
-        format = BzrDirMetaFormat1()
+        format = bzrdir.BzrDirMetaFormat1()
         format.set_branch_format(_mod_branch.BzrBranchFormat6())
         branch = self.make_branch('a', format=format)
         self.assertIsInstance(branch, self.get_class())
@@ -309,7 +292,7 @@
                          'locations.conf')
 
 
-class TestBranch6(TestBranch67, TestCaseWithTransport):
+class TestBranch6(TestBranch67, tests.TestCaseWithTransport):
 
     def get_class(self):
         return _mod_branch.BzrBranch6
@@ -330,7 +313,7 @@
         self.assertRaises(errors.UnstackableBranchFormat, branch.get_stacked_on_url)
 
 
-class TestBranch7(TestBranch67, TestCaseWithTransport):
+class TestBranch7(TestBranch67, tests.TestCaseWithTransport):
 
     def get_class(self):
         return _mod_branch.BzrBranch7
@@ -380,13 +363,14 @@
         self.assertTrue(branch.repository.has_revision(revid))
 
 
-class BzrBranch8(TestCaseWithTransport):
+class BzrBranch8(tests.TestCaseWithTransport):
 
     def make_branch(self, location, format=None):
         if format is None:
             format = bzrdir.format_registry.make_bzrdir('1.9')
             format.set_branch_format(_mod_branch.BzrBranchFormat8())
-        return TestCaseWithTransport.make_branch(self, location, format=format)
+        return tests.TestCaseWithTransport.make_branch(
+            self, location, format=format)
 
     def create_branch_with_reference(self):
         branch = self.make_branch('branch')
@@ -436,24 +420,25 @@
         branch.lock_write()
         branch.set_reference_info('file-id', 'path2', 'location2')
         branch.unlock()
-        doppelganger = Branch.open('branch')
+        doppelganger = _mod_branch.Branch.open('branch')
         doppelganger.set_reference_info('file-id', 'path3', 'location3')
         self.assertEqual(('path3', 'location3'),
                          branch.get_reference_info('file-id'))
 
-class TestBranchReference(TestCaseWithTransport):
+class TestBranchReference(tests.TestCaseWithTransport):
     """Tests for the branch reference facility."""
 
     def test_create_open_reference(self):
         bzrdirformat = bzrdir.BzrDirMetaFormat1()
-        t = get_transport(self.get_url('.'))
+        t = transport.get_transport(self.get_url('.'))
         t.mkdir('repo')
         dir = bzrdirformat.initialize(self.get_url('repo'))
         dir.create_repository()
         target_branch = dir.create_branch()
         t.mkdir('branch')
         branch_dir = bzrdirformat.initialize(self.get_url('branch'))
-        made_branch = BranchReferenceFormat().initialize(branch_dir, target_branch)
+        made_branch = _mod_branch.BranchReferenceFormat().initialize(
+            branch_dir, target_branch)
         self.assertEqual(made_branch.base, target_branch.base)
         opened_branch = branch_dir.open_branch()
         self.assertEqual(opened_branch.base, target_branch.base)
@@ -470,17 +455,18 @@
             _mod_branch.BranchReferenceFormat().get_reference(checkout.bzrdir))
 
 
-class TestHooks(TestCase):
+class TestHooks(tests.TestCase):
 
     def test_constructor(self):
         """Check that creating a BranchHooks instance has the right defaults."""
-        hooks = BranchHooks()
+        hooks = _mod_branch.BranchHooks()
         self.assertTrue("set_rh" in hooks, "set_rh not in %s" % hooks)
         self.assertTrue("post_push" in hooks, "post_push not in %s" % hooks)
         self.assertTrue("post_commit" in hooks, "post_commit not in %s" % hooks)
         self.assertTrue("pre_commit" in hooks, "pre_commit not in %s" % hooks)
         self.assertTrue("post_pull" in hooks, "post_pull not in %s" % hooks)
-        self.assertTrue("post_uncommit" in hooks, "post_uncommit not in %s" % hooks)
+        self.assertTrue("post_uncommit" in hooks,
+                        "post_uncommit not in %s" % hooks)
         self.assertTrue("post_change_branch_tip" in hooks,
                         "post_change_branch_tip not in %s" % hooks)
 
@@ -488,14 +474,14 @@
         """The installed hooks object should be a BranchHooks."""
         # the installed hooks are saved in self._preserved_hooks.
         self.assertIsInstance(self._preserved_hooks[_mod_branch.Branch][1],
-            BranchHooks)
-
-
-class TestPullResult(TestCase):
+                              _mod_branch.BranchHooks)
+
+
+class TestPullResult(tests.TestCase):
 
     def test_pull_result_to_int(self):
         # to support old code, the pull result can be used as an int
-        r = PullResult()
+        r = _mod_branch.PullResult()
         r.old_revno = 10
         r.new_revno = 20
         # this usage of results is not recommended for new code (because it
@@ -505,7 +491,7 @@
         self.assertEqual(a, "10 revisions pulled")
 
     def test_report_changed(self):
-        r = PullResult()
+        r = _mod_branch.PullResult()
         r.old_revid = "old-revid"
         r.old_revno = 10
         r.new_revid = "new-revid"
@@ -515,7 +501,7 @@
         self.assertEqual("Now on revision 20.\n", f.getvalue())
 
     def test_report_unchanged(self):
-        r = PullResult()
+        r = _mod_branch.PullResult()
         r.old_revid = "same-revid"
         r.new_revid = "same-revid"
         f = StringIO()
@@ -547,11 +533,11 @@
     """Helper for TestRunWithWriteLockedTarget."""
 
 
-class TestRunWithWriteLockedTarget(TestCase):
+class TestRunWithWriteLockedTarget(tests.TestCase):
     """Tests for _run_with_write_locked_target."""
 
     def setUp(self):
-        TestCase.setUp(self)
+        tests.TestCase.setUp(self)
         self._calls = []
 
     def func_that_returns_ok(self):
@@ -564,7 +550,7 @@
 
     def test_success_unlocks(self):
         lockable = _StubLockable(self._calls)
-        result = _run_with_write_locked_target(
+        result = _mod_branch._run_with_write_locked_target(
             lockable, self.func_that_returns_ok)
         self.assertEqual('ok', result)
         self.assertEqual(['lock_write', 'func called', 'unlock'], self._calls)
@@ -572,19 +558,22 @@
     def test_exception_unlocks_and_propagates(self):
         lockable = _StubLockable(self._calls)
         self.assertRaises(_ErrorFromCallable,
-            _run_with_write_locked_target, lockable, self.func_that_raises)
+                          _mod_branch._run_with_write_locked_target,
+                          lockable, self.func_that_raises)
         self.assertEqual(['lock_write', 'func called', 'unlock'], self._calls)
 
     def test_callable_succeeds_but_error_during_unlock(self):
         lockable = _StubLockable(self._calls, unlock_exc=_ErrorFromUnlock())
         self.assertRaises(_ErrorFromUnlock,
-            _run_with_write_locked_target, lockable, self.func_that_returns_ok)
+                          _mod_branch._run_with_write_locked_target,
+                          lockable, self.func_that_returns_ok)
         self.assertEqual(['lock_write', 'func called', 'unlock'], self._calls)
 
     def test_error_during_unlock_does_not_mask_original_error(self):
         lockable = _StubLockable(self._calls, unlock_exc=_ErrorFromUnlock())
         self.assertRaises(_ErrorFromCallable,
-            _run_with_write_locked_target, lockable, self.func_that_raises)
+                          _mod_branch._run_with_write_locked_target,
+                          lockable, self.func_that_raises)
         self.assertEqual(['lock_write', 'func called', 'unlock'], self._calls)
 
 

=== modified file 'bzrlib/tests/test_smart.py'
--- bzrlib/tests/test_smart.py	2010-01-11 05:58:22 +0000
+++ bzrlib/tests/test_smart.py	2010-02-05 15:20:51 +0000
@@ -30,47 +30,45 @@
 
 from bzrlib import (
     bencode,
+    branch as _mod_branch,
     bzrdir,
     errors,
     pack,
-    smart,
     tests,
+    transport,
     urlutils,
     versionedfile,
     )
-from bzrlib.branch import Branch, BranchReferenceFormat
-import bzrlib.smart.branch
-import bzrlib.smart.bzrdir, bzrlib.smart.bzrdir as smart_dir
-import bzrlib.smart.packrepository
-import bzrlib.smart.repository
-import bzrlib.smart.vfs
-from bzrlib.smart.request import (
-    FailedSmartServerResponse,
-    SmartServerRequest,
-    SmartServerResponse,
-    SuccessfulSmartServerResponse,
-    )
-from bzrlib.tests import (
-    split_suite_by_re,
-    )
-from bzrlib.transport import chroot, get_transport, local, memory
+from bzrlib.smart import (
+    branch as smart_branch,
+    bzrdir as smart_dir,
+    repository as smart_repo,
+    packrepository as smart_packrepo,
+    request as smart_req,
+    server,
+    vfs,
+    )
+from bzrlib.transport import (
+    chroot,
+    local,
+    memory,
+    )
 
 
 def load_tests(standard_tests, module, loader):
     """Multiply tests version and protocol consistency."""
     # FindRepository tests.
-    bzrdir_mod = bzrlib.smart.bzrdir
     scenarios = [
         ("find_repository", {
-            "_request_class":bzrdir_mod.SmartServerRequestFindRepositoryV1}),
+            "_request_class": smart_dir.SmartServerRequestFindRepositoryV1}),
         ("find_repositoryV2", {
-            "_request_class":bzrdir_mod.SmartServerRequestFindRepositoryV2}),
+            "_request_class": smart_dir.SmartServerRequestFindRepositoryV2}),
         ("find_repositoryV3", {
-            "_request_class":bzrdir_mod.SmartServerRequestFindRepositoryV3}),
+            "_request_class": smart_dir.SmartServerRequestFindRepositoryV3}),
         ]
-    to_adapt, result = split_suite_by_re(standard_tests,
+    to_adapt, result = tests.split_suite_by_re(standard_tests,
         "TestSmartServerRequestFindRepository")
-    v2_only, v1_and_2 = split_suite_by_re(to_adapt,
+    v2_only, v1_and_2 = tests.split_suite_by_re(to_adapt,
         "_v2")
     tests.multiply_tests(v1_and_2, scenarios, result)
     # The first scenario is only applicable to v1 protocols, it is deleted
@@ -91,7 +89,7 @@
             backing_transport = tests.TestCaseWithTransport.get_transport(self)
             self._chroot_server = chroot.ChrootServer(backing_transport)
             self.start_server(self._chroot_server)
-        t = get_transport(self._chroot_server.get_url())
+        t = transport.get_transport(self._chroot_server.get_url())
         if relpath is not None:
             t = t.clone(relpath)
         return t
@@ -108,7 +106,7 @@
         self.transport_server = self.make_transport_server
 
     def make_transport_server(self):
-        return smart.server.SmartTCPServer_for_testing('-' + self.id())
+        return server.SmartTCPServer_for_testing('-' + self.id())
 
     def get_smart_medium(self):
         """Get a smart medium to use in tests."""
@@ -123,11 +121,11 @@
             None, 'foo')]),('text', [
             versionedfile.FulltextContentFactory(('k2',), None, None, 'bar')])]
         fmt = bzrdir.format_registry.get('pack-0.92')().repository_format
-        bytes = smart.repository._stream_to_byte_stream(stream, fmt)
+        bytes = smart_repo._stream_to_byte_stream(stream, fmt)
         streams = []
         # Iterate the resulting iterable; checking that we get only one stream
         # out.
-        fmt, stream = smart.repository._byte_stream_to_stream(bytes)
+        fmt, stream = smart_repo._byte_stream_to_stream(bytes)
         for kind, substream in stream:
             streams.append((kind, list(substream)))
         self.assertLength(1, streams)
@@ -137,32 +135,32 @@
 class TestSmartServerResponse(tests.TestCase):
 
     def test__eq__(self):
-        self.assertEqual(SmartServerResponse(('ok', )),
-            SmartServerResponse(('ok', )))
-        self.assertEqual(SmartServerResponse(('ok', ), 'body'),
-            SmartServerResponse(('ok', ), 'body'))
-        self.assertNotEqual(SmartServerResponse(('ok', )),
-            SmartServerResponse(('notok', )))
-        self.assertNotEqual(SmartServerResponse(('ok', ), 'body'),
-            SmartServerResponse(('ok', )))
+        self.assertEqual(smart_req.SmartServerResponse(('ok', )),
+            smart_req.SmartServerResponse(('ok', )))
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), 'body'),
+            smart_req.SmartServerResponse(('ok', ), 'body'))
+        self.assertNotEqual(smart_req.SmartServerResponse(('ok', )),
+            smart_req.SmartServerResponse(('notok', )))
+        self.assertNotEqual(smart_req.SmartServerResponse(('ok', ), 'body'),
+            smart_req.SmartServerResponse(('ok', )))
         self.assertNotEqual(None,
-            SmartServerResponse(('ok', )))
+            smart_req.SmartServerResponse(('ok', )))
 
     def test__str__(self):
         """SmartServerResponses can be stringified."""
         self.assertEqual(
             "<SuccessfulSmartServerResponse args=('args',) body='body'>",
-            str(SuccessfulSmartServerResponse(('args',), 'body')))
+            str(smart_req.SuccessfulSmartServerResponse(('args',), 'body')))
         self.assertEqual(
             "<FailedSmartServerResponse args=('args',) body='body'>",
-            str(FailedSmartServerResponse(('args',), 'body')))
+            str(smart_req.FailedSmartServerResponse(('args',), 'body')))
 
 
 class TestSmartServerRequest(tests.TestCaseWithMemoryTransport):
 
     def test_translate_client_path(self):
         transport = self.get_transport()
-        request = SmartServerRequest(transport, 'foo/')
+        request = smart_req.SmartServerRequest(transport, 'foo/')
         self.assertEqual('./', request.translate_client_path('foo/'))
         self.assertRaises(
             errors.InvalidURLJoin, request.translate_client_path, 'foo/..')
@@ -178,7 +176,7 @@
     def test_translate_client_path_vfs(self):
         """VfsRequests receive escaped paths rather than raw UTF-8."""
         transport = self.get_transport()
-        request = smart.vfs.VfsRequest(transport, 'foo/')
+        request = vfs.VfsRequest(transport, 'foo/')
         e_acute = u'\N{LATIN SMALL LETTER E WITH ACUTE}'.encode('utf-8')
         escaped = urlutils.escape('foo/' + e_acute)
         self.assertEqual('./' + urlutils.escape(e_acute),
@@ -186,7 +184,7 @@
 
     def test_transport_from_client_path(self):
         transport = self.get_transport()
-        request = SmartServerRequest(transport, 'foo/')
+        request = smart_req.SmartServerRequest(transport, 'foo/')
         self.assertEqual(
             transport.base,
             request.transport_from_client_path('foo/').base)
@@ -203,7 +201,7 @@
         local_result = dir.cloning_metadir()
         request_class = smart_dir.SmartServerBzrDirRequestCloningMetaDir
         request = request_class(backing)
-        expected = SuccessfulSmartServerResponse(
+        expected = smart_req.SuccessfulSmartServerResponse(
             (local_result.network_name(),
             local_result.repository_format.network_name(),
             ('branch', local_result.get_branch_format().network_name())))
@@ -215,14 +213,15 @@
         referenced_branch = self.make_branch('referenced')
         dir = self.make_bzrdir('.')
         local_result = dir.cloning_metadir()
-        reference = BranchReferenceFormat().initialize(dir, referenced_branch)
-        reference_url = BranchReferenceFormat().get_reference(dir)
+        reference = _mod_branch.BranchReferenceFormat().initialize(
+            dir, referenced_branch)
+        reference_url = _mod_branch.BranchReferenceFormat().get_reference(dir)
         # The server shouldn't try to follow the branch reference, so it's fine
         # if the referenced branch isn't reachable.
         backing.rename('referenced', 'moved')
         request_class = smart_dir.SmartServerBzrDirRequestCloningMetaDir
         request = request_class(backing)
-        expected = FailedSmartServerResponse(('BranchReference',))
+        expected = smart_req.FailedSmartServerResponse(('BranchReference',))
         self.assertEqual(expected, request.execute('', 'False'))
 
 
@@ -233,12 +232,12 @@
         """When there is a bzrdir present, the call succeeds."""
         backing = self.get_transport()
         self.make_bzrdir('.')
-        request_class = bzrlib.smart.bzrdir.SmartServerRequestCreateRepository
+        request_class = smart_dir.SmartServerRequestCreateRepository
         request = request_class(backing)
         reference_bzrdir_format = bzrdir.format_registry.get('pack-0.92')()
         reference_format = reference_bzrdir_format.repository_format
         network_name = reference_format.network_name()
-        expected = SuccessfulSmartServerResponse(
+        expected = smart_req.SuccessfulSmartServerResponse(
             ('ok', 'no', 'no', 'no', network_name))
         self.assertEqual(expected, request.execute('', network_name, 'True'))
 
@@ -251,7 +250,7 @@
         backing = self.get_transport()
         request = self._request_class(backing)
         self.make_bzrdir('.')
-        self.assertEqual(SmartServerResponse(('norepository', )),
+        self.assertEqual(smart_req.SmartServerResponse(('norepository', )),
             request.execute(''))
 
     def test_nonshared_repository(self):
@@ -263,7 +262,7 @@
         result = self._make_repository_and_result()
         self.assertEqual(result, request.execute(''))
         self.make_bzrdir('subdir')
-        self.assertEqual(SmartServerResponse(('norepository', )),
+        self.assertEqual(smart_req.SmartServerResponse(('norepository', )),
             request.execute('subdir'))
 
     def _make_repository_and_result(self, shared=False, format=None):
@@ -284,19 +283,20 @@
             external = 'yes'
         else:
             external = 'no'
-        if (smart.bzrdir.SmartServerRequestFindRepositoryV3 ==
+        if (smart_dir.SmartServerRequestFindRepositoryV3 ==
             self._request_class):
-            return SuccessfulSmartServerResponse(
+            return smart_req.SuccessfulSmartServerResponse(
                 ('ok', '', rich_root, subtrees, external,
                  repo._format.network_name()))
-        elif (smart.bzrdir.SmartServerRequestFindRepositoryV2 ==
+        elif (smart_dir.SmartServerRequestFindRepositoryV2 ==
             self._request_class):
             # All tests so far are on formats, and for non-external
             # repositories.
-            return SuccessfulSmartServerResponse(
+            return smart_req.SuccessfulSmartServerResponse(
                 ('ok', '', rich_root, subtrees, external))
         else:
-            return SuccessfulSmartServerResponse(('ok', '', rich_root, subtrees))
+            return smart_req.SuccessfulSmartServerResponse(
+                ('ok', '', rich_root, subtrees))
 
     def test_shared_repository(self):
         """When there is a shared repository, we get 'ok', 'relpath-to-repo'."""
@@ -305,11 +305,13 @@
         result = self._make_repository_and_result(shared=True)
         self.assertEqual(result, request.execute(''))
         self.make_bzrdir('subdir')
-        result2 = SmartServerResponse(result.args[0:1] + ('..', ) + result.args[2:])
+        result2 = smart_req.SmartServerResponse(
+            result.args[0:1] + ('..', ) + result.args[2:])
         self.assertEqual(result2,
             request.execute('subdir'))
         self.make_bzrdir('subdir/deeper')
-        result3 = SmartServerResponse(result.args[0:1] + ('../..', ) + result.args[2:])
+        result3 = smart_req.SmartServerResponse(
+            result.args[0:1] + ('../..', ) + result.args[2:])
         self.assertEqual(result3,
             request.execute('subdir/deeper'))
 
@@ -317,7 +319,8 @@
         """Test for the format attributes for rich root and subtree support."""
         backing = self.get_transport()
         request = self._request_class(backing)
-        result = self._make_repository_and_result(format='dirstate-with-subtree')
+        result = self._make_repository_and_result(
+            format='dirstate-with-subtree')
         # check the test will be valid
         self.assertEqual('yes', result.args[2])
         self.assertEqual('yes', result.args[3])
@@ -327,7 +330,8 @@
         """Test for the supports_external_lookups attribute."""
         backing = self.get_transport()
         request = self._request_class(backing)
-        result = self._make_repository_and_result(format='dirstate-with-subtree')
+        result = self._make_repository_and_result(
+            format='dirstate-with-subtree')
         # check the test will be valid
         self.assertEqual('no', result.args[4])
         self.assertEqual(result, request.execute(''))
@@ -344,7 +348,7 @@
         local_result = dir._get_config()._get_config_file().read()
         request_class = smart_dir.SmartServerBzrDirRequestConfigFile
         request = request_class(backing)
-        expected = SuccessfulSmartServerResponse((), local_result)
+        expected = smart_req.SuccessfulSmartServerResponse((), local_result)
         self.assertEqual(expected, request.execute(''))
 
     def test_missing(self):
@@ -352,7 +356,7 @@
         dir = self.make_bzrdir('.')
         request_class = smart_dir.SmartServerBzrDirRequestConfigFile
         request = request_class(backing)
-        expected = SuccessfulSmartServerResponse((), '')
+        expected = smart_req.SuccessfulSmartServerResponse((), '')
         self.assertEqual(expected, request.execute(''))
 
 
@@ -361,8 +365,8 @@
     def test_empty_dir(self):
         """Initializing an empty dir should succeed and do it."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestInitializeBzrDir(backing)
-        self.assertEqual(SmartServerResponse(('ok', )),
+        request = smart_dir.SmartServerRequestInitializeBzrDir(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('ok', )),
             request.execute(''))
         made_dir = bzrdir.BzrDir.open_from_transport(backing)
         # no branch, tree or repository is expected with the current
@@ -374,20 +378,21 @@
     def test_missing_dir(self):
         """Initializing a missing directory should fail like the bzrdir api."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestInitializeBzrDir(backing)
+        request = smart_dir.SmartServerRequestInitializeBzrDir(backing)
         self.assertRaises(errors.NoSuchFile,
             request.execute, 'subdir')
 
     def test_initialized_dir(self):
         """Initializing an extant bzrdir should fail like the bzrdir api."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestInitializeBzrDir(backing)
+        request = smart_dir.SmartServerRequestInitializeBzrDir(backing)
         self.make_bzrdir('subdir')
         self.assertRaises(errors.FileExists,
             request.execute, 'subdir')
 
 
-class TestSmartServerRequestBzrDirInitializeEx(tests.TestCaseWithMemoryTransport):
+class TestSmartServerRequestBzrDirInitializeEx(
+    tests.TestCaseWithMemoryTransport):
     """Basic tests for BzrDir.initialize_ex_1.16 in the smart server.
 
     The main unit tests in test_bzrdir exercise the API comprehensively.
@@ -397,11 +402,12 @@
         """Initializing an empty dir should succeed and do it."""
         backing = self.get_transport()
         name = self.make_bzrdir('reference')._format.network_name()
-        request = smart.bzrdir.SmartServerRequestBzrDirInitializeEx(backing)
-        self.assertEqual(SmartServerResponse(('', '', '', '', '', '', name,
-            'False', '', '', '')),
+        request = smart_dir.SmartServerRequestBzrDirInitializeEx(backing)
+        self.assertEqual(
+            smart_req.SmartServerResponse(('', '', '', '', '', '', name,
+                                           'False', '', '', '')),
             request.execute(name, '', 'True', 'False', 'False', '', '', '', '',
-            'False'))
+                            'False'))
         made_dir = bzrdir.BzrDir.open_from_transport(backing)
         # no branch, tree or repository is expected with the current
         # default format.
@@ -413,7 +419,7 @@
         """Initializing a missing directory should fail like the bzrdir api."""
         backing = self.get_transport()
         name = self.make_bzrdir('reference')._format.network_name()
-        request = smart.bzrdir.SmartServerRequestBzrDirInitializeEx(backing)
+        request = smart_dir.SmartServerRequestBzrDirInitializeEx(backing)
         self.assertRaises(errors.NoSuchFile, request.execute, name,
             'subdir/dir', 'False', 'False', 'False', '', '', '', '', 'False')
 
@@ -421,76 +427,76 @@
         """Initializing an extant directory should fail like the bzrdir api."""
         backing = self.get_transport()
         name = self.make_bzrdir('reference')._format.network_name()
-        request = smart.bzrdir.SmartServerRequestBzrDirInitializeEx(backing)
+        request = smart_dir.SmartServerRequestBzrDirInitializeEx(backing)
         self.make_bzrdir('subdir')
         self.assertRaises(errors.FileExists, request.execute, name, 'subdir',
             'False', 'False', 'False', '', '', '', '', 'False')
 
 
 class TestSmartServerRequestOpenBzrDir(tests.TestCaseWithMemoryTransport):
-    
+
     def test_no_directory(self):
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir(backing)
-        self.assertEqual(SmartServerResponse(('no', )),
+        request = smart_dir.SmartServerRequestOpenBzrDir(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('does-not-exist'))
 
     def test_empty_directory(self):
         backing = self.get_transport()
         backing.mkdir('empty')
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir(backing)
-        self.assertEqual(SmartServerResponse(('no', )),
+        request = smart_dir.SmartServerRequestOpenBzrDir(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('empty'))
 
     def test_outside_root_client_path(self):
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir(backing,
+        request = smart_dir.SmartServerRequestOpenBzrDir(backing,
             root_client_path='root')
-        self.assertEqual(SmartServerResponse(('no', )),
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('not-root'))
 
-    
+
 class TestSmartServerRequestOpenBzrDir_2_1(tests.TestCaseWithMemoryTransport):
-    
+
     def test_no_directory(self):
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
-        self.assertEqual(SmartServerResponse(('no', )),
+        request = smart_dir.SmartServerRequestOpenBzrDir_2_1(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('does-not-exist'))
 
     def test_empty_directory(self):
         backing = self.get_transport()
         backing.mkdir('empty')
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
-        self.assertEqual(SmartServerResponse(('no', )),
+        request = smart_dir.SmartServerRequestOpenBzrDir_2_1(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('empty'))
 
     def test_present_without_workingtree(self):
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
+        request = smart_dir.SmartServerRequestOpenBzrDir_2_1(backing)
         self.make_bzrdir('.')
-        self.assertEqual(SmartServerResponse(('yes', 'no')),
+        self.assertEqual(smart_req.SmartServerResponse(('yes', 'no')),
             request.execute(''))
 
     def test_outside_root_client_path(self):
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing,
+        request = smart_dir.SmartServerRequestOpenBzrDir_2_1(backing,
             root_client_path='root')
-        self.assertEqual(SmartServerResponse(('no',)),
+        self.assertEqual(smart_req.SmartServerResponse(('no',)),
             request.execute('not-root'))
 
-    
+
 class TestSmartServerRequestOpenBzrDir_2_1_disk(TestCaseWithChrootedTransport):
 
     def test_present_with_workingtree(self):
         self.vfs_transport_factory = local.LocalURLServer
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
+        request = smart_dir.SmartServerRequestOpenBzrDir_2_1(backing)
         bd = self.make_bzrdir('.')
         bd.create_repository()
         bd.create_branch()
         bd.create_workingtree()
-        self.assertEqual(SmartServerResponse(('yes', 'yes')),
+        self.assertEqual(smart_req.SmartServerResponse(('yes', 'yes')),
             request.execute(''))
 
 
@@ -499,37 +505,38 @@
     def test_no_branch(self):
         """When there is no branch, ('nobranch', ) is returned."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranch(backing)
+        request = smart_dir.SmartServerRequestOpenBranch(backing)
         self.make_bzrdir('.')
-        self.assertEqual(SmartServerResponse(('nobranch', )),
+        self.assertEqual(smart_req.SmartServerResponse(('nobranch', )),
             request.execute(''))
 
     def test_branch(self):
         """When there is a branch, 'ok' is returned."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranch(backing)
+        request = smart_dir.SmartServerRequestOpenBranch(backing)
         self.make_branch('.')
-        self.assertEqual(SmartServerResponse(('ok', '')),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', '')),
             request.execute(''))
 
     def test_branch_reference(self):
         """When there is a branch reference, the reference URL is returned."""
         self.vfs_transport_factory = local.LocalURLServer
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranch(backing)
+        request = smart_dir.SmartServerRequestOpenBranch(backing)
         branch = self.make_branch('branch')
         checkout = branch.create_checkout('reference',lightweight=True)
-        reference_url = BranchReferenceFormat().get_reference(checkout.bzrdir)
+        reference_url = _mod_branch.BranchReferenceFormat().get_reference(
+            checkout.bzrdir)
         self.assertFileEqual(reference_url, 'reference/.bzr/branch/location')
-        self.assertEqual(SmartServerResponse(('ok', reference_url)),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', reference_url)),
             request.execute('reference'))
 
     def test_notification_on_branch_from_repository(self):
         """When there is a repository, the error should return details."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranch(backing)
+        request = smart_dir.SmartServerRequestOpenBranch(backing)
         repo = self.make_repository('.')
-        self.assertEqual(SmartServerResponse(('nobranch',)),
+        self.assertEqual(smart_req.SmartServerResponse(('nobranch',)),
             request.execute(''))
 
 
@@ -539,29 +546,32 @@
         """When there is no branch, ('nobranch', ) is returned."""
         backing = self.get_transport()
         self.make_bzrdir('.')
-        request = smart.bzrdir.SmartServerRequestOpenBranchV2(backing)
-        self.assertEqual(SmartServerResponse(('nobranch', )),
+        request = smart_dir.SmartServerRequestOpenBranchV2(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('nobranch', )),
             request.execute(''))
 
     def test_branch(self):
         """When there is a branch, 'ok' is returned."""
         backing = self.get_transport()
         expected = self.make_branch('.')._format.network_name()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV2(backing)
-        self.assertEqual(SuccessfulSmartServerResponse(('branch', expected)),
-            request.execute(''))
+        request = smart_dir.SmartServerRequestOpenBranchV2(backing)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(
+                ('branch', expected)),
+                         request.execute(''))
 
     def test_branch_reference(self):
         """When there is a branch reference, the reference URL is returned."""
         self.vfs_transport_factory = local.LocalURLServer
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV2(backing)
+        request = smart_dir.SmartServerRequestOpenBranchV2(backing)
         branch = self.make_branch('branch')
         checkout = branch.create_checkout('reference',lightweight=True)
-        reference_url = BranchReferenceFormat().get_reference(checkout.bzrdir)
+        reference_url = _mod_branch.BranchReferenceFormat().get_reference(
+            checkout.bzrdir)
         self.assertFileEqual(reference_url, 'reference/.bzr/branch/location')
-        self.assertEqual(SuccessfulSmartServerResponse(('ref', reference_url)),
-            request.execute('reference'))
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(
+                ('ref', reference_url)),
+                         request.execute('reference'))
 
     def test_stacked_branch(self):
         """Opening a stacked branch does not open the stacked-on branch."""
@@ -569,26 +579,27 @@
         feature = self.make_branch('feature')
         feature.set_stacked_on_url(trunk.base)
         opened_branches = []
-        Branch.hooks.install_named_hook('open', opened_branches.append, None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'open', opened_branches.append, None)
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV2(backing)
+        request = smart_dir.SmartServerRequestOpenBranchV2(backing)
         request.setup_jail()
         try:
             response = request.execute('feature')
         finally:
             request.teardown_jail()
         expected_format = feature._format.network_name()
-        self.assertEqual(
-            SuccessfulSmartServerResponse(('branch', expected_format)),
-            response)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(
+                ('branch', expected_format)),
+                         response)
         self.assertLength(1, opened_branches)
 
     def test_notification_on_branch_from_repository(self):
         """When there is a repository, the error should return details."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV2(backing)
+        request = smart_dir.SmartServerRequestOpenBranchV2(backing)
         repo = self.make_repository('.')
-        self.assertEqual(SmartServerResponse(('nobranch',)),
+        self.assertEqual(smart_req.SmartServerResponse(('nobranch',)),
             request.execute(''))
 
 
@@ -598,29 +609,32 @@
         """When there is no branch, ('nobranch', ) is returned."""
         backing = self.get_transport()
         self.make_bzrdir('.')
-        request = smart.bzrdir.SmartServerRequestOpenBranchV3(backing)
-        self.assertEqual(SmartServerResponse(('nobranch',)),
+        request = smart_dir.SmartServerRequestOpenBranchV3(backing)
+        self.assertEqual(smart_req.SmartServerResponse(('nobranch',)),
             request.execute(''))
 
     def test_branch(self):
         """When there is a branch, 'ok' is returned."""
         backing = self.get_transport()
         expected = self.make_branch('.')._format.network_name()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV3(backing)
-        self.assertEqual(SuccessfulSmartServerResponse(('branch', expected)),
-            request.execute(''))
+        request = smart_dir.SmartServerRequestOpenBranchV3(backing)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(
+                ('branch', expected)),
+                         request.execute(''))
 
     def test_branch_reference(self):
         """When there is a branch reference, the reference URL is returned."""
         self.vfs_transport_factory = local.LocalURLServer
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV3(backing)
+        request = smart_dir.SmartServerRequestOpenBranchV3(backing)
         branch = self.make_branch('branch')
         checkout = branch.create_checkout('reference',lightweight=True)
-        reference_url = BranchReferenceFormat().get_reference(checkout.bzrdir)
+        reference_url = _mod_branch.BranchReferenceFormat().get_reference(
+            checkout.bzrdir)
         self.assertFileEqual(reference_url, 'reference/.bzr/branch/location')
-        self.assertEqual(SuccessfulSmartServerResponse(('ref', reference_url)),
-            request.execute('reference'))
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(
+                ('ref', reference_url)),
+                         request.execute('reference'))
 
     def test_stacked_branch(self):
         """Opening a stacked branch does not open the stacked-on branch."""
@@ -628,28 +642,29 @@
         feature = self.make_branch('feature')
         feature.set_stacked_on_url(trunk.base)
         opened_branches = []
-        Branch.hooks.install_named_hook('open', opened_branches.append, None)
+        _mod_branch.Branch.hooks.install_named_hook(
+            'open', opened_branches.append, None)
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV3(backing)
+        request = smart_dir.SmartServerRequestOpenBranchV3(backing)
         request.setup_jail()
         try:
             response = request.execute('feature')
         finally:
             request.teardown_jail()
         expected_format = feature._format.network_name()
-        self.assertEqual(
-            SuccessfulSmartServerResponse(('branch', expected_format)),
-            response)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(
+                ('branch', expected_format)),
+                         response)
         self.assertLength(1, opened_branches)
 
     def test_notification_on_branch_from_repository(self):
         """When there is a repository, the error should return details."""
         backing = self.get_transport()
-        request = smart.bzrdir.SmartServerRequestOpenBranchV3(backing)
+        request = smart_dir.SmartServerRequestOpenBranchV3(backing)
         repo = self.make_repository('.')
-        self.assertEqual(
-            SmartServerResponse(('nobranch', 'location is a repository')),
-            request.execute(''))
+        self.assertEqual(smart_req.SmartServerResponse(
+                ('nobranch', 'location is a repository')),
+                         request.execute(''))
 
 
 class TestSmartServerRequestRevisionHistory(tests.TestCaseWithMemoryTransport):
@@ -657,15 +672,15 @@
     def test_empty(self):
         """For an empty branch, the body is empty."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerRequestRevisionHistory(backing)
+        request = smart_branch.SmartServerRequestRevisionHistory(backing)
         self.make_branch('.')
-        self.assertEqual(SmartServerResponse(('ok', ), ''),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), ''),
             request.execute(''))
 
     def test_not_empty(self):
         """For a non-empty branch, the body is empty."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerRequestRevisionHistory(backing)
+        request = smart_branch.SmartServerRequestRevisionHistory(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -673,7 +688,7 @@
         r2 = tree.commit('2nd commit', rev_id=u'\xc8'.encode('utf-8'))
         tree.unlock()
         self.assertEqual(
-            SmartServerResponse(('ok', ), ('\x00'.join([r1, r2]))),
+            smart_req.SmartServerResponse(('ok', ), ('\x00'.join([r1, r2]))),
             request.execute(''))
 
 
@@ -682,7 +697,7 @@
     def test_no_branch(self):
         """When there is a bzrdir and no branch, NotBranchError is raised."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequest(backing)
+        request = smart_branch.SmartServerBranchRequest(backing)
         self.make_bzrdir('.')
         self.assertRaises(errors.NotBranchError,
             request.execute, '')
@@ -690,27 +705,28 @@
     def test_branch_reference(self):
         """When there is a branch reference, NotBranchError is raised."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequest(backing)
+        request = smart_branch.SmartServerBranchRequest(backing)
         branch = self.make_branch('branch')
         checkout = branch.create_checkout('reference',lightweight=True)
         self.assertRaises(errors.NotBranchError,
             request.execute, 'checkout')
 
 
-class TestSmartServerBranchRequestLastRevisionInfo(tests.TestCaseWithMemoryTransport):
+class TestSmartServerBranchRequestLastRevisionInfo(
+    tests.TestCaseWithMemoryTransport):
 
     def test_empty(self):
         """For an empty branch, the result is ('ok', '0', 'null:')."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLastRevisionInfo(backing)
+        request = smart_branch.SmartServerBranchRequestLastRevisionInfo(backing)
         self.make_branch('.')
-        self.assertEqual(SmartServerResponse(('ok', '0', 'null:')),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', '0', 'null:')),
             request.execute(''))
 
     def test_not_empty(self):
         """For a non-empty branch, the result is ('ok', 'revno', 'revid')."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLastRevisionInfo(backing)
+        request = smart_branch.SmartServerBranchRequestLastRevisionInfo(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -719,20 +735,21 @@
         r2 = tree.commit('2nd commit', rev_id=rev_id_utf8)
         tree.unlock()
         self.assertEqual(
-            SmartServerResponse(('ok', '2', rev_id_utf8)),
+            smart_req.SmartServerResponse(('ok', '2', rev_id_utf8)),
             request.execute(''))
 
 
-class TestSmartServerBranchRequestGetConfigFile(tests.TestCaseWithMemoryTransport):
+class TestSmartServerBranchRequestGetConfigFile(
+    tests.TestCaseWithMemoryTransport):
 
     def test_default(self):
         """With no file, we get empty content."""
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchGetConfigFile(backing)
+        request = smart_branch.SmartServerBranchGetConfigFile(backing)
         branch = self.make_branch('.')
         # there should be no file by default
         content = ''
-        self.assertEqual(SmartServerResponse(('ok', ), content),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), content),
             request.execute(''))
 
     def test_with_content(self):
@@ -740,10 +757,10 @@
         # branch.control_files.get('branch.conf') for now - in the future it may
         # perform more complex processing.
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchGetConfigFile(backing)
+        request = smart_branch.SmartServerBranchGetConfigFile(backing)
         branch = self.make_branch('.')
         branch._transport.put_bytes('branch.conf', 'foo bar baz')
-        self.assertEqual(SmartServerResponse(('ok', ), 'foo bar baz'),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), 'foo bar baz'),
             request.execute(''))
 
 
@@ -760,26 +777,26 @@
 
     def test_value_name(self):
         branch = self.make_branch('.')
-        request = smart.branch.SmartServerBranchRequestSetConfigOption(
+        request = smart_branch.SmartServerBranchRequestSetConfigOption(
             branch.bzrdir.root_transport)
         branch_token, repo_token = self.get_lock_tokens(branch)
         config = branch._get_config()
         result = request.execute('', branch_token, repo_token, 'bar', 'foo',
             '')
-        self.assertEqual(SuccessfulSmartServerResponse(()), result)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), result)
         self.assertEqual('bar', config.get_option('foo'))
         # Cleanup
         branch.unlock()
 
     def test_value_name_section(self):
         branch = self.make_branch('.')
-        request = smart.branch.SmartServerBranchRequestSetConfigOption(
+        request = smart_branch.SmartServerBranchRequestSetConfigOption(
             branch.bzrdir.root_transport)
         branch_token, repo_token = self.get_lock_tokens(branch)
         config = branch._get_config()
         result = request.execute('', branch_token, repo_token, 'bar', 'foo',
             'gam')
-        self.assertEqual(SuccessfulSmartServerResponse(()), result)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), result)
         self.assertEqual('bar', config.get_option('foo', 'gam'))
         # Cleanup
         branch.unlock()
@@ -794,7 +811,7 @@
         tag_bytes = base_branch._get_tags_bytes()
         # get_lock_tokens takes out a lock.
         branch_token, repo_token = self.get_lock_tokens(base_branch)
-        request = smart.branch.SmartServerBranchSetTagsBytes(
+        request = smart_branch.SmartServerBranchSetTagsBytes(
             self.get_transport())
         response = request.execute('base', branch_token, repo_token)
         self.assertEqual(None, response)
@@ -802,14 +819,14 @@
         self.assertEqual(None, response)
         response = request.do_end()
         self.assertEquals(
-            SuccessfulSmartServerResponse(()), response)
+            smart_req.SuccessfulSmartServerResponse(()), response)
         base_branch.unlock()
 
     def test_lock_failed(self):
         base_branch = self.make_branch('base')
         base_branch.lock_write()
         tag_bytes = base_branch._get_tags_bytes()
-        request = smart.branch.SmartServerBranchSetTagsBytes(
+        request = smart_branch.SmartServerBranchSetTagsBytes(
             self.get_transport())
         self.assertRaises(errors.TokenMismatch, request.execute,
             'base', 'wrong token', 'wrong token')
@@ -846,7 +863,8 @@
 
     def assertRequestSucceeds(self, revision_id, revno):
         response = self.set_last_revision(revision_id, revno)
-        self.assertEqual(SuccessfulSmartServerResponse(('ok',)), response)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(('ok',)),
+                         response)
 
 
 class TestSetLastRevisionVerbMixin(object):
@@ -860,9 +878,9 @@
         """If the revision_id is not present, the verb returns NoSuchRevision.
         """
         revision_id = 'non-existent revision'
-        self.assertEqual(
-            FailedSmartServerResponse(('NoSuchRevision', revision_id)),
-            self.set_last_revision(revision_id, 1))
+        self.assertEqual(smart_req.FailedSmartServerResponse(('NoSuchRevision',
+                                                              revision_id)),
+                         self.set_last_revision(revision_id, 1))
 
     def make_tree_with_two_commits(self):
         self.tree.lock_write()
@@ -908,10 +926,10 @@
         rejection_message = u'rejection message\N{INTERROBANG}'
         def hook_that_rejects(params):
             raise errors.TipChangeRejected(rejection_message)
-        Branch.hooks.install_named_hook(
+        _mod_branch.Branch.hooks.install_named_hook(
             'pre_change_branch_tip', hook_that_rejects, None)
         self.assertEqual(
-            FailedSmartServerResponse(
+            smart_req.FailedSmartServerResponse(
                 ('TipChangeRejected', rejection_message.encode('utf-8'))),
             self.set_last_revision('null:', 0))
 
@@ -920,7 +938,7 @@
         SetLastRevisionTestBase, TestSetLastRevisionVerbMixin):
     """Tests for Branch.set_last_revision verb."""
 
-    request_class = smart.branch.SmartServerBranchRequestSetLastRevision
+    request_class = smart_branch.SmartServerBranchRequestSetLastRevision
 
     def _set_last_revision(self, revision_id, revno, branch_token, repo_token):
         return self.request.execute(
@@ -931,7 +949,7 @@
         SetLastRevisionTestBase, TestSetLastRevisionVerbMixin):
     """Tests for Branch.set_last_revision_info verb."""
 
-    request_class = smart.branch.SmartServerBranchRequestSetLastRevisionInfo
+    request_class = smart_branch.SmartServerBranchRequestSetLastRevisionInfo
 
     def _set_last_revision(self, revision_id, revno, branch_token, repo_token):
         return self.request.execute(
@@ -948,7 +966,7 @@
         SetLastRevisionTestBase, TestSetLastRevisionVerbMixin):
     """Tests for Branch.set_last_revision_ex verb."""
 
-    request_class = smart.branch.SmartServerBranchRequestSetLastRevisionEx
+    request_class = smart_branch.SmartServerBranchRequestSetLastRevisionEx
 
     def _set_last_revision(self, revision_id, revno, branch_token, repo_token):
         return self.request.execute(
@@ -957,7 +975,7 @@
     def assertRequestSucceeds(self, revision_id, revno):
         response = self.set_last_revision(revision_id, revno)
         self.assertEqual(
-            SuccessfulSmartServerResponse(('ok', revno, revision_id)),
+            smart_req.SuccessfulSmartServerResponse(('ok', revno, revision_id)),
             response)
 
     def test_branch_last_revision_info_rewind(self):
@@ -974,7 +992,7 @@
         response = self.request.execute(
             '', branch_token, repo_token, rev_id_utf8, 0, 0)
         self.assertEqual(
-            SuccessfulSmartServerResponse(('ok', 2, 'rev-2')),
+            smart_req.SuccessfulSmartServerResponse(('ok', 2, 'rev-2')),
             response)
         self.assertEqual(
             (2, 'rev-2'), self.tree.branch.last_revision_info())
@@ -984,7 +1002,7 @@
         response = self.request.execute(
             '', branch_token, repo_token, rev_id_utf8, 0, 1)
         self.assertEqual(
-            SuccessfulSmartServerResponse(('ok', 1, rev_id_utf8)),
+            smart_req.SuccessfulSmartServerResponse(('ok', 1, rev_id_utf8)),
             response)
         self.unlock_branch()
         self.assertEqual(
@@ -1015,7 +1033,7 @@
         """
         self.make_branch_with_divergent_history()
         self.assertEqual(
-            FailedSmartServerResponse(('Diverged',)),
+            smart_req.FailedSmartServerResponse(('Diverged',)),
             self.set_last_revision('child-1', 2))
         # The branch tip was not changed.
         self.assertEqual('child-2', self.tree.branch.last_revision())
@@ -1029,7 +1047,7 @@
         response = self.request.execute(
             '', branch_token, repo_token, 'child-1', 1, 0)
         self.assertEqual(
-            SuccessfulSmartServerResponse(('ok', 2, 'child-1')),
+            smart_req.SuccessfulSmartServerResponse(('ok', 2, 'child-1')),
             response)
         self.unlock_branch()
         # The branch tip was changed.
@@ -1040,18 +1058,18 @@
 
     def test_get_parent_none(self):
         base_branch = self.make_branch('base')
-        request = smart.branch.SmartServerBranchGetParent(self.get_transport())
+        request = smart_branch.SmartServerBranchGetParent(self.get_transport())
         response = request.execute('base')
         self.assertEquals(
-            SuccessfulSmartServerResponse(('',)), response)
+            smart_req.SuccessfulSmartServerResponse(('',)), response)
 
     def test_get_parent_something(self):
         base_branch = self.make_branch('base')
         base_branch.set_parent(self.get_url('foo'))
-        request = smart.branch.SmartServerBranchGetParent(self.get_transport())
+        request = smart_branch.SmartServerBranchGetParent(self.get_transport())
         response = request.execute('base')
         self.assertEquals(
-            SuccessfulSmartServerResponse(("../foo",)),
+            smart_req.SuccessfulSmartServerResponse(("../foo",)),
             response)
 
 
@@ -1062,7 +1080,7 @@
         branch.lock_write()
         branch._set_parent_location('foo')
         branch.unlock()
-        request = smart.branch.SmartServerBranchRequestSetParentLocation(
+        request = smart_branch.SmartServerBranchRequestSetParentLocation(
             self.get_transport())
         branch_token = branch.lock_write()
         repo_token = branch.repository.lock_write()
@@ -1071,12 +1089,12 @@
         finally:
             branch.repository.unlock()
             branch.unlock()
-        self.assertEqual(SuccessfulSmartServerResponse(()), response)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), response)
         self.assertEqual(None, branch.get_parent())
 
     def test_set_parent_something(self):
         branch = self.make_branch('base', format="1.9")
-        request = smart.branch.SmartServerBranchRequestSetParentLocation(
+        request = smart_branch.SmartServerBranchRequestSetParentLocation(
             self.get_transport())
         branch_token = branch.lock_write()
         repo_token = branch.repository.lock_write()
@@ -1086,21 +1104,22 @@
         finally:
             branch.repository.unlock()
             branch.unlock()
-        self.assertEqual(SuccessfulSmartServerResponse(()), response)
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(()), response)
         self.assertEqual('http://bar/', branch.get_parent())
 
 
-class TestSmartServerBranchRequestGetTagsBytes(tests.TestCaseWithMemoryTransport):
+class TestSmartServerBranchRequestGetTagsBytes(
+    tests.TestCaseWithMemoryTransport):
     # Only called when the branch format and tags match [yay factory
     # methods] so only need to test straight forward cases.
 
     def test_get_bytes(self):
         base_branch = self.make_branch('base')
-        request = smart.branch.SmartServerBranchGetTagsBytes(
+        request = smart_branch.SmartServerBranchGetTagsBytes(
             self.get_transport())
         response = request.execute('base')
         self.assertEquals(
-            SuccessfulSmartServerResponse(('',)), response)
+            smart_req.SuccessfulSmartServerResponse(('',)), response)
 
 
 class TestSmartServerBranchRequestGetStackedOnURL(tests.TestCaseWithMemoryTransport):
@@ -1110,11 +1129,11 @@
         stacked_branch = self.make_branch('stacked', format='1.6')
         # typically should be relative
         stacked_branch.set_stacked_on_url('../base')
-        request = smart.branch.SmartServerBranchRequestGetStackedOnURL(
+        request = smart_branch.SmartServerBranchRequestGetStackedOnURL(
             self.get_transport())
         response = request.execute('stacked')
         self.assertEquals(
-            SmartServerResponse(('ok', '../base')),
+            smart_req.SmartServerResponse(('ok', '../base')),
             response)
 
 
@@ -1125,33 +1144,33 @@
 
     def test_lock_write_on_unlocked_branch(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLockWrite(backing)
+        request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
         repository = branch.repository
         response = request.execute('')
         branch_nonce = branch.control_files._lock.peek().get('nonce')
         repository_nonce = repository.control_files._lock.peek().get('nonce')
-        self.assertEqual(
-            SmartServerResponse(('ok', branch_nonce, repository_nonce)),
-            response)
+        self.assertEqual(smart_req.SmartServerResponse(
+                ('ok', branch_nonce, repository_nonce)),
+                         response)
         # The branch (and associated repository) is now locked.  Verify that
         # with a new branch object.
         new_branch = repository.bzrdir.open_branch()
         self.assertRaises(errors.LockContention, new_branch.lock_write)
         # Cleanup
-        request = smart.branch.SmartServerBranchRequestUnlock(backing)
+        request = smart_branch.SmartServerBranchRequestUnlock(backing)
         response = request.execute('', branch_nonce, repository_nonce)
 
     def test_lock_write_on_locked_branch(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLockWrite(backing)
+        request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.')
         branch_token = branch.lock_write()
         branch.leave_lock_in_place()
         branch.unlock()
         response = request.execute('')
         self.assertEqual(
-            SmartServerResponse(('LockContention',)), response)
+            smart_req.SmartServerResponse(('LockContention',)), response)
         # Cleanup
         branch.lock_write(branch_token)
         branch.dont_leave_lock_in_place()
@@ -1159,7 +1178,7 @@
 
     def test_lock_write_with_tokens_on_locked_branch(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLockWrite(backing)
+        request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
         branch_token = branch.lock_write()
         repo_token = branch.repository.lock_write()
@@ -1170,7 +1189,8 @@
         response = request.execute('',
                                    branch_token, repo_token)
         self.assertEqual(
-            SmartServerResponse(('ok', branch_token, repo_token)), response)
+            smart_req.SmartServerResponse(('ok', branch_token, repo_token)),
+            response)
         # Cleanup
         branch.repository.lock_write(repo_token)
         branch.repository.dont_leave_lock_in_place()
@@ -1181,7 +1201,7 @@
 
     def test_lock_write_with_mismatched_tokens_on_locked_branch(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLockWrite(backing)
+        request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
         branch_token = branch.lock_write()
         repo_token = branch.repository.lock_write()
@@ -1192,7 +1212,7 @@
         response = request.execute('',
                                    branch_token+'xxx', repo_token)
         self.assertEqual(
-            SmartServerResponse(('TokenMismatch',)), response)
+            smart_req.SmartServerResponse(('TokenMismatch',)), response)
         # Cleanup
         branch.repository.lock_write(repo_token)
         branch.repository.dont_leave_lock_in_place()
@@ -1203,7 +1223,7 @@
 
     def test_lock_write_on_locked_repo(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestLockWrite(backing)
+        request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.', format='knit')
         repo = branch.repository
         repo_token = repo.lock_write()
@@ -1211,7 +1231,7 @@
         repo.unlock()
         response = request.execute('')
         self.assertEqual(
-            SmartServerResponse(('LockContention',)), response)
+            smart_req.SmartServerResponse(('LockContention',)), response)
         # Cleanup
         repo.lock_write(repo_token)
         repo.dont_leave_lock_in_place()
@@ -1219,7 +1239,7 @@
 
     def test_lock_write_on_readonly_transport(self):
         backing = self.get_readonly_transport()
-        request = smart.branch.SmartServerBranchRequestLockWrite(backing)
+        request = smart_branch.SmartServerBranchRequestLockWrite(backing)
         branch = self.make_branch('.')
         root = self.get_transport().clone('/')
         path = urlutils.relative_url(root.base, self.get_transport().base)
@@ -1236,7 +1256,7 @@
 
     def test_unlock_on_locked_branch_and_repo(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestUnlock(backing)
+        request = smart_branch.SmartServerBranchRequestUnlock(backing)
         branch = self.make_branch('.', format='knit')
         # Lock the branch
         branch_token = branch.lock_write()
@@ -1250,7 +1270,7 @@
         response = request.execute('',
                                    branch_token, repo_token)
         self.assertEqual(
-            SmartServerResponse(('ok',)), response)
+            smart_req.SmartServerResponse(('ok',)), response)
         # The branch is now unlocked.  Verify that with a new branch
         # object.
         new_branch = branch.bzrdir.open_branch()
@@ -1259,16 +1279,16 @@
 
     def test_unlock_on_unlocked_branch_unlocked_repo(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestUnlock(backing)
+        request = smart_branch.SmartServerBranchRequestUnlock(backing)
         branch = self.make_branch('.', format='knit')
         response = request.execute(
             '', 'branch token', 'repo token')
         self.assertEqual(
-            SmartServerResponse(('TokenMismatch',)), response)
+            smart_req.SmartServerResponse(('TokenMismatch',)), response)
 
     def test_unlock_on_unlocked_branch_locked_repo(self):
         backing = self.get_transport()
-        request = smart.branch.SmartServerBranchRequestUnlock(backing)
+        request = smart_branch.SmartServerBranchRequestUnlock(backing)
         branch = self.make_branch('.', format='knit')
         # Lock the repository.
         repo_token = branch.repository.lock_write()
@@ -1279,7 +1299,7 @@
         response = request.execute(
             '', 'branch token', repo_token)
         self.assertEqual(
-            SmartServerResponse(('TokenMismatch',)), response)
+            smart_req.SmartServerResponse(('TokenMismatch',)), response)
         # Cleanup
         branch.repository.lock_write(repo_token)
         branch.repository.dont_leave_lock_in_place()
@@ -1295,7 +1315,7 @@
         # its the exact path being looked at and the server is not
         # searching.
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryRequest(backing)
+        request = smart_repo.SmartServerRepositoryRequest(backing)
         self.make_repository('.', shared=True)
         self.make_bzrdir('subdir')
         self.assertRaises(errors.NoRepositoryPresent,
@@ -1307,34 +1327,35 @@
     def test_trivial_bzipped(self):
         # This tests that the wire encoding is actually bzipped
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetParentMap(backing)
+        request = smart_repo.SmartServerRepositoryGetParentMap(backing)
         tree = self.make_branch_and_memory_tree('.')
 
         self.assertEqual(None,
             request.execute('', 'missing-id'))
         # Note that it returns a body that is bzipped.
         self.assertEqual(
-            SuccessfulSmartServerResponse(('ok', ), bz2.compress('')),
+            smart_req.SuccessfulSmartServerResponse(('ok', ), bz2.compress('')),
             request.do_body('\n\n0\n'))
 
     def test_trivial_include_missing(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetParentMap(backing)
+        request = smart_repo.SmartServerRepositoryGetParentMap(backing)
         tree = self.make_branch_and_memory_tree('.')
 
         self.assertEqual(None,
             request.execute('', 'missing-id', 'include-missing:'))
         self.assertEqual(
-            SuccessfulSmartServerResponse(('ok', ),
+            smart_req.SuccessfulSmartServerResponse(('ok', ),
                 bz2.compress('missing:missing-id')),
             request.do_body('\n\n0\n'))
 
 
-class TestSmartServerRepositoryGetRevisionGraph(tests.TestCaseWithMemoryTransport):
+class TestSmartServerRepositoryGetRevisionGraph(
+    tests.TestCaseWithMemoryTransport):
 
     def test_none_argument(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetRevisionGraph(backing)
+        request = smart_repo.SmartServerRepositoryGetRevisionGraph(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1349,11 +1370,11 @@
         response.body = '\n'.join(sorted(response.body.split('\n')))
 
         self.assertEqual(
-            SmartServerResponse(('ok', ), '\n'.join(lines)), response)
+            smart_req.SmartServerResponse(('ok', ), '\n'.join(lines)), response)
 
     def test_specific_revision_argument(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetRevisionGraph(backing)
+        request = smart_repo.SmartServerRepositoryGetRevisionGraph(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1362,12 +1383,12 @@
         r2 = tree.commit('2nd commit', rev_id=u'\xc8'.encode('utf-8'))
         tree.unlock()
 
-        self.assertEqual(SmartServerResponse(('ok', ), rev_id_utf8),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), rev_id_utf8),
             request.execute('', rev_id_utf8))
 
     def test_no_such_revision(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetRevisionGraph(backing)
+        request = smart_repo.SmartServerRepositoryGetRevisionGraph(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1375,16 +1396,17 @@
         tree.unlock()
 
         # Note that it still returns body (of zero bytes).
-        self.assertEqual(
-            SmartServerResponse(('nosuchrevision', 'missingrevision', ), ''),
-            request.execute('', 'missingrevision'))
-
-
-class TestSmartServerRepositoryGetRevIdForRevno(tests.TestCaseWithMemoryTransport):
+        self.assertEqual(smart_req.SmartServerResponse(
+                ('nosuchrevision', 'missingrevision', ), ''),
+                         request.execute('', 'missingrevision'))
+
+
+class TestSmartServerRepositoryGetRevIdForRevno(
+    tests.TestCaseWithMemoryTransport):
 
     def test_revno_found(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetRevIdForRevno(backing)
+        request = smart_repo.SmartServerRepositoryGetRevIdForRevno(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1394,20 +1416,20 @@
         tree.commit('2nd commit', rev_id=rev2_id_utf8)
         tree.unlock()
 
-        self.assertEqual(SmartServerResponse(('ok', rev1_id_utf8)),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', rev1_id_utf8)),
             request.execute('', 1, (2, rev2_id_utf8)))
 
     def test_known_revid_missing(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetRevIdForRevno(backing)
+        request = smart_repo.SmartServerRepositoryGetRevIdForRevno(backing)
         repo = self.make_repository('.')
         self.assertEqual(
-            FailedSmartServerResponse(('nosuchrevision', 'ghost')),
+            smart_req.FailedSmartServerResponse(('nosuchrevision', 'ghost')),
             request.execute('', 1, (2, 'ghost')))
 
     def test_history_incomplete(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetRevIdForRevno(backing)
+        request = smart_repo.SmartServerRepositoryGetRevIdForRevno(backing)
         parent = self.make_branch_and_memory_tree('parent', format='1.9')
         parent.lock_write()
         parent.add([''], ['TREE_ROOT'])
@@ -1421,7 +1443,7 @@
         local.branch.create_clone_on_transport(
             self.get_transport('stacked'), stacked_on=self.get_url('parent'))
         self.assertEqual(
-            SmartServerResponse(('history-incomplete', 2, r2)),
+            smart_req.SmartServerResponse(('history-incomplete', 2, r2)),
             request.execute('stacked', 1, (3, r3)))
 
 
@@ -1440,7 +1462,7 @@
     def test_ancestry_of(self):
         """The search argument may be a 'ancestry-of' some heads'."""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetStream(backing)
+        request = smart_repo.SmartServerRepositoryGetStream(backing)
         repo, r1, r2 = self.make_two_commit_repo()
         fetch_spec = ['ancestry-of', r2]
         lines = '\n'.join(fetch_spec)
@@ -1453,7 +1475,7 @@
     def test_search(self):
         """The search argument may be a 'search' of some explicit keys."""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGetStream(backing)
+        request = smart_repo.SmartServerRepositoryGetStream(backing)
         repo, r1, r2 = self.make_two_commit_repo()
         fetch_spec = ['search', '%s %s' % (r1, r2), 'null:', '2']
         lines = '\n'.join(fetch_spec)
@@ -1469,15 +1491,15 @@
     def test_missing_revision(self):
         """For a missing revision, ('no', ) is returned."""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRequestHasRevision(backing)
+        request = smart_repo.SmartServerRequestHasRevision(backing)
         self.make_repository('.')
-        self.assertEqual(SmartServerResponse(('no', )),
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('', 'revid'))
 
     def test_present_revision(self):
         """For a present revision, ('yes', ) is returned."""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRequestHasRevision(backing)
+        request = smart_repo.SmartServerRequestHasRevision(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1485,7 +1507,7 @@
         r1 = tree.commit('a commit', rev_id=rev_id_utf8)
         tree.unlock()
         self.assertTrue(tree.branch.repository.has_revision(rev_id_utf8))
-        self.assertEqual(SmartServerResponse(('yes', )),
+        self.assertEqual(smart_req.SmartServerResponse(('yes', )),
             request.execute('', rev_id_utf8))
 
 
@@ -1494,18 +1516,18 @@
     def test_empty_revid(self):
         """With an empty revid, we get only size an number and revisions"""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryGatherStats(backing)
+        request = smart_repo.SmartServerRepositoryGatherStats(backing)
         repository = self.make_repository('.')
         stats = repository.gather_stats()
         expected_body = 'revisions: 0\n'
-        self.assertEqual(SmartServerResponse(('ok', ), expected_body),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), expected_body),
                          request.execute('', '', 'no'))
 
     def test_revid_with_committers(self):
         """For a revid we get more infos."""
         backing = self.get_transport()
         rev_id_utf8 = u'\xc8abc'.encode('utf-8')
-        request = smart.repository.SmartServerRepositoryGatherStats(backing)
+        request = smart_repo.SmartServerRepositoryGatherStats(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1519,7 +1541,7 @@
         expected_body = ('firstrev: 123456.200 3600\n'
                          'latestrev: 654321.400 0\n'
                          'revisions: 2\n')
-        self.assertEqual(SmartServerResponse(('ok', ), expected_body),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), expected_body),
                          request.execute('',
                                          rev_id_utf8, 'no'))
 
@@ -1527,7 +1549,7 @@
         """For a revid and requesting committers we get the whole thing."""
         backing = self.get_transport()
         rev_id_utf8 = u'\xc8abc'.encode('utf-8')
-        request = smart.repository.SmartServerRepositoryGatherStats(backing)
+        request = smart_repo.SmartServerRepositoryGatherStats(backing)
         tree = self.make_branch_and_memory_tree('.')
         tree.lock_write()
         tree.add('')
@@ -1543,7 +1565,7 @@
                          'firstrev: 123456.200 3600\n'
                          'latestrev: 654321.400 0\n'
                          'revisions: 2\n')
-        self.assertEqual(SmartServerResponse(('ok', ), expected_body),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), expected_body),
                          request.execute('',
                                          rev_id_utf8, 'yes'))
 
@@ -1553,17 +1575,17 @@
     def test_is_shared(self):
         """For a shared repository, ('yes', ) is returned."""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryIsShared(backing)
+        request = smart_repo.SmartServerRepositoryIsShared(backing)
         self.make_repository('.', shared=True)
-        self.assertEqual(SmartServerResponse(('yes', )),
+        self.assertEqual(smart_req.SmartServerResponse(('yes', )),
             request.execute('', ))
 
     def test_is_not_shared(self):
         """For a shared repository, ('no', ) is returned."""
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryIsShared(backing)
+        request = smart_repo.SmartServerRepositoryIsShared(backing)
         self.make_repository('.', shared=False)
-        self.assertEqual(SmartServerResponse(('no', )),
+        self.assertEqual(smart_req.SmartServerResponse(('no', )),
             request.execute('', ))
 
 
@@ -1571,29 +1593,29 @@
 
     def test_lock_write_on_unlocked_repo(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryLockWrite(backing)
+        request = smart_repo.SmartServerRepositoryLockWrite(backing)
         repository = self.make_repository('.', format='knit')
         response = request.execute('')
         nonce = repository.control_files._lock.peek().get('nonce')
-        self.assertEqual(SmartServerResponse(('ok', nonce)), response)
+        self.assertEqual(smart_req.SmartServerResponse(('ok', nonce)), response)
         # The repository is now locked.  Verify that with a new repository
         # object.
         new_repo = repository.bzrdir.open_repository()
         self.assertRaises(errors.LockContention, new_repo.lock_write)
         # Cleanup
-        request = smart.repository.SmartServerRepositoryUnlock(backing)
+        request = smart_repo.SmartServerRepositoryUnlock(backing)
         response = request.execute('', nonce)
 
     def test_lock_write_on_locked_repo(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryLockWrite(backing)
+        request = smart_repo.SmartServerRepositoryLockWrite(backing)
         repository = self.make_repository('.', format='knit')
         repo_token = repository.lock_write()
         repository.leave_lock_in_place()
         repository.unlock()
         response = request.execute('')
         self.assertEqual(
-            SmartServerResponse(('LockContention',)), response)
+            smart_req.SmartServerResponse(('LockContention',)), response)
         # Cleanup
         repository.lock_write(repo_token)
         repository.dont_leave_lock_in_place()
@@ -1601,7 +1623,7 @@
 
     def test_lock_write_on_readonly_transport(self):
         backing = self.get_readonly_transport()
-        request = smart.repository.SmartServerRepositoryLockWrite(backing)
+        request = smart_repo.SmartServerRepositoryLockWrite(backing)
         repository = self.make_repository('.', format='knit')
         response = request.execute('')
         self.assertFalse(response.is_successful())
@@ -1611,7 +1633,7 @@
 class TestInsertStreamBase(tests.TestCaseWithMemoryTransport):
 
     def make_empty_byte_stream(self, repo):
-        byte_stream = smart.repository._stream_to_byte_stream([], repo._format)
+        byte_stream = smart_repo._stream_to_byte_stream([], repo._format)
         return ''.join(byte_stream)
 
 
@@ -1619,21 +1641,21 @@
 
     def test_insert_stream_empty(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryInsertStream(backing)
+        request = smart_repo.SmartServerRepositoryInsertStream(backing)
         repository = self.make_repository('.')
         response = request.execute('', '')
         self.assertEqual(None, response)
         response = request.do_chunk(self.make_empty_byte_stream(repository))
         self.assertEqual(None, response)
         response = request.do_end()
-        self.assertEqual(SmartServerResponse(('ok', )), response)
-        
+        self.assertEqual(smart_req.SmartServerResponse(('ok', )), response)
+
 
 class TestSmartServerRepositoryInsertStreamLocked(TestInsertStreamBase):
 
     def test_insert_stream_empty(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryInsertStreamLocked(
+        request = smart_repo.SmartServerRepositoryInsertStreamLocked(
             backing)
         repository = self.make_repository('.', format='knit')
         lock_token = repository.lock_write()
@@ -1642,12 +1664,12 @@
         response = request.do_chunk(self.make_empty_byte_stream(repository))
         self.assertEqual(None, response)
         response = request.do_end()
-        self.assertEqual(SmartServerResponse(('ok', )), response)
+        self.assertEqual(smart_req.SmartServerResponse(('ok', )), response)
         repository.unlock()
 
     def test_insert_stream_with_wrong_lock_token(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryInsertStreamLocked(
+        request = smart_repo.SmartServerRepositoryInsertStreamLocked(
             backing)
         repository = self.make_repository('.', format='knit')
         lock_token = repository.lock_write()
@@ -1663,14 +1685,14 @@
 
     def test_unlock_on_locked_repo(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryUnlock(backing)
+        request = smart_repo.SmartServerRepositoryUnlock(backing)
         repository = self.make_repository('.', format='knit')
         token = repository.lock_write()
         repository.leave_lock_in_place()
         repository.unlock()
         response = request.execute('', token)
         self.assertEqual(
-            SmartServerResponse(('ok',)), response)
+            smart_req.SmartServerResponse(('ok',)), response)
         # The repository is now unlocked.  Verify that with a new repository
         # object.
         new_repo = repository.bzrdir.open_repository()
@@ -1679,39 +1701,40 @@
 
     def test_unlock_on_unlocked_repo(self):
         backing = self.get_transport()
-        request = smart.repository.SmartServerRepositoryUnlock(backing)
+        request = smart_repo.SmartServerRepositoryUnlock(backing)
         repository = self.make_repository('.', format='knit')
         response = request.execute('', 'some token')
         self.assertEqual(
-            SmartServerResponse(('TokenMismatch',)), response)
+            smart_req.SmartServerResponse(('TokenMismatch',)), response)
 
 
 class TestSmartServerIsReadonly(tests.TestCaseWithMemoryTransport):
 
     def test_is_readonly_no(self):
         backing = self.get_transport()
-        request = smart.request.SmartServerIsReadonly(backing)
+        request = smart_req.SmartServerIsReadonly(backing)
         response = request.execute()
         self.assertEqual(
-            SmartServerResponse(('no',)), response)
+            smart_req.SmartServerResponse(('no',)), response)
 
     def test_is_readonly_yes(self):
         backing = self.get_readonly_transport()
-        request = smart.request.SmartServerIsReadonly(backing)
+        request = smart_req.SmartServerIsReadonly(backing)
         response = request.execute()
         self.assertEqual(
-            SmartServerResponse(('yes',)), response)
-
-
-class TestSmartServerRepositorySetMakeWorkingTrees(tests.TestCaseWithMemoryTransport):
+            smart_req.SmartServerResponse(('yes',)), response)
+
+
+class TestSmartServerRepositorySetMakeWorkingTrees(
+    tests.TestCaseWithMemoryTransport):
 
     def test_set_false(self):
         backing = self.get_transport()
         repo = self.make_repository('.', shared=True)
         repo.set_make_working_trees(True)
-        request_class = smart.repository.SmartServerRepositorySetMakeWorkingTrees
+        request_class = smart_repo.SmartServerRepositorySetMakeWorkingTrees
         request = request_class(backing)
-        self.assertEqual(SuccessfulSmartServerResponse(('ok',)),
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(('ok',)),
             request.execute('', 'False'))
         repo = repo.bzrdir.open_repository()
         self.assertFalse(repo.make_working_trees())
@@ -1720,9 +1743,9 @@
         backing = self.get_transport()
         repo = self.make_repository('.', shared=True)
         repo.set_make_working_trees(False)
-        request_class = smart.repository.SmartServerRepositorySetMakeWorkingTrees
+        request_class = smart_repo.SmartServerRepositorySetMakeWorkingTrees
         request = request_class(backing)
-        self.assertEqual(SuccessfulSmartServerResponse(('ok',)),
+        self.assertEqual(smart_req.SuccessfulSmartServerResponse(('ok',)),
             request.execute('', 'True'))
         repo = repo.bzrdir.open_repository()
         self.assertTrue(repo.make_working_trees())
@@ -1747,10 +1770,10 @@
         repo.lock_write()
         self.addCleanup(repo.unlock)
         backing = self.get_transport()
-        request = smart.packrepository.SmartServerPackRepositoryAutopack(
+        request = smart_packrepo.SmartServerPackRepositoryAutopack(
             backing)
         response = request.execute('')
-        self.assertEqual(SmartServerResponse(('ok',)), response)
+        self.assertEqual(smart_req.SmartServerResponse(('ok',)), response)
         repo._pack_collection.reload_pack_names()
         self.assertEqual(1, len(repo._pack_collection.names()))
 
@@ -1762,10 +1785,10 @@
         for x in range(9):
             tree.commit('commit %s' % x)
         backing = self.get_transport()
-        request = smart.packrepository.SmartServerPackRepositoryAutopack(
+        request = smart_packrepo.SmartServerPackRepositoryAutopack(
             backing)
         response = request.execute('')
-        self.assertEqual(SmartServerResponse(('ok',)), response)
+        self.assertEqual(smart_req.SmartServerResponse(('ok',)), response)
         repo._pack_collection.reload_pack_names()
         self.assertEqual(9, len(repo._pack_collection.names()))
 
@@ -1773,10 +1796,10 @@
         """A request to autopack a non-pack repo is a no-op."""
         repo = self.make_repository('.', format='knit')
         backing = self.get_transport()
-        request = smart.packrepository.SmartServerPackRepositoryAutopack(
+        request = smart_packrepo.SmartServerPackRepositoryAutopack(
             backing)
         response = request.execute('')
-        self.assertEqual(SmartServerResponse(('ok',)), response)
+        self.assertEqual(smart_req.SmartServerResponse(('ok',)), response)
 
 
 class TestSmartServerVfsGet(tests.TestCaseWithMemoryTransport):
@@ -1786,9 +1809,9 @@
         filename = u'foo\N{INTERROBANG}'
         filename_escaped = urlutils.escape(filename)
         backing = self.get_transport()
-        request = smart.vfs.GetRequest(backing)
+        request = vfs.GetRequest(backing)
         backing.put_bytes_non_atomic(filename_escaped, 'contents')
-        self.assertEqual(SmartServerResponse(('ok', ), 'contents'),
+        self.assertEqual(smart_req.SmartServerResponse(('ok', ), 'contents'),
             request.execute(filename_escaped))
 
 
@@ -1799,81 +1822,81 @@
         """All registered request_handlers can be found."""
         # If there's a typo in a register_lazy call, this loop will fail with
         # an AttributeError.
-        for key, item in smart.request.request_handlers.iteritems():
+        for key, item in smart_req.request_handlers.iteritems():
             pass
 
     def assertHandlerEqual(self, verb, handler):
-        self.assertEqual(smart.request.request_handlers.get(verb), handler)
+        self.assertEqual(smart_req.request_handlers.get(verb), handler)
 
     def test_registered_methods(self):
         """Test that known methods are registered to the correct object."""
         self.assertHandlerEqual('Branch.get_config_file',
-            smart.branch.SmartServerBranchGetConfigFile)
+            smart_branch.SmartServerBranchGetConfigFile)
         self.assertHandlerEqual('Branch.get_parent',
-            smart.branch.SmartServerBranchGetParent)
+            smart_branch.SmartServerBranchGetParent)
         self.assertHandlerEqual('Branch.get_tags_bytes',
-            smart.branch.SmartServerBranchGetTagsBytes)
+            smart_branch.SmartServerBranchGetTagsBytes)
         self.assertHandlerEqual('Branch.lock_write',
-            smart.branch.SmartServerBranchRequestLockWrite)
+            smart_branch.SmartServerBranchRequestLockWrite)
         self.assertHandlerEqual('Branch.last_revision_info',
-            smart.branch.SmartServerBranchRequestLastRevisionInfo)
+            smart_branch.SmartServerBranchRequestLastRevisionInfo)
         self.assertHandlerEqual('Branch.revision_history',
-            smart.branch.SmartServerRequestRevisionHistory)
+            smart_branch.SmartServerRequestRevisionHistory)
         self.assertHandlerEqual('Branch.set_config_option',
-            smart.branch.SmartServerBranchRequestSetConfigOption)
+            smart_branch.SmartServerBranchRequestSetConfigOption)
         self.assertHandlerEqual('Branch.set_last_revision',
-            smart.branch.SmartServerBranchRequestSetLastRevision)
+            smart_branch.SmartServerBranchRequestSetLastRevision)
         self.assertHandlerEqual('Branch.set_last_revision_info',
-            smart.branch.SmartServerBranchRequestSetLastRevisionInfo)
+            smart_branch.SmartServerBranchRequestSetLastRevisionInfo)
         self.assertHandlerEqual('Branch.set_last_revision_ex',
-            smart.branch.SmartServerBranchRequestSetLastRevisionEx)
+            smart_branch.SmartServerBranchRequestSetLastRevisionEx)
         self.assertHandlerEqual('Branch.set_parent_location',
-            smart.branch.SmartServerBranchRequestSetParentLocation)
+            smart_branch.SmartServerBranchRequestSetParentLocation)
         self.assertHandlerEqual('Branch.unlock',
-            smart.branch.SmartServerBranchRequestUnlock)
+            smart_branch.SmartServerBranchRequestUnlock)
         self.assertHandlerEqual('BzrDir.find_repository',
-            smart.bzrdir.SmartServerRequestFindRepositoryV1)
+            smart_dir.SmartServerRequestFindRepositoryV1)
         self.assertHandlerEqual('BzrDir.find_repositoryV2',
-            smart.bzrdir.SmartServerRequestFindRepositoryV2)
+            smart_dir.SmartServerRequestFindRepositoryV2)
         self.assertHandlerEqual('BzrDirFormat.initialize',
-            smart.bzrdir.SmartServerRequestInitializeBzrDir)
+            smart_dir.SmartServerRequestInitializeBzrDir)
         self.assertHandlerEqual('BzrDirFormat.initialize_ex_1.16',
-            smart.bzrdir.SmartServerRequestBzrDirInitializeEx)
+            smart_dir.SmartServerRequestBzrDirInitializeEx)
         self.assertHandlerEqual('BzrDir.cloning_metadir',
-            smart.bzrdir.SmartServerBzrDirRequestCloningMetaDir)
+            smart_dir.SmartServerBzrDirRequestCloningMetaDir)
         self.assertHandlerEqual('BzrDir.get_config_file',
-            smart.bzrdir.SmartServerBzrDirRequestConfigFile)
+            smart_dir.SmartServerBzrDirRequestConfigFile)
         self.assertHandlerEqual('BzrDir.open_branch',
-            smart.bzrdir.SmartServerRequestOpenBranch)
+            smart_dir.SmartServerRequestOpenBranch)
         self.assertHandlerEqual('BzrDir.open_branchV2',
-            smart.bzrdir.SmartServerRequestOpenBranchV2)
+            smart_dir.SmartServerRequestOpenBranchV2)
         self.assertHandlerEqual('BzrDir.open_branchV3',
-            smart.bzrdir.SmartServerRequestOpenBranchV3)
+            smart_dir.SmartServerRequestOpenBranchV3)
         self.assertHandlerEqual('PackRepository.autopack',
-            smart.packrepository.SmartServerPackRepositoryAutopack)
+            smart_packrepo.SmartServerPackRepositoryAutopack)
         self.assertHandlerEqual('Repository.gather_stats',
-            smart.repository.SmartServerRepositoryGatherStats)
+            smart_repo.SmartServerRepositoryGatherStats)
         self.assertHandlerEqual('Repository.get_parent_map',
-            smart.repository.SmartServerRepositoryGetParentMap)
+            smart_repo.SmartServerRepositoryGetParentMap)
         self.assertHandlerEqual('Repository.get_rev_id_for_revno',
-            smart.repository.SmartServerRepositoryGetRevIdForRevno)
+            smart_repo.SmartServerRepositoryGetRevIdForRevno)
         self.assertHandlerEqual('Repository.get_revision_graph',
-            smart.repository.SmartServerRepositoryGetRevisionGraph)
+            smart_repo.SmartServerRepositoryGetRevisionGraph)
         self.assertHandlerEqual('Repository.get_stream',
-            smart.repository.SmartServerRepositoryGetStream)
+            smart_repo.SmartServerRepositoryGetStream)
         self.assertHandlerEqual('Repository.has_revision',
-            smart.repository.SmartServerRequestHasRevision)
+            smart_repo.SmartServerRequestHasRevision)
         self.assertHandlerEqual('Repository.insert_stream',
-            smart.repository.SmartServerRepositoryInsertStream)
+            smart_repo.SmartServerRepositoryInsertStream)
         self.assertHandlerEqual('Repository.insert_stream_locked',
-            smart.repository.SmartServerRepositoryInsertStreamLocked)
+            smart_repo.SmartServerRepositoryInsertStreamLocked)
         self.assertHandlerEqual('Repository.is_shared',
-            smart.repository.SmartServerRepositoryIsShared)
+            smart_repo.SmartServerRepositoryIsShared)
         self.assertHandlerEqual('Repository.lock_write',
-            smart.repository.SmartServerRepositoryLockWrite)
+            smart_repo.SmartServerRepositoryLockWrite)
         self.assertHandlerEqual('Repository.tarball',
-            smart.repository.SmartServerRepositoryTarball)
+            smart_repo.SmartServerRepositoryTarball)
         self.assertHandlerEqual('Repository.unlock',
-            smart.repository.SmartServerRepositoryUnlock)
+            smart_repo.SmartServerRepositoryUnlock)
         self.assertHandlerEqual('Transport.is_readonly',
-            smart.request.SmartServerIsReadonly)
+            smart_req.SmartServerIsReadonly)

=== modified file 'bzrlib/tests/test_smart_transport.py'
--- bzrlib/tests/test_smart_transport.py	2010-01-07 03:03:01 +0000
+++ bzrlib/tests/test_smart_transport.py	2010-02-05 15:26:17 +0000
@@ -28,6 +28,7 @@
         errors,
         osutils,
         tests,
+        transport,
         urlutils,
         )
 from bzrlib.smart import (
@@ -39,14 +40,13 @@
         server,
         vfs,
 )
-from bzrlib.tests.test_smart import TestCaseWithSmartMedium
+from bzrlib.tests import test_smart
 from bzrlib.transport import (
-        get_transport,
+        http,
         local,
         memory,
         remote,
         )
-from bzrlib.transport.http import SmartClientHTTPMediumRequest
 
 
 class StringIOSSHVendor(object):
@@ -557,7 +557,7 @@
         self.assertRaises(errors.ReadingCompleted, request.read_bytes, None)
 
 
-class RemoteTransportTests(TestCaseWithSmartMedium):
+class RemoteTransportTests(test_smart.TestCaseWithSmartMedium):
 
     def test_plausible_url(self):
         self.assert_(self.get_url().startswith('bzr://'))
@@ -1003,12 +1003,14 @@
             mem_server.start_server()
             self.addCleanup(mem_server.stop_server)
             self.permit_url(mem_server.get_url())
-            self.backing_transport = get_transport(mem_server.get_url())
+            self.backing_transport = transport.get_transport(
+                mem_server.get_url())
         else:
             self.backing_transport = backing_transport
         if readonly:
             self.real_backing_transport = self.backing_transport
-            self.backing_transport = get_transport("readonly+" + self.backing_transport.abspath('.'))
+            self.backing_transport = transport.get_transport(
+                "readonly+" + self.backing_transport.abspath('.'))
         self.server = server.SmartTCPServer(self.backing_transport)
         self.server.start_background_thread('-' + self.id())
         self.transport = remote.RemoteTCPTransport(self.server.get_url())
@@ -1161,7 +1163,7 @@
         self.hook_calls = []
         server.SmartTCPServer.hooks.install_named_hook('server_started',
             self.capture_server_call, None)
-        self.start_server(backing_transport=get_transport("."))
+        self.start_server(backing_transport=transport.get_transport("."))
         # at this point, the server will be starting a thread up.
         # there is no indicator at the moment, so bodge it by doing a request.
         self.transport.has('.')
@@ -1194,7 +1196,7 @@
         self.hook_calls = []
         server.SmartTCPServer.hooks.install_named_hook('server_stopped',
             self.capture_server_call, None)
-        self.start_server(backing_transport=get_transport("."))
+        self.start_server(backing_transport=transport.get_transport("."))
         result = [(
             [self.backing_transport.base, self.backing_transport.external_url()]
             , self.transport.base)]
@@ -1339,13 +1341,13 @@
 class RemoteTransportRegistration(tests.TestCase):
 
     def test_registration(self):
-        t = get_transport('bzr+ssh://example.com/path')
+        t = transport.get_transport('bzr+ssh://example.com/path')
         self.assertIsInstance(t, remote.RemoteSSHTransport)
         self.assertEqual('example.com', t._host)
 
     def test_bzr_https(self):
         # https://bugs.launchpad.net/bzr/+bug/128456
-        t = get_transport('bzr+https://example.com/path')
+        t = transport.get_transport('bzr+https://example.com/path')
         self.assertIsInstance(t, remote.RemoteHTTPTransport)
         self.assertStartsWith(
             t._http_transport.base,
@@ -3516,7 +3518,7 @@
 
     def test_smart_http_medium_request_accept_bytes(self):
         medium = FakeHTTPMedium()
-        request = SmartClientHTTPMediumRequest(medium)
+        request = http.SmartClientHTTPMediumRequest(medium)
         request.accept_bytes('abc')
         request.accept_bytes('def')
         self.assertEqual(None, medium.written_request)

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2010-01-08 20:03:04 +0000
+++ bzrlib/tests/test_transport.py	2010-02-05 16:25:49 +0000
@@ -25,89 +25,73 @@
     errors,
     osutils,
     tests,
-    transport as _mod_transport,
+    transport,
     urlutils,
     )
 from bzrlib.transport import (
+    chroot,
     fakenfs,
+    local,
     memory,
+    pathfilter,
     readonly,
     )
-from bzrlib.errors import (DependencyNotPresent,
-                           FileExists,
-                           InvalidURLJoin,
-                           NoSuchFile,
-                           PathNotChild,
-                           ReadError,
-                           UnsupportedProtocol,
-                           )
-from bzrlib.tests import features, TestCase, TestCaseInTempDir
-from bzrlib.transport import (_clear_protocol_handlers,
-                              _CoalescedOffset,
-                              ConnectedTransport,
-                              _get_protocol_handlers,
-                              _set_protocol_handlers,
-                              _get_transport_modules,
-                              get_transport,
-                              LateReadError,
-                              register_lazy_transport,
-                              register_transport_proto,
-                              Transport,
-                              )
-from bzrlib.transport.chroot import ChrootServer
-from bzrlib.transport.local import (LocalTransport,
-                                    EmulatedWin32LocalTransport)
-from bzrlib.transport.pathfilter import PathFilteringServer
+from bzrlib.tests import features
 
 
 # TODO: Should possibly split transport-specific tests into their own files.
 
 
-class TestTransport(TestCase):
+class TestTransport(tests.TestCase):
     """Test the non transport-concrete class functionality."""
 
+    # FIXME: These tests should use addCleanup() and/or overrideAttr() instead
+    # of try/finally -- vila 20100205
+
     def test__get_set_protocol_handlers(self):
-        handlers = _get_protocol_handlers()
+        handlers = transport._get_protocol_handlers()
         self.assertNotEqual([], handlers.keys( ))
         try:
-            _clear_protocol_handlers()
-            self.assertEqual([], _get_protocol_handlers().keys())
+            transport._clear_protocol_handlers()
+            self.assertEqual([], transport._get_protocol_handlers().keys())
         finally:
-            _set_protocol_handlers(handlers)
+            transport._set_protocol_handlers(handlers)
 
     def test_get_transport_modules(self):
-        handlers = _get_protocol_handlers()
+        handlers = transport._get_protocol_handlers()
         # don't pollute the current handlers
-        _clear_protocol_handlers()
+        transport._clear_protocol_handlers()
         class SampleHandler(object):
             """I exist, isnt that enough?"""
         try:
-            _clear_protocol_handlers()
-            register_transport_proto('foo')
-            register_lazy_transport('foo', 'bzrlib.tests.test_transport',
-                                    'TestTransport.SampleHandler')
-            register_transport_proto('bar')
-            register_lazy_transport('bar', 'bzrlib.tests.test_transport',
-                                    'TestTransport.SampleHandler')
+            transport._clear_protocol_handlers()
+            transport.register_transport_proto('foo')
+            transport.register_lazy_transport('foo',
+                                              'bzrlib.tests.test_transport',
+                                              'TestTransport.SampleHandler')
+            transport.register_transport_proto('bar')
+            transport.register_lazy_transport('bar',
+                                              'bzrlib.tests.test_transport',
+                                              'TestTransport.SampleHandler')
             self.assertEqual([SampleHandler.__module__,
                               'bzrlib.transport.chroot',
                               'bzrlib.transport.pathfilter'],
-                             _get_transport_modules())
+                             transport._get_transport_modules())
         finally:
-            _set_protocol_handlers(handlers)
+            transport._set_protocol_handlers(handlers)
 
     def test_transport_dependency(self):
         """Transport with missing dependency causes no error"""
-        saved_handlers = _get_protocol_handlers()
+        saved_handlers = transport._get_protocol_handlers()
         # don't pollute the current handlers
-        _clear_protocol_handlers()
+        transport._clear_protocol_handlers()
         try:
-            register_transport_proto('foo')
-            register_lazy_transport('foo', 'bzrlib.tests.test_transport',
-                    'BadTransportHandler')
+            transport.register_transport_proto('foo')
+            transport.register_lazy_transport(
+                'foo', 'bzrlib.tests.test_transport', 'BadTransportHandler')
             try:
-                get_transport('foo://fooserver/foo')
-            except UnsupportedProtocol, e:
+                transport.get_transport('foo://fooserver/foo')
+            except errors.UnsupportedProtocol, e:
                 e_str = str(e)
                 self.assertEquals('Unsupported protocol'
                                   ' for url "foo://fooserver/foo":'
@@ -117,48 +101,49 @@
                 self.fail('Did not raise UnsupportedProtocol')
         finally:
             # restore original values
-            _set_protocol_handlers(saved_handlers)
+            transport._set_protocol_handlers(saved_handlers)
 
     def test_transport_fallback(self):
         """Transport with missing dependency causes no error"""
-        saved_handlers = _get_protocol_handlers()
+        saved_handlers = transport._get_protocol_handlers()
         try:
-            _clear_protocol_handlers()
-            register_transport_proto('foo')
-            register_lazy_transport('foo', 'bzrlib.tests.test_transport',
-                    'BackupTransportHandler')
-            register_lazy_transport('foo', 'bzrlib.tests.test_transport',
-                    'BadTransportHandler')
-            t = get_transport('foo://fooserver/foo')
+            transport._clear_protocol_handlers()
+            transport.register_transport_proto('foo')
+            transport.register_lazy_transport(
+                'foo', 'bzrlib.tests.test_transport', 'BackupTransportHandler')
+            transport.register_lazy_transport(
+                'foo', 'bzrlib.tests.test_transport', 'BadTransportHandler')
+            t = transport.get_transport('foo://fooserver/foo')
             self.assertTrue(isinstance(t, BackupTransportHandler))
         finally:
-            _set_protocol_handlers(saved_handlers)
+            transport._set_protocol_handlers(saved_handlers)
 
     def test_ssh_hints(self):
         """Transport ssh:// should raise an error pointing out bzr+ssh://"""
         try:
-            get_transport('ssh://fooserver/foo')
-        except UnsupportedProtocol, e:
+            transport.get_transport('ssh://fooserver/foo')
+        except errors.UnsupportedProtocol, e:
             e_str = str(e)
             self.assertEquals('Unsupported protocol'
                               ' for url "ssh://fooserver/foo":'
-                              ' bzr supports bzr+ssh to operate over ssh, use "bzr+ssh://fooserver/foo".',
+                              ' bzr supports bzr+ssh to operate over ssh,'
+                              ' use "bzr+ssh://fooserver/foo".',
                               str(e))
         else:
             self.fail('Did not raise UnsupportedProtocol')
 
     def test_LateReadError(self):
         """The LateReadError helper should raise on read()."""
-        a_file = LateReadError('a path')
+        a_file = transport.LateReadError('a path')
         try:
             a_file.read()
-        except ReadError, error:
+        except errors.ReadError, error:
             self.assertEqual('a path', error.path)
-        self.assertRaises(ReadError, a_file.read, 40)
+        self.assertRaises(errors.ReadError, a_file.read, 40)
         a_file.close()
 
     def test__combine_paths(self):
-        t = Transport('/')
+        t = transport.Transport('/')
         self.assertEqual('/home/sarah/project/foo',
                          t._combine_paths('/home/sarah', 'project/foo'))
         self.assertEqual('/etc',
@@ -175,11 +160,11 @@
         self.assertEqual('memory:///t is not a local path.', str(e))
 
 
-class TestCoalesceOffsets(TestCase):
+class TestCoalesceOffsets(tests.TestCase):
 
     def check(self, expected, offsets, limit=0, max_size=0, fudge=0):
-        coalesce = Transport._coalesce_offsets
-        exp = [_CoalescedOffset(*x) for x in expected]
+        coalesce = transport.Transport._coalesce_offsets
+        exp = [transport._CoalescedOffset(*x) for x in expected]
         out = list(coalesce(offsets, limit=limit, fudge_factor=fudge,
                             max_size=max_size))
         self.assertEqual(exp, out)
@@ -260,149 +245,150 @@
                    max_size=1*1024*1024*1024)
 
 
-class TestMemoryServer(TestCase):
+class TestMemoryServer(tests.TestCase):
 
     def test_create_server(self):
         server = memory.MemoryServer()
         server.start_server()
         url = server.get_url()
-        self.assertTrue(url in _mod_transport.transport_list_registry)
-        t = _mod_transport.get_transport(url)
+        self.assertTrue(url in transport.transport_list_registry)
+        t = transport.get_transport(url)
         del t
         server.stop_server()
-        self.assertFalse(url in _mod_transport.transport_list_registry)
+        self.assertFalse(url in transport.transport_list_registry)
         self.assertRaises(errors.UnsupportedProtocol,
-                          _mod_transport.get_transport, url)
-
-
-class TestMemoryTransport(TestCase):
+                          transport.get_transport, url)
+
+
+class TestMemoryTransport(tests.TestCase):
 
     def test_get_transport(self):
         memory.MemoryTransport()
 
     def test_clone(self):
-        transport = memory.MemoryTransport()
-        self.assertTrue(isinstance(transport, memory.MemoryTransport))
-        self.assertEqual("memory:///", transport.clone("/").base)
+        t = memory.MemoryTransport()
+        self.assertTrue(isinstance(t, memory.MemoryTransport))
+        self.assertEqual("memory:///", t.clone("/").base)
 
     def test_abspath(self):
-        transport = memory.MemoryTransport()
-        self.assertEqual("memory:///relpath", transport.abspath('relpath'))
+        t = memory.MemoryTransport()
+        self.assertEqual("memory:///relpath", t.abspath('relpath'))
 
     def test_abspath_of_root(self):
-        transport = memory.MemoryTransport()
-        self.assertEqual("memory:///", transport.base)
-        self.assertEqual("memory:///", transport.abspath('/'))
+        t = memory.MemoryTransport()
+        self.assertEqual("memory:///", t.base)
+        self.assertEqual("memory:///", t.abspath('/'))
 
     def test_abspath_of_relpath_starting_at_root(self):
-        transport = memory.MemoryTransport()
-        self.assertEqual("memory:///foo", transport.abspath('/foo'))
+        t = memory.MemoryTransport()
+        self.assertEqual("memory:///foo", t.abspath('/foo'))
 
     def test_append_and_get(self):
-        transport = memory.MemoryTransport()
-        transport.append_bytes('path', 'content')
-        self.assertEqual(transport.get('path').read(), 'content')
-        transport.append_file('path', StringIO('content'))
-        self.assertEqual(transport.get('path').read(), 'contentcontent')
+        t = memory.MemoryTransport()
+        t.append_bytes('path', 'content')
+        self.assertEqual(t.get('path').read(), 'content')
+        t.append_file('path', StringIO('content'))
+        self.assertEqual(t.get('path').read(), 'contentcontent')
 
     def test_put_and_get(self):
-        transport = memory.MemoryTransport()
-        transport.put_file('path', StringIO('content'))
-        self.assertEqual(transport.get('path').read(), 'content')
-        transport.put_bytes('path', 'content')
-        self.assertEqual(transport.get('path').read(), 'content')
+        t = memory.MemoryTransport()
+        t.put_file('path', StringIO('content'))
+        self.assertEqual(t.get('path').read(), 'content')
+        t.put_bytes('path', 'content')
+        self.assertEqual(t.get('path').read(), 'content')
 
     def test_append_without_dir_fails(self):
-        transport = memory.MemoryTransport()
-        self.assertRaises(NoSuchFile,
-                          transport.append_bytes, 'dir/path', 'content')
+        t = memory.MemoryTransport()
+        self.assertRaises(errors.NoSuchFile,
+                          t.append_bytes, 'dir/path', 'content')
 
     def test_put_without_dir_fails(self):
-        transport = memory.MemoryTransport()
-        self.assertRaises(NoSuchFile,
-                          transport.put_file, 'dir/path', StringIO('content'))
+        t = memory.MemoryTransport()
+        self.assertRaises(errors.NoSuchFile,
+                          t.put_file, 'dir/path', StringIO('content'))
 
     def test_get_missing(self):
         transport = memory.MemoryTransport()
-        self.assertRaises(NoSuchFile, transport.get, 'foo')
+        self.assertRaises(errors.NoSuchFile, transport.get, 'foo')
 
     def test_has_missing(self):
-        transport = memory.MemoryTransport()
-        self.assertEquals(False, transport.has('foo'))
+        t = memory.MemoryTransport()
+        self.assertEquals(False, t.has('foo'))
 
     def test_has_present(self):
-        transport = memory.MemoryTransport()
-        transport.append_bytes('foo', 'content')
-        self.assertEquals(True, transport.has('foo'))
+        t = memory.MemoryTransport()
+        t.append_bytes('foo', 'content')
+        self.assertEquals(True, t.has('foo'))
 
     def test_list_dir(self):
-        transport = memory.MemoryTransport()
-        transport.put_bytes('foo', 'content')
-        transport.mkdir('dir')
-        transport.put_bytes('dir/subfoo', 'content')
-        transport.put_bytes('dirlike', 'content')
+        t = memory.MemoryTransport()
+        t.put_bytes('foo', 'content')
+        t.mkdir('dir')
+        t.put_bytes('dir/subfoo', 'content')
+        t.put_bytes('dirlike', 'content')
 
-        self.assertEquals(['dir', 'dirlike', 'foo'], sorted(transport.list_dir('.')))
-        self.assertEquals(['subfoo'], sorted(transport.list_dir('dir')))
+        self.assertEquals(['dir', 'dirlike', 'foo'], sorted(t.list_dir('.')))
+        self.assertEquals(['subfoo'], sorted(t.list_dir('dir')))
 
     def test_mkdir(self):
-        transport = memory.MemoryTransport()
-        transport.mkdir('dir')
-        transport.append_bytes('dir/path', 'content')
-        self.assertEqual(transport.get('dir/path').read(), 'content')
+        t = memory.MemoryTransport()
+        t.mkdir('dir')
+        t.append_bytes('dir/path', 'content')
+        self.assertEqual(t.get('dir/path').read(), 'content')
 
     def test_mkdir_missing_parent(self):
-        transport = memory.MemoryTransport()
-        self.assertRaises(NoSuchFile,
-                          transport.mkdir, 'dir/dir')
+        t = memory.MemoryTransport()
+        self.assertRaises(errors.NoSuchFile, t.mkdir, 'dir/dir')
 
     def test_mkdir_twice(self):
-        transport = memory.MemoryTransport()
-        transport.mkdir('dir')
-        self.assertRaises(FileExists, transport.mkdir, 'dir')
+        t = memory.MemoryTransport()
+        t.mkdir('dir')
+        self.assertRaises(errors.FileExists, t.mkdir, 'dir')
 
     def test_parameters(self):
-        transport = memory.MemoryTransport()
-        self.assertEqual(True, transport.listable())
-        self.assertEqual(False, transport.is_readonly())
+        t = memory.MemoryTransport()
+        self.assertEqual(True, t.listable())
+        self.assertEqual(False, t.is_readonly())
 
     def test_iter_files_recursive(self):
-        transport = memory.MemoryTransport()
-        transport.mkdir('dir')
-        transport.put_bytes('dir/foo', 'content')
-        transport.put_bytes('dir/bar', 'content')
-        transport.put_bytes('bar', 'content')
-        paths = set(transport.iter_files_recursive())
+        t = memory.MemoryTransport()
+        t.mkdir('dir')
+        t.put_bytes('dir/foo', 'content')
+        t.put_bytes('dir/bar', 'content')
+        t.put_bytes('bar', 'content')
+        paths = set(t.iter_files_recursive())
         self.assertEqual(set(['dir/foo', 'dir/bar', 'bar']), paths)
 
     def test_stat(self):
-        transport = memory.MemoryTransport()
-        transport.put_bytes('foo', 'content')
-        transport.put_bytes('bar', 'phowar')
-        self.assertEqual(7, transport.stat('foo').st_size)
-        self.assertEqual(6, transport.stat('bar').st_size)
-
-
-class ChrootDecoratorTransportTest(TestCase):
+        t = memory.MemoryTransport()
+        t.put_bytes('foo', 'content')
+        t.put_bytes('bar', 'phowar')
+        self.assertEqual(7, t.stat('foo').st_size)
+        self.assertEqual(6, t.stat('bar').st_size)
+
+
+class ChrootDecoratorTransportTest(tests.TestCase):
     """Chroot decoration specific tests."""
 
     def test_abspath(self):
         # The abspath is always relative to the chroot_url.
-        server = ChrootServer(get_transport('memory:///foo/bar/'))
+        server = chroot.ChrootServer(
+            transport.get_transport('memory:///foo/bar/'))
         self.start_server(server)
-        transport = get_transport(server.get_url())
-        self.assertEqual(server.get_url(), transport.abspath('/'))
+        t = transport.get_transport(server.get_url())
+        self.assertEqual(server.get_url(), t.abspath('/'))
 
-        subdir_transport = transport.clone('subdir')
-        self.assertEqual(server.get_url(), subdir_transport.abspath('/'))
+        subdir_t = t.clone('subdir')
+        self.assertEqual(server.get_url(), subdir_t.abspath('/'))
 
     def test_clone(self):
-        server = ChrootServer(get_transport('memory:///foo/bar/'))
+        server = chroot.ChrootServer(
+            transport.get_transport('memory:///foo/bar/'))
         self.start_server(server)
-        transport = get_transport(server.get_url())
+        t = transport.get_transport(server.get_url())
         # relpath from root and root path are the same
-        relpath_cloned = transport.clone('foo')
-        abspath_cloned = transport.clone('/foo')
+        relpath_cloned = t.clone('foo')
+        abspath_cloned = t.clone('/foo')
         self.assertEqual(server, relpath_cloned.server)
         self.assertEqual(server, abspath_cloned.server)
 
@@ -414,14 +400,15 @@
         This is so that it is not possible to escape a chroot by doing::
             url = chroot_transport.base
             parent_url = urlutils.join(url, '..')
-            new_transport = get_transport(parent_url)
+            new_t = transport.get_transport(parent_url)
         """
-        server = ChrootServer(get_transport('memory:///path/subpath'))
+        server = chroot.ChrootServer(
+            transport.get_transport('memory:///path/subpath'))
         self.start_server(server)
-        transport = get_transport(server.get_url())
-        new_transport = get_transport(transport.base)
-        self.assertEqual(transport.server, new_transport.server)
-        self.assertEqual(transport.base, new_transport.base)
+        t = transport.get_transport(server.get_url())
+        new_t = transport.get_transport(t.base)
+        self.assertEqual(t.server, new_t.server)
+        self.assertEqual(t.base, new_t.base)
 
     def test_urljoin_preserves_chroot(self):
         """Using urlutils.join(url, '..') on a chroot URL should not produce a
@@ -430,41 +417,43 @@
         This is so that it is not possible to escape a chroot by doing::
             url = chroot_transport.base
             parent_url = urlutils.join(url, '..')
-            new_transport = get_transport(parent_url)
+            new_t = transport.get_transport(parent_url)
         """
-        server = ChrootServer(get_transport('memory:///path/'))
+        server = chroot.ChrootServer(transport.get_transport('memory:///path/'))
         self.start_server(server)
-        transport = get_transport(server.get_url())
+        t = transport.get_transport(server.get_url())
         self.assertRaises(
-            InvalidURLJoin, urlutils.join, transport.base, '..')
-
-
-class ChrootServerTest(TestCase):
+            errors.InvalidURLJoin, urlutils.join, t.base, '..')
+
+
+class TestChrootServer(tests.TestCase):
 
     def test_construct(self):
         backing_transport = memory.MemoryTransport()
-        server = ChrootServer(backing_transport)
+        server = chroot.ChrootServer(backing_transport)
         self.assertEqual(backing_transport, server.backing_transport)
 
     def test_setUp(self):
         backing_transport = memory.MemoryTransport()
-        server = ChrootServer(backing_transport)
+        server = chroot.ChrootServer(backing_transport)
         server.start_server()
         try:
-            self.assertTrue(server.scheme in _get_protocol_handlers().keys())
+            self.assertTrue(server.scheme
+                            in transport._get_protocol_handlers().keys())
         finally:
             server.stop_server()
 
     def test_stop_server(self):
         backing_transport = memory.MemoryTransport()
-        server = ChrootServer(backing_transport)
+        server = chroot.ChrootServer(backing_transport)
         server.start_server()
         server.stop_server()
-        self.assertFalse(server.scheme in _get_protocol_handlers().keys())
+        self.assertFalse(server.scheme
+                         in transport._get_protocol_handlers().keys())
 
     def test_get_url(self):
         backing_transport = memory.MemoryTransport()
-        server = ChrootServer(backing_transport)
+        server = chroot.ChrootServer(backing_transport)
         server.start_server()
         try:
             self.assertEqual('chroot-%d:///' % id(server), server.get_url())
@@ -472,19 +461,20 @@
             server.stop_server()
 
 
-class PathFilteringDecoratorTransportTest(TestCase):
+class PathFilteringDecoratorTransportTest(tests.TestCase):
     """Pathfilter decoration specific tests."""
 
     def test_abspath(self):
         # The abspath is always relative to the base of the backing transport.
-        server = PathFilteringServer(get_transport('memory:///foo/bar/'),
+        server = pathfilter.PathFilteringServer(
+            transport.get_transport('memory:///foo/bar/'),
             lambda x: x)
         server.start_server()
-        transport = get_transport(server.get_url())
-        self.assertEqual(server.get_url(), transport.abspath('/'))
+        t = transport.get_transport(server.get_url())
+        self.assertEqual(server.get_url(), t.abspath('/'))
 
-        subdir_transport = transport.clone('subdir')
-        self.assertEqual(server.get_url(), subdir_transport.abspath('/'))
+        subdir_t = t.clone('subdir')
+        self.assertEqual(server.get_url(), subdir_t.abspath('/'))
         server.stop_server()
 
     def make_pf_transport(self, filter_func=None):
@@ -494,50 +484,49 @@
             parameter to override it."""
         if filter_func is None:
             filter_func = lambda x: x
-        server = PathFilteringServer(
-            get_transport('memory:///foo/bar/'), filter_func)
+        server = pathfilter.PathFilteringServer(
+            transport.get_transport('memory:///foo/bar/'), filter_func)
         server.start_server()
         self.addCleanup(server.stop_server)
-        return get_transport(server.get_url())
+        return transport.get_transport(server.get_url())
 
     def test__filter(self):
         # _filter (with an identity func as filter_func) always returns
         # paths relative to the base of the backing transport.
-        transport = self.make_pf_transport()
-        self.assertEqual('foo', transport._filter('foo'))
-        self.assertEqual('foo/bar', transport._filter('foo/bar'))
-        self.assertEqual('', transport._filter('..'))
-        self.assertEqual('', transport._filter('/'))
+        t = self.make_pf_transport()
+        self.assertEqual('foo', t._filter('foo'))
+        self.assertEqual('foo/bar', t._filter('foo/bar'))
+        self.assertEqual('', t._filter('..'))
+        self.assertEqual('', t._filter('/'))
         # The base of the pathfiltering transport is taken into account too.
-        transport = transport.clone('subdir1/subdir2')
-        self.assertEqual('subdir1/subdir2/foo', transport._filter('foo'))
-        self.assertEqual(
-            'subdir1/subdir2/foo/bar', transport._filter('foo/bar'))
-        self.assertEqual('subdir1', transport._filter('..'))
-        self.assertEqual('', transport._filter('/'))
+        t = t.clone('subdir1/subdir2')
+        self.assertEqual('subdir1/subdir2/foo', t._filter('foo'))
+        self.assertEqual('subdir1/subdir2/foo/bar', t._filter('foo/bar'))
+        self.assertEqual('subdir1', t._filter('..'))
+        self.assertEqual('', t._filter('/'))
 
     def test_filter_invocation(self):
         filter_log = []
         def filter(path):
             filter_log.append(path)
             return path
-        transport = self.make_pf_transport(filter)
-        transport.has('abc')
+        t = self.make_pf_transport(filter)
+        t.has('abc')
         self.assertEqual(['abc'], filter_log)
         del filter_log[:]
-        transport.clone('abc').has('xyz')
+        t.clone('abc').has('xyz')
         self.assertEqual(['abc/xyz'], filter_log)
         del filter_log[:]
-        transport.has('/abc')
+        t.has('/abc')
         self.assertEqual(['abc'], filter_log)
 
     def test_clone(self):
-        transport = self.make_pf_transport()
+        t = self.make_pf_transport()
         # relpath from root and root path are the same
-        relpath_cloned = transport.clone('foo')
-        abspath_cloned = transport.clone('/foo')
-        self.assertEqual(transport.server, relpath_cloned.server)
-        self.assertEqual(transport.server, abspath_cloned.server)
+        relpath_cloned = t.clone('foo')
+        abspath_cloned = t.clone('/foo')
+        self.assertEqual(t.server, relpath_cloned.server)
+        self.assertEqual(t.server, abspath_cloned.server)
 
     def test_url_preserves_pathfiltering(self):
         """Calling get_transport on a pathfiltered transport's base should
@@ -548,36 +537,35 @@
         otherwise) the filtering by doing::
             url = filtered_transport.base
             parent_url = urlutils.join(url, '..')
-            new_transport = get_transport(parent_url)
+            new_t = transport.get_transport(parent_url)
         """
-        transport = self.make_pf_transport()
-        new_transport = get_transport(transport.base)
-        self.assertEqual(transport.server, new_transport.server)
-        self.assertEqual(transport.base, new_transport.base)
-
-
-class ReadonlyDecoratorTransportTest(TestCase):
+        t = self.make_pf_transport()
+        new_t = transport.get_transport(t.base)
+        self.assertEqual(t.server, new_t.server)
+        self.assertEqual(t.base, new_t.base)
+
+
+class ReadonlyDecoratorTransportTest(tests.TestCase):
     """Readonly decoration specific tests."""
 
     def test_local_parameters(self):
         # connect to . in readonly mode
-        transport = readonly.ReadonlyTransportDecorator('readonly+.')
-        self.assertEqual(True, transport.listable())
-        self.assertEqual(True, transport.is_readonly())
+        t = readonly.ReadonlyTransportDecorator('readonly+.')
+        self.assertEqual(True, t.listable())
+        self.assertEqual(True, t.is_readonly())
 
     def test_http_parameters(self):
         from bzrlib.tests.http_server import HttpServer
         # connect to '.' via http which is not listable
         server = HttpServer()
         self.start_server(server)
-        transport = get_transport('readonly+' + server.get_url())
-        self.failUnless(isinstance(transport,
-                                   readonly.ReadonlyTransportDecorator))
-        self.assertEqual(False, transport.listable())
-        self.assertEqual(True, transport.is_readonly())
-
-
-class FakeNFSDecoratorTests(TestCaseInTempDir):
+        t = transport.get_transport('readonly+' + server.get_url())
+        self.failUnless(isinstance(t, readonly.ReadonlyTransportDecorator))
+        self.assertEqual(False, t.listable())
+        self.assertEqual(True, t.is_readonly())
+
+
+class FakeNFSDecoratorTests(tests.TestCaseInTempDir):
     """NFS decorator specific tests."""
 
     def get_nfs_transport(self, url):
@@ -587,9 +575,9 @@
     def test_local_parameters(self):
         # the listable and is_readonly parameters
         # are not changed by the fakenfs decorator
-        transport = self.get_nfs_transport('.')
-        self.assertEqual(True, transport.listable())
-        self.assertEqual(False, transport.is_readonly())
+        t = self.get_nfs_transport('.')
+        self.assertEqual(True, t.listable())
+        self.assertEqual(False, t.is_readonly())
 
     def test_http_parameters(self):
         # the listable and is_readonly parameters
@@ -598,11 +586,10 @@
         # connect to '.' via http which is not listable
         server = HttpServer()
         self.start_server(server)
-        transport = self.get_nfs_transport(server.get_url())
-        self.assertIsInstance(
-            transport, fakenfs.FakeNFSTransportDecorator)
-        self.assertEqual(False, transport.listable())
-        self.assertEqual(True, transport.is_readonly())
+        t = self.get_nfs_transport(server.get_url())
+        self.assertIsInstance(t, fakenfs.FakeNFSTransportDecorator)
+        self.assertEqual(False, t.listable())
+        self.assertEqual(True, t.is_readonly())
 
     def test_fakenfs_server_default(self):
         # a FakeNFSServer() should bring up a local relpath server for itself
@@ -611,21 +598,20 @@
         # the url should be decorated appropriately
         self.assertStartsWith(server.get_url(), 'fakenfs+')
         # and we should be able to get a transport for it
-        transport = get_transport(server.get_url())
+        t = transport.get_transport(server.get_url())
         # which must be a FakeNFSTransportDecorator instance.
-        self.assertIsInstance(transport, fakenfs.FakeNFSTransportDecorator)
+        self.assertIsInstance(t, fakenfs.FakeNFSTransportDecorator)
 
     def test_fakenfs_rename_semantics(self):
         # a FakeNFS transport must mangle the way rename errors occur to
         # look like NFS problems.
-        transport = self.get_nfs_transport('.')
+        t = self.get_nfs_transport('.')
         self.build_tree(['from/', 'from/foo', 'to/', 'to/bar'],
-                        transport=transport)
-        self.assertRaises(errors.ResourceBusy,
-                          transport.rename, 'from', 'to')
-
-
-class FakeVFATDecoratorTests(TestCaseInTempDir):
+                        transport=t)
+        self.assertRaises(errors.ResourceBusy, t.rename, 'from', 'to')
+
+
+class FakeVFATDecoratorTests(tests.TestCaseInTempDir):
     """Tests for simulation of VFAT restrictions"""
 
     def get_vfat_transport(self, url):
@@ -635,31 +621,32 @@
 
     def test_transport_creation(self):
         from bzrlib.transport.fakevfat import FakeVFATTransportDecorator
-        transport = self.get_vfat_transport('.')
-        self.assertIsInstance(transport, FakeVFATTransportDecorator)
+        t = self.get_vfat_transport('.')
+        self.assertIsInstance(t, FakeVFATTransportDecorator)
 
     def test_transport_mkdir(self):
-        transport = self.get_vfat_transport('.')
-        transport.mkdir('HELLO')
-        self.assertTrue(transport.has('hello'))
-        self.assertTrue(transport.has('Hello'))
+        t = self.get_vfat_transport('.')
+        t.mkdir('HELLO')
+        self.assertTrue(t.has('hello'))
+        self.assertTrue(t.has('Hello'))
 
     def test_forbidden_chars(self):
-        transport = self.get_vfat_transport('.')
-        self.assertRaises(ValueError, transport.has, "<NU>")
-
-
-class BadTransportHandler(Transport):
+        t = self.get_vfat_transport('.')
+        self.assertRaises(ValueError, t.has, "<NU>")
+
+
+class BadTransportHandler(transport.Transport):
     def __init__(self, base_url):
-        raise DependencyNotPresent('some_lib', 'testing missing dependency')
-
-
-class BackupTransportHandler(Transport):
+        raise errors.DependencyNotPresent('some_lib',
+                                          'testing missing dependency')
+
+
+class BackupTransportHandler(transport.Transport):
     """Test transport that works as a backup for the BadTransportHandler"""
     pass
 
 
-class TestTransportImplementation(TestCaseInTempDir):
+class TestTransportImplementation(tests.TestCaseInTempDir):
     """Implementation verification for transports.
 
     To verify a transport we need a server factory, which is a callable
@@ -694,7 +681,7 @@
         base_url = self._server.get_url()
         url = self._adjust_url(base_url, relpath)
         # try getting the transport via the regular interface:
-        t = get_transport(url)
+        t = transport.get_transport(url)
         # vila--20070607 if the following are commented out the test suite
         # still pass. Is this really still needed or was it a forgotten
         # temporary fix ?
@@ -705,40 +692,40 @@
         return t
 
 
-class TestLocalTransports(TestCase):
+class TestLocalTransports(tests.TestCase):
 
     def test_get_transport_from_abspath(self):
         here = osutils.abspath('.')
-        t = get_transport(here)
-        self.assertIsInstance(t, LocalTransport)
+        t = transport.get_transport(here)
+        self.assertIsInstance(t, local.LocalTransport)
         self.assertEquals(t.base, urlutils.local_path_to_url(here) + '/')
 
     def test_get_transport_from_relpath(self):
         here = osutils.abspath('.')
-        t = get_transport('.')
-        self.assertIsInstance(t, LocalTransport)
+        t = transport.get_transport('.')
+        self.assertIsInstance(t, local.LocalTransport)
         self.assertEquals(t.base, urlutils.local_path_to_url('.') + '/')
 
     def test_get_transport_from_local_url(self):
         here = osutils.abspath('.')
         here_url = urlutils.local_path_to_url(here) + '/'
-        t = get_transport(here_url)
-        self.assertIsInstance(t, LocalTransport)
+        t = transport.get_transport(here_url)
+        self.assertIsInstance(t, local.LocalTransport)
         self.assertEquals(t.base, here_url)
 
     def test_local_abspath(self):
         here = osutils.abspath('.')
-        t = get_transport(here)
+        t = transport.get_transport(here)
         self.assertEquals(t.local_abspath(''), here)
 
 
-class TestWin32LocalTransport(TestCase):
+class TestWin32LocalTransport(tests.TestCase):
 
     def test_unc_clone_to_root(self):
         # Win32 UNC path like \\HOST\path
         # clone to root should stop at least at \\HOST part
         # not on \\
-        t = EmulatedWin32LocalTransport('file://HOST/path/to/some/dir/')
+        t = local.EmulatedWin32LocalTransport('file://HOST/path/to/some/dir/')
         for i in xrange(4):
             t = t.clone('..')
         self.assertEquals(t.base, 'file://HOST/')
@@ -747,11 +734,12 @@
         self.assertEquals(t.base, 'file://HOST/')
 
 
-class TestConnectedTransport(TestCase):
+class TestConnectedTransport(tests.TestCase):
     """Tests for connected to remote server transports"""
 
     def test_parse_url(self):
-        t = ConnectedTransport('http://simple.example.com/home/source')
+        t = transport.ConnectedTransport(
+            'http://simple.example.com/home/source')
         self.assertEquals(t._host, 'simple.example.com')
         self.assertEquals(t._port, None)
         self.assertEquals(t._path, '/home/source/')
@@ -762,11 +750,12 @@
 
     def test_parse_url_with_at_in_user(self):
         # Bug 228058
-        t = ConnectedTransport('ftp://user@host.com@www.host.com/')
+        t = transport.ConnectedTransport('ftp://user@host.com@www.host.com/')
         self.assertEquals(t._user, 'user@host.com')
 
     def test_parse_quoted_url(self):
-        t = ConnectedTransport('http://ro%62ey:h%40t@ex%41mple.com:2222/path')
+        t = transport.ConnectedTransport(
+            'http://ro%62ey:h%40t@ex%41mple.com:2222/path')
         self.assertEquals(t._host, 'exAmple.com')
         self.assertEquals(t._port, 2222)
         self.assertEquals(t._user, 'robey')
@@ -778,11 +767,11 @@
 
     def test_parse_invalid_url(self):
         self.assertRaises(errors.InvalidURL,
-                          ConnectedTransport,
+                          transport.ConnectedTransport,
                           'sftp://lily.org:~janneke/public/bzr/gub')
 
     def test_relpath(self):
-        t = ConnectedTransport('sftp://user@host.com/abs/path')
+        t = transport.ConnectedTransport('sftp://user@host.com/abs/path')
 
         self.assertEquals(t.relpath('sftp://user@host.com/abs/path/sub'), 'sub')
         self.assertRaises(errors.PathNotChild, t.relpath,
@@ -794,15 +783,15 @@
         self.assertRaises(errors.PathNotChild, t.relpath,
                           'sftp://user@host.com:33/abs/path/sub')
         # Make sure it works when we don't supply a username
-        t = ConnectedTransport('sftp://host.com/abs/path')
+        t = transport.ConnectedTransport('sftp://host.com/abs/path')
         self.assertEquals(t.relpath('sftp://host.com/abs/path/sub'), 'sub')
 
         # Make sure it works when parts of the path will be url encoded
-        t = ConnectedTransport('sftp://host.com/dev/%path')
+        t = transport.ConnectedTransport('sftp://host.com/dev/%path')
         self.assertEquals(t.relpath('sftp://host.com/dev/%path/sub'), 'sub')
 
     def test_connection_sharing_propagate_credentials(self):
-        t = ConnectedTransport('ftp://user@host.com/abs/path')
+        t = transport.ConnectedTransport('ftp://user@host.com/abs/path')
         self.assertEquals('user', t._user)
         self.assertEquals('host.com', t._host)
         self.assertIs(None, t._get_connection())
@@ -829,73 +818,76 @@
         self.assertIs(new_password, c._get_credentials())
 
 
-class TestReusedTransports(TestCase):
+class TestReusedTransports(tests.TestCase):
     """Tests for transport reuse"""
 
     def test_reuse_same_transport(self):
         possible_transports = []
-        t1 = get_transport('http://foo/',
-                           possible_transports=possible_transports)
+        t1 = transport.get_transport('http://foo/',
+                                     possible_transports=possible_transports)
         self.assertEqual([t1], possible_transports)
-        t2 = get_transport('http://foo/', possible_transports=[t1])
+        t2 = transport.get_transport('http://foo/',
+                                     possible_transports=[t1])
         self.assertIs(t1, t2)
 
         # Also check that final '/' are handled correctly
-        t3 = get_transport('http://foo/path/')
-        t4 = get_transport('http://foo/path', possible_transports=[t3])
+        t3 = transport.get_transport('http://foo/path/')
+        t4 = transport.get_transport('http://foo/path',
+                                     possible_transports=[t3])
         self.assertIs(t3, t4)
 
-        t5 = get_transport('http://foo/path')
-        t6 = get_transport('http://foo/path/', possible_transports=[t5])
+        t5 = transport.get_transport('http://foo/path')
+        t6 = transport.get_transport('http://foo/path/',
+                                     possible_transports=[t5])
         self.assertIs(t5, t6)
 
     def test_don_t_reuse_different_transport(self):
-        t1 = get_transport('http://foo/path')
-        t2 = get_transport('http://bar/path', possible_transports=[t1])
+        t1 = transport.get_transport('http://foo/path')
+        t2 = transport.get_transport('http://bar/path',
+                                     possible_transports=[t1])
         self.assertIsNot(t1, t2)
 
 
-class TestTransportTrace(TestCase):
+class TestTransportTrace(tests.TestCase):
 
     def test_get(self):
-        transport = get_transport('trace+memory://')
-        self.assertIsInstance(
-            transport, bzrlib.transport.trace.TransportTraceDecorator)
+        t = transport.get_transport('trace+memory://')
+        self.assertIsInstance(t, bzrlib.transport.trace.TransportTraceDecorator)
 
     def test_clone_preserves_activity(self):
-        transport = get_transport('trace+memory://')
-        transport2 = transport.clone('.')
-        self.assertTrue(transport is not transport2)
-        self.assertTrue(transport._activity is transport2._activity)
+        t = transport.get_transport('trace+memory://')
+        t2 = t.clone('.')
+        self.assertTrue(t is not t2)
+        self.assertTrue(t._activity is t2._activity)
 
     # the following specific tests are for the operations that have made use of
     # logging in tests; we could test every single operation but doing that
     # still won't cause a test failure when the top level Transport API
     # changes; so there is little return doing that.
     def test_get(self):
-        transport = get_transport('trace+memory:///')
-        transport.put_bytes('foo', 'barish')
-        transport.get('foo')
+        t = transport.get_transport('trace+memory:///')
+        t.put_bytes('foo', 'barish')
+        t.get('foo')
         expected_result = []
         # put_bytes records the bytes, not the content to avoid memory
         # pressure.
         expected_result.append(('put_bytes', 'foo', 6, None))
         # get records the file name only.
         expected_result.append(('get', 'foo'))
-        self.assertEqual(expected_result, transport._activity)
+        self.assertEqual(expected_result, t._activity)
 
     def test_readv(self):
-        transport = get_transport('trace+memory:///')
-        transport.put_bytes('foo', 'barish')
-        list(transport.readv('foo', [(0, 1), (3, 2)], adjust_for_latency=True,
-            upper_limit=6))
+        t = transport.get_transport('trace+memory:///')
+        t.put_bytes('foo', 'barish')
+        list(t.readv('foo', [(0, 1), (3, 2)],
+                     adjust_for_latency=True, upper_limit=6))
         expected_result = []
         # put_bytes records the bytes, not the content to avoid memory
         # pressure.
         expected_result.append(('put_bytes', 'foo', 6, None))
         # readv records the supplied offset request
         expected_result.append(('readv', 'foo', [(0, 1), (3, 2)], True, 6))
-        self.assertEqual(expected_result, transport._activity)
+        self.assertEqual(expected_result, t._activity)
 
 
 class TestSSHConnections(tests.TestCaseWithTransport):
@@ -978,7 +970,7 @@
             # prefix a '/' to get the right path.
             path_to_branch = '/' + path_to_branch
         url = 'bzr+ssh://fred:secret@localhost:%d%s' % (port, path_to_branch)
-        t = get_transport(url)
+        t = transport.get_transport(url)
         self.permit_url(t.base)
         t.mkdir('foo')
 

